// Code generated by smithy-go-codegen DO NOT EDIT.

package codecommit

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/codecommit/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns information about the contents of one or more commits in a repository.
func (c *Client) BatchGetCommits(ctx context.Context, params *BatchGetCommitsInput, optFns ...func(*Options)) (*BatchGetCommitsOutput, error) {
	if params == nil {
		params = &BatchGetCommitsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "BatchGetCommits", params, optFns, c.addOperationBatchGetCommitsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*BatchGetCommitsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type BatchGetCommitsInput struct {

	// The full commit IDs of the commits to get information about.
	//
	// You must supply the full SHA IDs of each commit. You cannot use shortened SHA
	// IDs.
	//
	// This member is required.
	CommitIds []string

	// The name of the repository that contains the commits.
	//
	// This member is required.
	RepositoryName *string

	noSmithyDocumentSerde
}

type BatchGetCommitsOutput struct {

	// An array of commit data type objects, each of which contains information about
	// a specified commit.
	Commits []types.Commit

	// Returns any commit IDs for which information could not be found. For example,
	// if one of the commit IDs was a shortened SHA ID or that commit was not found in
	// the specified repository, the ID returns an error object with more information.
	Errors []types.BatchGetCommitsError

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationBatchGetCommitsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpBatchGetCommits{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpBatchGetCommits{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpBatchGetCommitsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "BatchGetCommits"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
