// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type StringEnum string

// Enum values for StringEnum
const (
	StringEnumV StringEnum = "enumvalue"
)

// Values returns all known values for StringEnum. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (StringEnum) Values() []StringEnum {
	return []StringEnum{
		"enumvalue",
	}
}

type TestEnum string

// Enum values for TestEnum
const (
	TestEnumFoo TestEnum = "FOO"
	TestEnumBar TestEnum = "BAR"
	TestEnumBaz TestEnum = "BAZ"
)

// Values returns all known values for TestEnum. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TestEnum) Values() []TestEnum {
	return []TestEnum{
		"FOO",
		"BAR",
		"BAZ",
	}
}

type TestIntEnum = int32

// Enum values for TestIntEnum
const (
	TestIntEnumOne TestIntEnum = 1
	TestIntEnumTwo TestIntEnum = 2
)

type FooEnum string

// Enum values for FooEnum
const (
	FooEnumFoo  FooEnum = "Foo"
	FooEnumBaz  FooEnum = "Baz"
	FooEnumBar  FooEnum = "Bar"
	FooEnumOne  FooEnum = "1"
	FooEnumZero FooEnum = "0"
)

// Values returns all known values for FooEnum. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FooEnum) Values() []FooEnum {
	return []FooEnum{
		"Foo",
		"Baz",
		"Bar",
		"1",
		"0",
	}
}

type IntegerEnum = int32

// Enum values for IntegerEnum
const (
	IntegerEnumA IntegerEnum = 1
	IntegerEnumB IntegerEnum = 2
	IntegerEnumC IntegerEnum = 3
)
