// Code generated by smithy-go-codegen DO NOT EDIT.

package computeoptimizer

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/schemas"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns the Compute Optimizer enrollment (opt-in) status of organization member
// accounts, if your account is an organization management account.
//
// To get the enrollment status of standalone accounts, use the GetEnrollmentStatus action.
func (c *Client) GetEnrollmentStatusesForOrganization(ctx context.Context, params *GetEnrollmentStatusesForOrganizationInput, optFns ...func(*Options)) (*GetEnrollmentStatusesForOrganizationOutput, error) {
	if params == nil {
		params = &GetEnrollmentStatusesForOrganizationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetEnrollmentStatusesForOrganization", params, optFns, c.addOperationGetEnrollmentStatusesForOrganizationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetEnrollmentStatusesForOrganizationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetEnrollmentStatusesForOrganizationInput struct {

	// An array of objects to specify a filter that returns a more specific list of
	// account enrollment statuses.
	Filters []types.EnrollmentFilter

	// The maximum number of account enrollment statuses to return with a single
	// request. You can specify up to 100 statuses to return with each request.
	//
	// To retrieve the remaining results, make another request with the returned
	// nextToken value.
	MaxResults *int32

	// The token to advance to the next page of account enrollment statuses.
	NextToken *string

	noSmithyDocumentSerde
}

func (v *GetEnrollmentStatusesForOrganizationInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetEnrollmentStatusesForOrganizationRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetEnrollmentStatusesForOrganizationInput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeEnrollmentFilters(s, schemas.GetEnrollmentStatusesForOrganizationRequest_filters, v.Filters)
	if v.MaxResults != nil {
		s.WriteInt32(schemas.GetEnrollmentStatusesForOrganizationRequest_maxResults, *v.MaxResults)
	}
	if v.NextToken != nil {
		s.WriteString(schemas.GetEnrollmentStatusesForOrganizationRequest_nextToken, *v.NextToken)
	}
}

type GetEnrollmentStatusesForOrganizationOutput struct {

	// An array of objects that describe the enrollment statuses of organization
	// member accounts.
	AccountEnrollmentStatuses []types.AccountEnrollmentStatus

	// The token to use to advance to the next page of account enrollment statuses.
	//
	// This value is null when there are no more pages of account enrollment statuses
	// to return.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *GetEnrollmentStatusesForOrganizationOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetEnrollmentStatusesForOrganizationResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetEnrollmentStatusesForOrganizationOutput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeAccountEnrollmentStatuses(s, schemas.GetEnrollmentStatusesForOrganizationResponse_accountEnrollmentStatuses, v.AccountEnrollmentStatuses)
	if v.NextToken != nil {
		s.WriteString(schemas.GetEnrollmentStatusesForOrganizationResponse_nextToken, *v.NextToken)
	}
}
func (v *GetEnrollmentStatusesForOrganizationOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.GetEnrollmentStatusesForOrganizationResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.GetEnrollmentStatusesForOrganizationResponse_accountEnrollmentStatuses:
			return deserializeAccountEnrollmentStatuses(d, schemas.GetEnrollmentStatusesForOrganizationResponse_accountEnrollmentStatuses, &v.AccountEnrollmentStatuses)
		case schemas.GetEnrollmentStatusesForOrganizationResponse_nextToken:
			v.NextToken = new(string)
			return d.ReadString(schemas.GetEnrollmentStatusesForOrganizationResponse_nextToken, v.NextToken)
		}
		return nil
	})
}
func (c *Client) addOperationGetEnrollmentStatusesForOrganizationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetEnrollmentStatusesForOrganization, schemas.GetEnrollmentStatusesForOrganizationRequest, schemas.GetEnrollmentStatusesForOrganizationResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetEnrollmentStatusesForOrganization, schemas.GetEnrollmentStatusesForOrganizationRequest, schemas.GetEnrollmentStatusesForOrganizationResponse), output: &GetEnrollmentStatusesForOrganizationOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetEnrollmentStatusesForOrganization"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// GetEnrollmentStatusesForOrganizationPaginatorOptions is the paginator options
// for GetEnrollmentStatusesForOrganization
type GetEnrollmentStatusesForOrganizationPaginatorOptions struct {
	// The maximum number of account enrollment statuses to return with a single
	// request. You can specify up to 100 statuses to return with each request.
	//
	// To retrieve the remaining results, make another request with the returned
	// nextToken value.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// GetEnrollmentStatusesForOrganizationPaginator is a paginator for
// GetEnrollmentStatusesForOrganization
type GetEnrollmentStatusesForOrganizationPaginator struct {
	options   GetEnrollmentStatusesForOrganizationPaginatorOptions
	client    GetEnrollmentStatusesForOrganizationAPIClient
	params    *GetEnrollmentStatusesForOrganizationInput
	nextToken *string
	firstPage bool
}

// NewGetEnrollmentStatusesForOrganizationPaginator returns a new
// GetEnrollmentStatusesForOrganizationPaginator
func NewGetEnrollmentStatusesForOrganizationPaginator(client GetEnrollmentStatusesForOrganizationAPIClient, params *GetEnrollmentStatusesForOrganizationInput, optFns ...func(*GetEnrollmentStatusesForOrganizationPaginatorOptions)) *GetEnrollmentStatusesForOrganizationPaginator {
	if params == nil {
		params = &GetEnrollmentStatusesForOrganizationInput{}
	}

	options := GetEnrollmentStatusesForOrganizationPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &GetEnrollmentStatusesForOrganizationPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *GetEnrollmentStatusesForOrganizationPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next GetEnrollmentStatusesForOrganization page.
func (p *GetEnrollmentStatusesForOrganizationPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*GetEnrollmentStatusesForOrganizationOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.GetEnrollmentStatusesForOrganization(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// GetEnrollmentStatusesForOrganizationAPIClient is a client that implements the
// GetEnrollmentStatusesForOrganization operation.
type GetEnrollmentStatusesForOrganizationAPIClient interface {
	GetEnrollmentStatusesForOrganization(context.Context, *GetEnrollmentStatusesForOrganizationInput, ...func(*Options)) (*GetEnrollmentStatusesForOrganizationOutput, error)
}

var _ GetEnrollmentStatusesForOrganizationAPIClient = (*Client)(nil)
