// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type BatchCreateBillScenarioCommitmentModificationErrorCode string

// Enum values for BatchCreateBillScenarioCommitmentModificationErrorCode
const (
	BatchCreateBillScenarioCommitmentModificationErrorCodeConflict            BatchCreateBillScenarioCommitmentModificationErrorCode = "CONFLICT"
	BatchCreateBillScenarioCommitmentModificationErrorCodeInternalServerError BatchCreateBillScenarioCommitmentModificationErrorCode = "INTERNAL_SERVER_ERROR"
	BatchCreateBillScenarioCommitmentModificationErrorCodeInvalidAccount      BatchCreateBillScenarioCommitmentModificationErrorCode = "INVALID_ACCOUNT"
)

// Values returns all known values for
// BatchCreateBillScenarioCommitmentModificationErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchCreateBillScenarioCommitmentModificationErrorCode) Values() []BatchCreateBillScenarioCommitmentModificationErrorCode {
	return []BatchCreateBillScenarioCommitmentModificationErrorCode{
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
		"INVALID_ACCOUNT",
	}
}

type BatchCreateBillScenarioUsageModificationErrorCode string

// Enum values for BatchCreateBillScenarioUsageModificationErrorCode
const (
	BatchCreateBillScenarioUsageModificationErrorCodeBadRequest          BatchCreateBillScenarioUsageModificationErrorCode = "BAD_REQUEST"
	BatchCreateBillScenarioUsageModificationErrorCodeNotFound            BatchCreateBillScenarioUsageModificationErrorCode = "NOT_FOUND"
	BatchCreateBillScenarioUsageModificationErrorCodeConflict            BatchCreateBillScenarioUsageModificationErrorCode = "CONFLICT"
	BatchCreateBillScenarioUsageModificationErrorCodeInternalServerError BatchCreateBillScenarioUsageModificationErrorCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for
// BatchCreateBillScenarioUsageModificationErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchCreateBillScenarioUsageModificationErrorCode) Values() []BatchCreateBillScenarioUsageModificationErrorCode {
	return []BatchCreateBillScenarioUsageModificationErrorCode{
		"BAD_REQUEST",
		"NOT_FOUND",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}

type BatchCreateWorkloadEstimateUsageCode string

// Enum values for BatchCreateWorkloadEstimateUsageCode
const (
	BatchCreateWorkloadEstimateUsageCodeBadRequest          BatchCreateWorkloadEstimateUsageCode = "BAD_REQUEST"
	BatchCreateWorkloadEstimateUsageCodeNotFound            BatchCreateWorkloadEstimateUsageCode = "NOT_FOUND"
	BatchCreateWorkloadEstimateUsageCodeConflict            BatchCreateWorkloadEstimateUsageCode = "CONFLICT"
	BatchCreateWorkloadEstimateUsageCodeInternalServerError BatchCreateWorkloadEstimateUsageCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for BatchCreateWorkloadEstimateUsageCode. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchCreateWorkloadEstimateUsageCode) Values() []BatchCreateWorkloadEstimateUsageCode {
	return []BatchCreateWorkloadEstimateUsageCode{
		"BAD_REQUEST",
		"NOT_FOUND",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}

type BatchDeleteBillScenarioCommitmentModificationErrorCode string

// Enum values for BatchDeleteBillScenarioCommitmentModificationErrorCode
const (
	BatchDeleteBillScenarioCommitmentModificationErrorCodeBadRequest          BatchDeleteBillScenarioCommitmentModificationErrorCode = "BAD_REQUEST"
	BatchDeleteBillScenarioCommitmentModificationErrorCodeConflict            BatchDeleteBillScenarioCommitmentModificationErrorCode = "CONFLICT"
	BatchDeleteBillScenarioCommitmentModificationErrorCodeInternalServerError BatchDeleteBillScenarioCommitmentModificationErrorCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for
// BatchDeleteBillScenarioCommitmentModificationErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchDeleteBillScenarioCommitmentModificationErrorCode) Values() []BatchDeleteBillScenarioCommitmentModificationErrorCode {
	return []BatchDeleteBillScenarioCommitmentModificationErrorCode{
		"BAD_REQUEST",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}

type BatchDeleteBillScenarioUsageModificationErrorCode string

// Enum values for BatchDeleteBillScenarioUsageModificationErrorCode
const (
	BatchDeleteBillScenarioUsageModificationErrorCodeBadRequest          BatchDeleteBillScenarioUsageModificationErrorCode = "BAD_REQUEST"
	BatchDeleteBillScenarioUsageModificationErrorCodeConflict            BatchDeleteBillScenarioUsageModificationErrorCode = "CONFLICT"
	BatchDeleteBillScenarioUsageModificationErrorCodeInternalServerError BatchDeleteBillScenarioUsageModificationErrorCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for
// BatchDeleteBillScenarioUsageModificationErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchDeleteBillScenarioUsageModificationErrorCode) Values() []BatchDeleteBillScenarioUsageModificationErrorCode {
	return []BatchDeleteBillScenarioUsageModificationErrorCode{
		"BAD_REQUEST",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}

type BatchUpdateBillScenarioCommitmentModificationErrorCode string

// Enum values for BatchUpdateBillScenarioCommitmentModificationErrorCode
const (
	BatchUpdateBillScenarioCommitmentModificationErrorCodeBadRequest          BatchUpdateBillScenarioCommitmentModificationErrorCode = "BAD_REQUEST"
	BatchUpdateBillScenarioCommitmentModificationErrorCodeNotFound            BatchUpdateBillScenarioCommitmentModificationErrorCode = "NOT_FOUND"
	BatchUpdateBillScenarioCommitmentModificationErrorCodeConflict            BatchUpdateBillScenarioCommitmentModificationErrorCode = "CONFLICT"
	BatchUpdateBillScenarioCommitmentModificationErrorCodeInternalServerError BatchUpdateBillScenarioCommitmentModificationErrorCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for
// BatchUpdateBillScenarioCommitmentModificationErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchUpdateBillScenarioCommitmentModificationErrorCode) Values() []BatchUpdateBillScenarioCommitmentModificationErrorCode {
	return []BatchUpdateBillScenarioCommitmentModificationErrorCode{
		"BAD_REQUEST",
		"NOT_FOUND",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}

type BatchUpdateBillScenarioUsageModificationErrorCode string

// Enum values for BatchUpdateBillScenarioUsageModificationErrorCode
const (
	BatchUpdateBillScenarioUsageModificationErrorCodeBadRequest          BatchUpdateBillScenarioUsageModificationErrorCode = "BAD_REQUEST"
	BatchUpdateBillScenarioUsageModificationErrorCodeNotFound            BatchUpdateBillScenarioUsageModificationErrorCode = "NOT_FOUND"
	BatchUpdateBillScenarioUsageModificationErrorCodeConflict            BatchUpdateBillScenarioUsageModificationErrorCode = "CONFLICT"
	BatchUpdateBillScenarioUsageModificationErrorCodeInternalServerError BatchUpdateBillScenarioUsageModificationErrorCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for
// BatchUpdateBillScenarioUsageModificationErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchUpdateBillScenarioUsageModificationErrorCode) Values() []BatchUpdateBillScenarioUsageModificationErrorCode {
	return []BatchUpdateBillScenarioUsageModificationErrorCode{
		"BAD_REQUEST",
		"NOT_FOUND",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}

type BillEstimateStatus string

// Enum values for BillEstimateStatus
const (
	BillEstimateStatusInProgress BillEstimateStatus = "IN_PROGRESS"
	BillEstimateStatusComplete   BillEstimateStatus = "COMPLETE"
	BillEstimateStatusFailed     BillEstimateStatus = "FAILED"
)

// Values returns all known values for BillEstimateStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BillEstimateStatus) Values() []BillEstimateStatus {
	return []BillEstimateStatus{
		"IN_PROGRESS",
		"COMPLETE",
		"FAILED",
	}
}

type BillScenarioStatus string

// Enum values for BillScenarioStatus
const (
	BillScenarioStatusReady  BillScenarioStatus = "READY"
	BillScenarioStatusLocked BillScenarioStatus = "LOCKED"
	BillScenarioStatusFailed BillScenarioStatus = "FAILED"
	BillScenarioStatusStale  BillScenarioStatus = "STALE"
)

// Values returns all known values for BillScenarioStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BillScenarioStatus) Values() []BillScenarioStatus {
	return []BillScenarioStatus{
		"READY",
		"LOCKED",
		"FAILED",
		"STALE",
	}
}

type CurrencyCode string

// Enum values for CurrencyCode
const (
	CurrencyCodeUsd CurrencyCode = "USD"
)

// Values returns all known values for CurrencyCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CurrencyCode) Values() []CurrencyCode {
	return []CurrencyCode{
		"USD",
	}
}

type GroupSharingPreferenceEnum string

// Enum values for GroupSharingPreferenceEnum
const (
	GroupSharingPreferenceEnumOpen        GroupSharingPreferenceEnum = "OPEN"
	GroupSharingPreferenceEnumPrioritized GroupSharingPreferenceEnum = "PRIORITIZED"
	GroupSharingPreferenceEnumRestricted  GroupSharingPreferenceEnum = "RESTRICTED"
)

// Values returns all known values for GroupSharingPreferenceEnum. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GroupSharingPreferenceEnum) Values() []GroupSharingPreferenceEnum {
	return []GroupSharingPreferenceEnum{
		"OPEN",
		"PRIORITIZED",
		"RESTRICTED",
	}
}

type ListBillEstimateLineItemsFilterName string

// Enum values for ListBillEstimateLineItemsFilterName
const (
	ListBillEstimateLineItemsFilterNameUsageAccountId ListBillEstimateLineItemsFilterName = "USAGE_ACCOUNT_ID"
	ListBillEstimateLineItemsFilterNameServiceCode    ListBillEstimateLineItemsFilterName = "SERVICE_CODE"
	ListBillEstimateLineItemsFilterNameUsageType      ListBillEstimateLineItemsFilterName = "USAGE_TYPE"
	ListBillEstimateLineItemsFilterNameOperation      ListBillEstimateLineItemsFilterName = "OPERATION"
	ListBillEstimateLineItemsFilterNameLocation       ListBillEstimateLineItemsFilterName = "LOCATION"
	ListBillEstimateLineItemsFilterNameLineItemType   ListBillEstimateLineItemsFilterName = "LINE_ITEM_TYPE"
)

// Values returns all known values for ListBillEstimateLineItemsFilterName. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ListBillEstimateLineItemsFilterName) Values() []ListBillEstimateLineItemsFilterName {
	return []ListBillEstimateLineItemsFilterName{
		"USAGE_ACCOUNT_ID",
		"SERVICE_CODE",
		"USAGE_TYPE",
		"OPERATION",
		"LOCATION",
		"LINE_ITEM_TYPE",
	}
}

type ListBillEstimatesFilterName string

// Enum values for ListBillEstimatesFilterName
const (
	ListBillEstimatesFilterNameStatus ListBillEstimatesFilterName = "STATUS"
	ListBillEstimatesFilterNameName   ListBillEstimatesFilterName = "NAME"
)

// Values returns all known values for ListBillEstimatesFilterName. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ListBillEstimatesFilterName) Values() []ListBillEstimatesFilterName {
	return []ListBillEstimatesFilterName{
		"STATUS",
		"NAME",
	}
}

type ListBillScenariosFilterName string

// Enum values for ListBillScenariosFilterName
const (
	ListBillScenariosFilterNameStatus                 ListBillScenariosFilterName = "STATUS"
	ListBillScenariosFilterNameName                   ListBillScenariosFilterName = "NAME"
	ListBillScenariosFilterNameGroupSharingPreference ListBillScenariosFilterName = "GROUP_SHARING_PREFERENCE"
	ListBillScenariosFilterNameCostCategoryArn        ListBillScenariosFilterName = "COST_CATEGORY_ARN"
)

// Values returns all known values for ListBillScenariosFilterName. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ListBillScenariosFilterName) Values() []ListBillScenariosFilterName {
	return []ListBillScenariosFilterName{
		"STATUS",
		"NAME",
		"GROUP_SHARING_PREFERENCE",
		"COST_CATEGORY_ARN",
	}
}

type ListUsageFilterName string

// Enum values for ListUsageFilterName
const (
	ListUsageFilterNameUsageAccountId           ListUsageFilterName = "USAGE_ACCOUNT_ID"
	ListUsageFilterNameServiceCode              ListUsageFilterName = "SERVICE_CODE"
	ListUsageFilterNameUsageType                ListUsageFilterName = "USAGE_TYPE"
	ListUsageFilterNameOperation                ListUsageFilterName = "OPERATION"
	ListUsageFilterNameLocation                 ListUsageFilterName = "LOCATION"
	ListUsageFilterNameUsageGroup               ListUsageFilterName = "USAGE_GROUP"
	ListUsageFilterNameHistoricalUsageAccountId ListUsageFilterName = "HISTORICAL_USAGE_ACCOUNT_ID"
	ListUsageFilterNameHistoricalServiceCode    ListUsageFilterName = "HISTORICAL_SERVICE_CODE"
	ListUsageFilterNameHistoricalUsageType      ListUsageFilterName = "HISTORICAL_USAGE_TYPE"
	ListUsageFilterNameHistoricalOperation      ListUsageFilterName = "HISTORICAL_OPERATION"
	ListUsageFilterNameHistoricalLocation       ListUsageFilterName = "HISTORICAL_LOCATION"
)

// Values returns all known values for ListUsageFilterName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ListUsageFilterName) Values() []ListUsageFilterName {
	return []ListUsageFilterName{
		"USAGE_ACCOUNT_ID",
		"SERVICE_CODE",
		"USAGE_TYPE",
		"OPERATION",
		"LOCATION",
		"USAGE_GROUP",
		"HISTORICAL_USAGE_ACCOUNT_ID",
		"HISTORICAL_SERVICE_CODE",
		"HISTORICAL_USAGE_TYPE",
		"HISTORICAL_OPERATION",
		"HISTORICAL_LOCATION",
	}
}

type ListWorkloadEstimatesFilterName string

// Enum values for ListWorkloadEstimatesFilterName
const (
	ListWorkloadEstimatesFilterNameStatus ListWorkloadEstimatesFilterName = "STATUS"
	ListWorkloadEstimatesFilterNameName   ListWorkloadEstimatesFilterName = "NAME"
)

// Values returns all known values for ListWorkloadEstimatesFilterName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ListWorkloadEstimatesFilterName) Values() []ListWorkloadEstimatesFilterName {
	return []ListWorkloadEstimatesFilterName{
		"STATUS",
		"NAME",
	}
}

type MatchOption string

// Enum values for MatchOption
const (
	MatchOptionEquals     MatchOption = "EQUALS"
	MatchOptionStartsWith MatchOption = "STARTS_WITH"
	MatchOptionContains   MatchOption = "CONTAINS"
)

// Values returns all known values for MatchOption. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MatchOption) Values() []MatchOption {
	return []MatchOption{
		"EQUALS",
		"STARTS_WITH",
		"CONTAINS",
	}
}

type PurchaseAgreementType string

// Enum values for PurchaseAgreementType
const (
	PurchaseAgreementTypeSavingsPlans     PurchaseAgreementType = "SAVINGS_PLANS"
	PurchaseAgreementTypeReservedInstance PurchaseAgreementType = "RESERVED_INSTANCE"
)

// Values returns all known values for PurchaseAgreementType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PurchaseAgreementType) Values() []PurchaseAgreementType {
	return []PurchaseAgreementType{
		"SAVINGS_PLANS",
		"RESERVED_INSTANCE",
	}
}

type RateType string

// Enum values for RateType
const (
	RateTypeBeforeDiscounts              RateType = "BEFORE_DISCOUNTS"
	RateTypeAfterDiscounts               RateType = "AFTER_DISCOUNTS"
	RateTypeAfterDiscountsAndCommitments RateType = "AFTER_DISCOUNTS_AND_COMMITMENTS"
)

// Values returns all known values for RateType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RateType) Values() []RateType {
	return []RateType{
		"BEFORE_DISCOUNTS",
		"AFTER_DISCOUNTS",
		"AFTER_DISCOUNTS_AND_COMMITMENTS",
	}
}

type ValidationExceptionReason string

// Enum values for ValidationExceptionReason
const (
	ValidationExceptionReasonUnknownOperation         ValidationExceptionReason = "unknownOperation"
	ValidationExceptionReasonCannotParse              ValidationExceptionReason = "cannotParse"
	ValidationExceptionReasonFieldValidationFailed    ValidationExceptionReason = "fieldValidationFailed"
	ValidationExceptionReasonInvalidRequestFromMember ValidationExceptionReason = "invalidRequestFromMember"
	ValidationExceptionReasonDisallowedRate           ValidationExceptionReason = "disallowedRate"
	ValidationExceptionReasonOther                    ValidationExceptionReason = "other"
)

// Values returns all known values for ValidationExceptionReason. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ValidationExceptionReason) Values() []ValidationExceptionReason {
	return []ValidationExceptionReason{
		"unknownOperation",
		"cannotParse",
		"fieldValidationFailed",
		"invalidRequestFromMember",
		"disallowedRate",
		"other",
	}
}

type WorkloadEstimateCostStatus string

// Enum values for WorkloadEstimateCostStatus
const (
	WorkloadEstimateCostStatusValid   WorkloadEstimateCostStatus = "VALID"
	WorkloadEstimateCostStatusInvalid WorkloadEstimateCostStatus = "INVALID"
	WorkloadEstimateCostStatusStale   WorkloadEstimateCostStatus = "STALE"
)

// Values returns all known values for WorkloadEstimateCostStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WorkloadEstimateCostStatus) Values() []WorkloadEstimateCostStatus {
	return []WorkloadEstimateCostStatus{
		"VALID",
		"INVALID",
		"STALE",
	}
}

type WorkloadEstimateRateType string

// Enum values for WorkloadEstimateRateType
const (
	WorkloadEstimateRateTypeBeforeDiscounts              WorkloadEstimateRateType = "BEFORE_DISCOUNTS"
	WorkloadEstimateRateTypeAfterDiscounts               WorkloadEstimateRateType = "AFTER_DISCOUNTS"
	WorkloadEstimateRateTypeAfterDiscountsAndCommitments WorkloadEstimateRateType = "AFTER_DISCOUNTS_AND_COMMITMENTS"
)

// Values returns all known values for WorkloadEstimateRateType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WorkloadEstimateRateType) Values() []WorkloadEstimateRateType {
	return []WorkloadEstimateRateType{
		"BEFORE_DISCOUNTS",
		"AFTER_DISCOUNTS",
		"AFTER_DISCOUNTS_AND_COMMITMENTS",
	}
}

type WorkloadEstimateStatus string

// Enum values for WorkloadEstimateStatus
const (
	WorkloadEstimateStatusUpdating     WorkloadEstimateStatus = "UPDATING"
	WorkloadEstimateStatusValid        WorkloadEstimateStatus = "VALID"
	WorkloadEstimateStatusInvalid      WorkloadEstimateStatus = "INVALID"
	WorkloadEstimateStatusActionNeeded WorkloadEstimateStatus = "ACTION_NEEDED"
)

// Values returns all known values for WorkloadEstimateStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WorkloadEstimateStatus) Values() []WorkloadEstimateStatus {
	return []WorkloadEstimateStatus{
		"UPDATING",
		"VALID",
		"INVALID",
		"ACTION_NEEDED",
	}
}

type WorkloadEstimateUpdateUsageErrorCode string

// Enum values for WorkloadEstimateUpdateUsageErrorCode
const (
	WorkloadEstimateUpdateUsageErrorCodeBadRequest          WorkloadEstimateUpdateUsageErrorCode = "BAD_REQUEST"
	WorkloadEstimateUpdateUsageErrorCodeNotFound            WorkloadEstimateUpdateUsageErrorCode = "NOT_FOUND"
	WorkloadEstimateUpdateUsageErrorCodeConflict            WorkloadEstimateUpdateUsageErrorCode = "CONFLICT"
	WorkloadEstimateUpdateUsageErrorCodeInternalServerError WorkloadEstimateUpdateUsageErrorCode = "INTERNAL_SERVER_ERROR"
)

// Values returns all known values for WorkloadEstimateUpdateUsageErrorCode. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WorkloadEstimateUpdateUsageErrorCode) Values() []WorkloadEstimateUpdateUsageErrorCode {
	return []WorkloadEstimateUpdateUsageErrorCode{
		"BAD_REQUEST",
		"NOT_FOUND",
		"CONFLICT",
		"INTERNAL_SERVER_ERROR",
	}
}
