// Code generated by smithy-go-codegen DO NOT EDIT.

package amplifyuibuilder

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/amplifyuibuilder/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns an existing code generation job.
func (c *Client) GetCodegenJob(ctx context.Context, params *GetCodegenJobInput, optFns ...func(*Options)) (*GetCodegenJobOutput, error) {
	if params == nil {
		params = &GetCodegenJobInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetCodegenJob", params, optFns, c.addOperationGetCodegenJobMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetCodegenJobOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetCodegenJobInput struct {

	// The unique ID of the Amplify app associated with the code generation job.
	//
	// This member is required.
	AppId *string

	// The name of the backend environment that is a part of the Amplify app
	// associated with the code generation job.
	//
	// This member is required.
	EnvironmentName *string

	// The unique ID of the code generation job.
	//
	// This member is required.
	Id *string

	noSmithyDocumentSerde
}

type GetCodegenJobOutput struct {

	// The configuration settings for the code generation job.
	Job *types.CodegenJob

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetCodegenJobMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetCodegenJob{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetCodegenJob{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetCodegenJobValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetCodegenJob"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
