// Code generated by smithy-go-codegen DO NOT EDIT.

package apprunner

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/apprunner/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Create an App Runner VPC Ingress Connection resource. App Runner requires this
// resource when you want to associate your App Runner service with an Amazon VPC
// endpoint.
func (c *Client) CreateVpcIngressConnection(ctx context.Context, params *CreateVpcIngressConnectionInput, optFns ...func(*Options)) (*CreateVpcIngressConnectionOutput, error) {
	if params == nil {
		params = &CreateVpcIngressConnectionInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateVpcIngressConnection", params, optFns, c.addOperationCreateVpcIngressConnectionMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateVpcIngressConnectionOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateVpcIngressConnectionInput struct {

	// Specifications for the customer’s Amazon VPC and the related Amazon Web
	// Services PrivateLink VPC endpoint that are used to create the VPC Ingress
	// Connection resource.
	//
	// This member is required.
	IngressVpcConfiguration *types.IngressVpcConfiguration

	// The Amazon Resource Name (ARN) for this App Runner service that is used to
	// create the VPC Ingress Connection resource.
	//
	// This member is required.
	ServiceArn *string

	// A name for the VPC Ingress Connection resource. It must be unique across all
	// the active VPC Ingress Connections in your Amazon Web Services account in the
	// Amazon Web Services Region.
	//
	// This member is required.
	VpcIngressConnectionName *string

	// An optional list of metadata items that you can associate with the VPC Ingress
	// Connection resource. A tag is a key-value pair.
	Tags []types.Tag

	noSmithyDocumentSerde
}

type CreateVpcIngressConnectionOutput struct {

	// A description of the App Runner VPC Ingress Connection resource that's created
	// by this request.
	//
	// This member is required.
	VpcIngressConnection *types.VpcIngressConnection

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateVpcIngressConnectionMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpCreateVpcIngressConnection{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpCreateVpcIngressConnection{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateVpcIngressConnectionValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateVpcIngressConnection"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
