// Code generated by smithy-go-codegen DO NOT EDIT.

// Package bedrockagentruntime provides the API client, operations, and parameter
// types for Agents for Amazon Bedrock Runtime.
//
// Contains APIs related to model invocation and querying of knowledge bases.
package bedrockagentruntime
