// Code generated by smithy-go-codegen DO NOT EDIT.

package schemas

import (
	smithy "github.com/aws/smithy-go"
	smithyprelude "github.com/aws/smithy-go/prelude"
	smithytraits "github.com/aws/smithy-go/traits"
)

var DescribeEntitiesDetectionV2Job = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeEntitiesDetectionV2Job",
}, smithy.ShapeTypeOperation, 0)

var DescribeICD10CMInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeICD10CMInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var DescribePHIDetectionJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribePHIDetectionJob",
}, smithy.ShapeTypeOperation, 0)

var DescribeRxNormInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeRxNormInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var DescribeSNOMEDCTInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeSNOMEDCTInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var DetectEntities = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectEntities",
}, smithy.ShapeTypeOperation, 0)

var DetectEntitiesV2 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectEntitiesV2",
}, smithy.ShapeTypeOperation, 0)

var DetectPHI = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectPHI",
}, smithy.ShapeTypeOperation, 0)

var InferICD10CM = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferICD10CM",
}, smithy.ShapeTypeOperation, 0)

var InferRxNorm = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferRxNorm",
}, smithy.ShapeTypeOperation, 0)

var InferSNOMEDCT = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferSNOMEDCT",
}, smithy.ShapeTypeOperation, 0)

var ListEntitiesDetectionV2Jobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListEntitiesDetectionV2Jobs",
}, smithy.ShapeTypeOperation, 0)

var ListICD10CMInferenceJobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListICD10CMInferenceJobs",
}, smithy.ShapeTypeOperation, 0)

var ListPHIDetectionJobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListPHIDetectionJobs",
}, smithy.ShapeTypeOperation, 0)

var ListRxNormInferenceJobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListRxNormInferenceJobs",
}, smithy.ShapeTypeOperation, 0)

var ListSNOMEDCTInferenceJobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListSNOMEDCTInferenceJobs",
}, smithy.ShapeTypeOperation, 0)

var StartEntitiesDetectionV2Job = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartEntitiesDetectionV2Job",
}, smithy.ShapeTypeOperation, 0)

var StartICD10CMInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartICD10CMInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var StartPHIDetectionJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartPHIDetectionJob",
}, smithy.ShapeTypeOperation, 0)

var StartRxNormInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartRxNormInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var StartSNOMEDCTInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartSNOMEDCTInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var StopEntitiesDetectionV2Job = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopEntitiesDetectionV2Job",
}, smithy.ShapeTypeOperation, 0)

var StopICD10CMInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopICD10CMInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var StopPHIDetectionJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopPHIDetectionJob",
}, smithy.ShapeTypeOperation, 0)

var StopRxNormInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopRxNormInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var StopSNOMEDCTInferenceJob = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopSNOMEDCTInferenceJob",
}, smithy.ShapeTypeOperation, 0)

var _ComprehendMedical_20181030 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ComprehendMedical_20181030",
}, smithy.ShapeTypeService, 0)

var ComprehendMedical_20181030 = smithy.NewServiceSchema(_ComprehendMedical_20181030, "2018-10-30")

var _AnyLengthString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "AnyLengthString",
}, smithy.ShapeTypeString, 0)

var Attribute = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Attribute",
}, smithy.ShapeTypeStructure, 10)
var Attribute_Type *smithy.Schema

var Attribute_Score *smithy.Schema

var Attribute_RelationshipScore *smithy.Schema

var Attribute_RelationshipType *smithy.Schema

var Attribute_Id *smithy.Schema

var Attribute_BeginOffset *smithy.Schema

var Attribute_EndOffset *smithy.Schema

var Attribute_Text *smithy.Schema

var Attribute_Category *smithy.Schema

var Attribute_Traits *smithy.Schema

var _AttributeList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "AttributeList",
}, smithy.ShapeTypeList, 1)
var _AttributeList_member *smithy.Schema

var AttributeName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "AttributeName",
}, smithy.ShapeTypeEnum, 9)
var AttributeName_SIGN *smithy.Schema

var AttributeName_SYMPTOM *smithy.Schema

var AttributeName_DIAGNOSIS *smithy.Schema

var AttributeName_NEGATION *smithy.Schema

var AttributeName_PERTAINS_TO_FAMILY *smithy.Schema

var AttributeName_HYPOTHETICAL *smithy.Schema

var AttributeName_LOW_CONFIDENCE *smithy.Schema

var AttributeName_PAST_HISTORY *smithy.Schema

var AttributeName_FUTURE *smithy.Schema

var _BoundedLengthString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "BoundedLengthString",
}, smithy.ShapeTypeString, 0)

var Characters = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Characters",
}, smithy.ShapeTypeStructure, 1)
var Characters_OriginalTextCharacters *smithy.Schema

var _ClientRequestTokenString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ClientRequestTokenString",
}, smithy.ShapeTypeString, 0)

var ComprehendMedicalAsyncJobFilter = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ComprehendMedicalAsyncJobFilter",
}, smithy.ShapeTypeStructure, 4)
var ComprehendMedicalAsyncJobFilter_JobName *smithy.Schema

var ComprehendMedicalAsyncJobFilter_JobStatus *smithy.Schema

var ComprehendMedicalAsyncJobFilter_SubmitTimeBefore *smithy.Schema

var ComprehendMedicalAsyncJobFilter_SubmitTimeAfter *smithy.Schema

var ComprehendMedicalAsyncJobProperties = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ComprehendMedicalAsyncJobProperties",
}, smithy.ShapeTypeStructure, 14)
var ComprehendMedicalAsyncJobProperties_JobId *smithy.Schema

var ComprehendMedicalAsyncJobProperties_JobName *smithy.Schema

var ComprehendMedicalAsyncJobProperties_JobStatus *smithy.Schema

var ComprehendMedicalAsyncJobProperties_Message *smithy.Schema

var ComprehendMedicalAsyncJobProperties_SubmitTime *smithy.Schema

var ComprehendMedicalAsyncJobProperties_EndTime *smithy.Schema

var ComprehendMedicalAsyncJobProperties_ExpirationTime *smithy.Schema

var ComprehendMedicalAsyncJobProperties_InputDataConfig *smithy.Schema

var ComprehendMedicalAsyncJobProperties_OutputDataConfig *smithy.Schema

var ComprehendMedicalAsyncJobProperties_LanguageCode *smithy.Schema

var ComprehendMedicalAsyncJobProperties_DataAccessRoleArn *smithy.Schema

var ComprehendMedicalAsyncJobProperties_ManifestFilePath *smithy.Schema

var ComprehendMedicalAsyncJobProperties_KMSKey *smithy.Schema

var ComprehendMedicalAsyncJobProperties_ModelVersion *smithy.Schema

var _ComprehendMedicalAsyncJobPropertiesList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ComprehendMedicalAsyncJobPropertiesList",
}, smithy.ShapeTypeList, 1)
var _ComprehendMedicalAsyncJobPropertiesList_member *smithy.Schema

var Entity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Entity",
}, smithy.ShapeTypeStructure, 9)
var Entity_Id *smithy.Schema

var Entity_BeginOffset *smithy.Schema

var Entity_EndOffset *smithy.Schema

var Entity_Score *smithy.Schema

var Entity_Text *smithy.Schema

var Entity_Category *smithy.Schema

var Entity_Type *smithy.Schema

var Entity_Traits *smithy.Schema

var Entity_Attributes *smithy.Schema

var _EntityList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "EntityList",
}, smithy.ShapeTypeList, 1)
var _EntityList_member *smithy.Schema

var EntitySubType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "EntitySubType",
}, smithy.ShapeTypeEnum, 45)
var EntitySubType_NAME *smithy.Schema

var EntitySubType_DX_NAME *smithy.Schema

var EntitySubType_DOSAGE *smithy.Schema

var EntitySubType_ROUTE_OR_MODE *smithy.Schema

var EntitySubType_FORM *smithy.Schema

var EntitySubType_FREQUENCY *smithy.Schema

var EntitySubType_DURATION *smithy.Schema

var EntitySubType_GENERIC_NAME *smithy.Schema

var EntitySubType_BRAND_NAME *smithy.Schema

var EntitySubType_STRENGTH *smithy.Schema

var EntitySubType_RATE *smithy.Schema

var EntitySubType_ACUITY *smithy.Schema

var EntitySubType_TEST_NAME *smithy.Schema

var EntitySubType_TEST_VALUE *smithy.Schema

var EntitySubType_TEST_UNITS *smithy.Schema

var EntitySubType_TEST_UNIT *smithy.Schema

var EntitySubType_PROCEDURE_NAME *smithy.Schema

var EntitySubType_TREATMENT_NAME *smithy.Schema

var EntitySubType_DATE *smithy.Schema

var EntitySubType_AGE *smithy.Schema

var EntitySubType_CONTACT_POINT *smithy.Schema

var EntitySubType_PHONE_OR_FAX *smithy.Schema

var EntitySubType_EMAIL *smithy.Schema

var EntitySubType_IDENTIFIER *smithy.Schema

var EntitySubType_ID *smithy.Schema

var EntitySubType_URL *smithy.Schema

var EntitySubType_ADDRESS *smithy.Schema

var EntitySubType_PROFESSION *smithy.Schema

var EntitySubType_SYSTEM_ORGAN_SITE *smithy.Schema

var EntitySubType_DIRECTION *smithy.Schema

var EntitySubType_QUALITY *smithy.Schema

var EntitySubType_QUANTITY *smithy.Schema

var EntitySubType_TIME_EXPRESSION *smithy.Schema

var EntitySubType_TIME_TO_MEDICATION_NAME *smithy.Schema

var EntitySubType_TIME_TO_DX_NAME *smithy.Schema

var EntitySubType_TIME_TO_TEST_NAME *smithy.Schema

var EntitySubType_TIME_TO_PROCEDURE_NAME *smithy.Schema

var EntitySubType_TIME_TO_TREATMENT_NAME *smithy.Schema

var EntitySubType_AMOUNT *smithy.Schema

var EntitySubType_GENDER *smithy.Schema

var EntitySubType_RACE_ETHNICITY *smithy.Schema

var EntitySubType_ALLERGIES *smithy.Schema

var EntitySubType_TOBACCO_USE *smithy.Schema

var EntitySubType_ALCOHOL_CONSUMPTION *smithy.Schema

var EntitySubType_REC_DRUG_USE *smithy.Schema

var EntityType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "EntityType",
}, smithy.ShapeTypeEnum, 7)
var EntityType_MEDICATION *smithy.Schema

var EntityType_MEDICAL_CONDITION *smithy.Schema

var EntityType_PROTECTED_HEALTH_INFORMATION *smithy.Schema

var EntityType_TEST_TREATMENT_PROCEDURE *smithy.Schema

var EntityType_ANATOMY *smithy.Schema

var EntityType_TIME_EXPRESSION *smithy.Schema

var EntityType_BEHAVIORAL_ENVIRONMENTAL_SOCIAL *smithy.Schema

var _Float = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Float",
}, smithy.ShapeTypeFloat, 0)

var _IamRoleArn = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "IamRoleArn",
}, smithy.ShapeTypeString, 0)

var ICD10CMAttribute = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMAttribute",
}, smithy.ShapeTypeStructure, 10)
var ICD10CMAttribute_Type *smithy.Schema

var ICD10CMAttribute_Score *smithy.Schema

var ICD10CMAttribute_RelationshipScore *smithy.Schema

var ICD10CMAttribute_Id *smithy.Schema

var ICD10CMAttribute_BeginOffset *smithy.Schema

var ICD10CMAttribute_EndOffset *smithy.Schema

var ICD10CMAttribute_Text *smithy.Schema

var ICD10CMAttribute_Traits *smithy.Schema

var ICD10CMAttribute_Category *smithy.Schema

var ICD10CMAttribute_RelationshipType *smithy.Schema

var _ICD10CMAttributeList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMAttributeList",
}, smithy.ShapeTypeList, 1)
var _ICD10CMAttributeList_member *smithy.Schema

var ICD10CMAttributeType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMAttributeType",
}, smithy.ShapeTypeEnum, 7)
var ICD10CMAttributeType_ACUITY *smithy.Schema

var ICD10CMAttributeType_DIRECTION *smithy.Schema

var ICD10CMAttributeType_SYSTEM_ORGAN_SITE *smithy.Schema

var ICD10CMAttributeType_QUALITY *smithy.Schema

var ICD10CMAttributeType_QUANTITY *smithy.Schema

var ICD10CMAttributeType_TIME_TO_DX_NAME *smithy.Schema

var ICD10CMAttributeType_TIME_EXPRESSION *smithy.Schema

var ICD10CMConcept = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMConcept",
}, smithy.ShapeTypeStructure, 3)
var ICD10CMConcept_Description *smithy.Schema

var ICD10CMConcept_Code *smithy.Schema

var ICD10CMConcept_Score *smithy.Schema

var _ICD10CMConceptList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMConceptList",
}, smithy.ShapeTypeList, 1)
var _ICD10CMConceptList_member *smithy.Schema

var ICD10CMEntity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMEntity",
}, smithy.ShapeTypeStructure, 10)
var ICD10CMEntity_Id *smithy.Schema

var ICD10CMEntity_Text *smithy.Schema

var ICD10CMEntity_Category *smithy.Schema

var ICD10CMEntity_Type *smithy.Schema

var ICD10CMEntity_Score *smithy.Schema

var ICD10CMEntity_BeginOffset *smithy.Schema

var ICD10CMEntity_EndOffset *smithy.Schema

var ICD10CMEntity_Attributes *smithy.Schema

var ICD10CMEntity_Traits *smithy.Schema

var ICD10CMEntity_ICD10CMConcepts *smithy.Schema

var ICD10CMEntityCategory = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMEntityCategory",
}, smithy.ShapeTypeEnum, 1)
var ICD10CMEntityCategory_MEDICAL_CONDITION *smithy.Schema

var _ICD10CMEntityList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMEntityList",
}, smithy.ShapeTypeList, 1)
var _ICD10CMEntityList_member *smithy.Schema

var ICD10CMEntityType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMEntityType",
}, smithy.ShapeTypeEnum, 2)
var ICD10CMEntityType_DX_NAME *smithy.Schema

var ICD10CMEntityType_TIME_EXPRESSION *smithy.Schema

var ICD10CMRelationshipType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMRelationshipType",
}, smithy.ShapeTypeEnum, 3)
var ICD10CMRelationshipType_OVERLAP *smithy.Schema

var ICD10CMRelationshipType_SYSTEM_ORGAN_SITE *smithy.Schema

var ICD10CMRelationshipType_QUALITY *smithy.Schema

var ICD10CMTrait = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMTrait",
}, smithy.ShapeTypeStructure, 2)
var ICD10CMTrait_Name *smithy.Schema

var ICD10CMTrait_Score *smithy.Schema

var _ICD10CMTraitList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMTraitList",
}, smithy.ShapeTypeList, 1)
var _ICD10CMTraitList_member *smithy.Schema

var ICD10CMTraitName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ICD10CMTraitName",
}, smithy.ShapeTypeEnum, 7)
var ICD10CMTraitName_NEGATION *smithy.Schema

var ICD10CMTraitName_DIAGNOSIS *smithy.Schema

var ICD10CMTraitName_SIGN *smithy.Schema

var ICD10CMTraitName_SYMPTOM *smithy.Schema

var ICD10CMTraitName_PERTAINS_TO_FAMILY *smithy.Schema

var ICD10CMTraitName_HYPOTHETICAL *smithy.Schema

var ICD10CMTraitName_LOW_CONFIDENCE *smithy.Schema

var InputDataConfig = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InputDataConfig",
}, smithy.ShapeTypeStructure, 2)
var InputDataConfig_S3Bucket *smithy.Schema

var InputDataConfig_S3Key *smithy.Schema

var _Integer = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Integer",
}, smithy.ShapeTypeInteger, 0)

var InternalServerException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InternalServerException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 500})
var InternalServerException_Message *smithy.Schema

var InvalidEncodingException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InvalidEncodingException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var InvalidEncodingException_Message *smithy.Schema

var InvalidRequestException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InvalidRequestException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var InvalidRequestException_Message *smithy.Schema

var _JobId = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "JobId",
}, smithy.ShapeTypeString, 0)

var _JobName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "JobName",
}, smithy.ShapeTypeString, 0)

var JobStatus = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "JobStatus",
}, smithy.ShapeTypeEnum, 7)
var JobStatus_SUBMITTED *smithy.Schema

var JobStatus_IN_PROGRESS *smithy.Schema

var JobStatus_COMPLETED *smithy.Schema

var JobStatus_PARTIAL_SUCCESS *smithy.Schema

var JobStatus_FAILED *smithy.Schema

var JobStatus_STOP_REQUESTED *smithy.Schema

var JobStatus_STOPPED *smithy.Schema

var _KMSKey = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "KMSKey",
}, smithy.ShapeTypeString, 0)

var LanguageCode = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "LanguageCode",
}, smithy.ShapeTypeEnum, 1)
var LanguageCode_EN *smithy.Schema

var _ManifestFilePath = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ManifestFilePath",
}, smithy.ShapeTypeString, 0)

var _MaxResultsInteger = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "MaxResultsInteger",
}, smithy.ShapeTypeInteger, 0)

var _ModelVersion = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ModelVersion",
}, smithy.ShapeTypeString, 0)

var _OntologyLinkingBoundedLengthString = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "OntologyLinkingBoundedLengthString",
}, smithy.ShapeTypeString, 0)

var OutputDataConfig = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "OutputDataConfig",
}, smithy.ShapeTypeStructure, 2)
var OutputDataConfig_S3Bucket *smithy.Schema

var OutputDataConfig_S3Key *smithy.Schema

var RelationshipType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RelationshipType",
}, smithy.ShapeTypeEnum, 22)
var RelationshipType_EVERY *smithy.Schema

var RelationshipType_WITH_DOSAGE *smithy.Schema

var RelationshipType_ADMINISTERED_VIA *smithy.Schema

var RelationshipType_FOR *smithy.Schema

var RelationshipType_NEGATIVE *smithy.Schema

var RelationshipType_OVERLAP *smithy.Schema

var RelationshipType_DOSAGE *smithy.Schema

var RelationshipType_ROUTE_OR_MODE *smithy.Schema

var RelationshipType_FORM *smithy.Schema

var RelationshipType_FREQUENCY *smithy.Schema

var RelationshipType_DURATION *smithy.Schema

var RelationshipType_STRENGTH *smithy.Schema

var RelationshipType_RATE *smithy.Schema

var RelationshipType_ACUITY *smithy.Schema

var RelationshipType_TEST_VALUE *smithy.Schema

var RelationshipType_TEST_UNITS *smithy.Schema

var RelationshipType_TEST_UNIT *smithy.Schema

var RelationshipType_DIRECTION *smithy.Schema

var RelationshipType_SYSTEM_ORGAN_SITE *smithy.Schema

var RelationshipType_AMOUNT *smithy.Schema

var RelationshipType_USAGE *smithy.Schema

var RelationshipType_QUALITY *smithy.Schema

var ResourceNotFoundException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ResourceNotFoundException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 404})
var ResourceNotFoundException_Message *smithy.Schema

var RxNormAttribute = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormAttribute",
}, smithy.ShapeTypeStructure, 8)
var RxNormAttribute_Type *smithy.Schema

var RxNormAttribute_Score *smithy.Schema

var RxNormAttribute_RelationshipScore *smithy.Schema

var RxNormAttribute_Id *smithy.Schema

var RxNormAttribute_BeginOffset *smithy.Schema

var RxNormAttribute_EndOffset *smithy.Schema

var RxNormAttribute_Text *smithy.Schema

var RxNormAttribute_Traits *smithy.Schema

var _RxNormAttributeList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormAttributeList",
}, smithy.ShapeTypeList, 1)
var _RxNormAttributeList_member *smithy.Schema

var RxNormAttributeType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormAttributeType",
}, smithy.ShapeTypeEnum, 7)
var RxNormAttributeType_DOSAGE *smithy.Schema

var RxNormAttributeType_DURATION *smithy.Schema

var RxNormAttributeType_FORM *smithy.Schema

var RxNormAttributeType_FREQUENCY *smithy.Schema

var RxNormAttributeType_RATE *smithy.Schema

var RxNormAttributeType_ROUTE_OR_MODE *smithy.Schema

var RxNormAttributeType_STRENGTH *smithy.Schema

var RxNormConcept = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormConcept",
}, smithy.ShapeTypeStructure, 3)
var RxNormConcept_Description *smithy.Schema

var RxNormConcept_Code *smithy.Schema

var RxNormConcept_Score *smithy.Schema

var _RxNormConceptList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormConceptList",
}, smithy.ShapeTypeList, 1)
var _RxNormConceptList_member *smithy.Schema

var RxNormEntity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormEntity",
}, smithy.ShapeTypeStructure, 10)
var RxNormEntity_Id *smithy.Schema

var RxNormEntity_Text *smithy.Schema

var RxNormEntity_Category *smithy.Schema

var RxNormEntity_Type *smithy.Schema

var RxNormEntity_Score *smithy.Schema

var RxNormEntity_BeginOffset *smithy.Schema

var RxNormEntity_EndOffset *smithy.Schema

var RxNormEntity_Attributes *smithy.Schema

var RxNormEntity_Traits *smithy.Schema

var RxNormEntity_RxNormConcepts *smithy.Schema

var RxNormEntityCategory = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormEntityCategory",
}, smithy.ShapeTypeEnum, 1)
var RxNormEntityCategory_MEDICATION *smithy.Schema

var _RxNormEntityList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormEntityList",
}, smithy.ShapeTypeList, 1)
var _RxNormEntityList_member *smithy.Schema

var RxNormEntityType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormEntityType",
}, smithy.ShapeTypeEnum, 2)
var RxNormEntityType_BRAND_NAME *smithy.Schema

var RxNormEntityType_GENERIC_NAME *smithy.Schema

var RxNormTrait = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormTrait",
}, smithy.ShapeTypeStructure, 2)
var RxNormTrait_Name *smithy.Schema

var RxNormTrait_Score *smithy.Schema

var _RxNormTraitList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormTraitList",
}, smithy.ShapeTypeList, 1)
var _RxNormTraitList_member *smithy.Schema

var RxNormTraitName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "RxNormTraitName",
}, smithy.ShapeTypeEnum, 2)
var RxNormTraitName_NEGATION *smithy.Schema

var RxNormTraitName_PAST_HISTORY *smithy.Schema

var _S3Bucket = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "S3Bucket",
}, smithy.ShapeTypeString, 0)

var _S3Key = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "S3Key",
}, smithy.ShapeTypeString, 0)

var ServiceUnavailableException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ServiceUnavailableException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 503})
var ServiceUnavailableException_Message *smithy.Schema

var SNOMEDCTAttribute = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTAttribute",
}, smithy.ShapeTypeStructure, 11)
var SNOMEDCTAttribute_Category *smithy.Schema

var SNOMEDCTAttribute_Type *smithy.Schema

var SNOMEDCTAttribute_Score *smithy.Schema

var SNOMEDCTAttribute_RelationshipScore *smithy.Schema

var SNOMEDCTAttribute_RelationshipType *smithy.Schema

var SNOMEDCTAttribute_Id *smithy.Schema

var SNOMEDCTAttribute_BeginOffset *smithy.Schema

var SNOMEDCTAttribute_EndOffset *smithy.Schema

var SNOMEDCTAttribute_Text *smithy.Schema

var SNOMEDCTAttribute_Traits *smithy.Schema

var SNOMEDCTAttribute_SNOMEDCTConcepts *smithy.Schema

var _SNOMEDCTAttributeList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTAttributeList",
}, smithy.ShapeTypeList, 1)
var _SNOMEDCTAttributeList_member *smithy.Schema

var SNOMEDCTAttributeType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTAttributeType",
}, smithy.ShapeTypeEnum, 6)
var SNOMEDCTAttributeType_ACUITY *smithy.Schema

var SNOMEDCTAttributeType_QUALITY *smithy.Schema

var SNOMEDCTAttributeType_DIRECTION *smithy.Schema

var SNOMEDCTAttributeType_SYSTEM_ORGAN_SITE *smithy.Schema

var SNOMEDCTAttributeType_TEST_VALUE *smithy.Schema

var SNOMEDCTAttributeType_TEST_UNIT *smithy.Schema

var SNOMEDCTConcept = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTConcept",
}, smithy.ShapeTypeStructure, 3)
var SNOMEDCTConcept_Description *smithy.Schema

var SNOMEDCTConcept_Code *smithy.Schema

var SNOMEDCTConcept_Score *smithy.Schema

var _SNOMEDCTConceptList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTConceptList",
}, smithy.ShapeTypeList, 1)
var _SNOMEDCTConceptList_member *smithy.Schema

var SNOMEDCTDetails = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTDetails",
}, smithy.ShapeTypeStructure, 3)
var SNOMEDCTDetails_Edition *smithy.Schema

var SNOMEDCTDetails_Language *smithy.Schema

var SNOMEDCTDetails_VersionDate *smithy.Schema

var SNOMEDCTEntity = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTEntity",
}, smithy.ShapeTypeStructure, 10)
var SNOMEDCTEntity_Id *smithy.Schema

var SNOMEDCTEntity_Text *smithy.Schema

var SNOMEDCTEntity_Category *smithy.Schema

var SNOMEDCTEntity_Type *smithy.Schema

var SNOMEDCTEntity_Score *smithy.Schema

var SNOMEDCTEntity_BeginOffset *smithy.Schema

var SNOMEDCTEntity_EndOffset *smithy.Schema

var SNOMEDCTEntity_Attributes *smithy.Schema

var SNOMEDCTEntity_Traits *smithy.Schema

var SNOMEDCTEntity_SNOMEDCTConcepts *smithy.Schema

var SNOMEDCTEntityCategory = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTEntityCategory",
}, smithy.ShapeTypeEnum, 3)
var SNOMEDCTEntityCategory_MEDICAL_CONDITION *smithy.Schema

var SNOMEDCTEntityCategory_ANATOMY *smithy.Schema

var SNOMEDCTEntityCategory_TEST_TREATMENT_PROCEDURE *smithy.Schema

var _SNOMEDCTEntityList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTEntityList",
}, smithy.ShapeTypeList, 1)
var _SNOMEDCTEntityList_member *smithy.Schema

var SNOMEDCTEntityType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTEntityType",
}, smithy.ShapeTypeEnum, 4)
var SNOMEDCTEntityType_DX_NAME *smithy.Schema

var SNOMEDCTEntityType_TEST_NAME *smithy.Schema

var SNOMEDCTEntityType_PROCEDURE_NAME *smithy.Schema

var SNOMEDCTEntityType_TREATMENT_NAME *smithy.Schema

var SNOMEDCTRelationshipType = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTRelationshipType",
}, smithy.ShapeTypeEnum, 7)
var SNOMEDCTRelationshipType_ACUITY *smithy.Schema

var SNOMEDCTRelationshipType_QUALITY *smithy.Schema

var SNOMEDCTRelationshipType_TEST_VALUE *smithy.Schema

var SNOMEDCTRelationshipType_TEST_UNITS *smithy.Schema

var SNOMEDCTRelationshipType_DIRECTION *smithy.Schema

var SNOMEDCTRelationshipType_SYSTEM_ORGAN_SITE *smithy.Schema

var SNOMEDCTRelationshipType_TEST_UNIT *smithy.Schema

var SNOMEDCTTrait = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTTrait",
}, smithy.ShapeTypeStructure, 2)
var SNOMEDCTTrait_Name *smithy.Schema

var SNOMEDCTTrait_Score *smithy.Schema

var _SNOMEDCTTraitList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTTraitList",
}, smithy.ShapeTypeList, 1)
var _SNOMEDCTTraitList_member *smithy.Schema

var SNOMEDCTTraitName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "SNOMEDCTTraitName",
}, smithy.ShapeTypeEnum, 9)
var SNOMEDCTTraitName_NEGATION *smithy.Schema

var SNOMEDCTTraitName_DIAGNOSIS *smithy.Schema

var SNOMEDCTTraitName_SIGN *smithy.Schema

var SNOMEDCTTraitName_SYMPTOM *smithy.Schema

var SNOMEDCTTraitName_PERTAINS_TO_FAMILY *smithy.Schema

var SNOMEDCTTraitName_HYPOTHETICAL *smithy.Schema

var SNOMEDCTTraitName_LOW_CONFIDENCE *smithy.Schema

var SNOMEDCTTraitName_PAST_HISTORY *smithy.Schema

var SNOMEDCTTraitName_FUTURE *smithy.Schema

var _String = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "String",
}, smithy.ShapeTypeString, 0)

var TextSizeLimitExceededException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "TextSizeLimitExceededException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var TextSizeLimitExceededException_Message *smithy.Schema

var _Timestamp = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Timestamp",
}, smithy.ShapeTypeTimestamp, 0)

var TooManyRequestsException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "TooManyRequestsException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 429})
var TooManyRequestsException_Message *smithy.Schema

var Trait = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "Trait",
}, smithy.ShapeTypeStructure, 2)
var Trait_Name *smithy.Schema

var Trait_Score *smithy.Schema

var _TraitList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "TraitList",
}, smithy.ShapeTypeList, 1)
var _TraitList_member *smithy.Schema

var UnmappedAttribute = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "UnmappedAttribute",
}, smithy.ShapeTypeStructure, 2)
var UnmappedAttribute_Type *smithy.Schema

var UnmappedAttribute_Attribute *smithy.Schema

var _UnmappedAttributeList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "UnmappedAttributeList",
}, smithy.ShapeTypeList, 1)
var _UnmappedAttributeList_member *smithy.Schema

var ValidationException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ValidationException",
}, smithy.ShapeTypeStructure, 1, &smithytraits.HTTPError{Code: 400})
var ValidationException_Message *smithy.Schema

var DescribeEntitiesDetectionV2JobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeEntitiesDetectionV2JobRequest",
}, smithy.ShapeTypeStructure, 1)
var DescribeEntitiesDetectionV2JobRequest_JobId *smithy.Schema

var DescribeEntitiesDetectionV2JobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeEntitiesDetectionV2JobResponse",
}, smithy.ShapeTypeStructure, 1)
var DescribeEntitiesDetectionV2JobResponse_ComprehendMedicalAsyncJobProperties *smithy.Schema

var DescribeICD10CMInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeICD10CMInferenceJobRequest",
}, smithy.ShapeTypeStructure, 1)
var DescribeICD10CMInferenceJobRequest_JobId *smithy.Schema

var DescribeICD10CMInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeICD10CMInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var DescribeICD10CMInferenceJobResponse_ComprehendMedicalAsyncJobProperties *smithy.Schema

var DescribePHIDetectionJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribePHIDetectionJobRequest",
}, smithy.ShapeTypeStructure, 1)
var DescribePHIDetectionJobRequest_JobId *smithy.Schema

var DescribePHIDetectionJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribePHIDetectionJobResponse",
}, smithy.ShapeTypeStructure, 1)
var DescribePHIDetectionJobResponse_ComprehendMedicalAsyncJobProperties *smithy.Schema

var DescribeRxNormInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeRxNormInferenceJobRequest",
}, smithy.ShapeTypeStructure, 1)
var DescribeRxNormInferenceJobRequest_JobId *smithy.Schema

var DescribeRxNormInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeRxNormInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var DescribeRxNormInferenceJobResponse_ComprehendMedicalAsyncJobProperties *smithy.Schema

var DescribeSNOMEDCTInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeSNOMEDCTInferenceJobRequest",
}, smithy.ShapeTypeStructure, 1)
var DescribeSNOMEDCTInferenceJobRequest_JobId *smithy.Schema

var DescribeSNOMEDCTInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DescribeSNOMEDCTInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var DescribeSNOMEDCTInferenceJobResponse_ComprehendMedicalAsyncJobProperties *smithy.Schema

var DetectEntitiesRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectEntitiesRequest",
}, smithy.ShapeTypeStructure, 1)
var DetectEntitiesRequest_Text *smithy.Schema

var DetectEntitiesResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectEntitiesResponse",
}, smithy.ShapeTypeStructure, 4)
var DetectEntitiesResponse_Entities *smithy.Schema

var DetectEntitiesResponse_UnmappedAttributes *smithy.Schema

var DetectEntitiesResponse_PaginationToken *smithy.Schema

var DetectEntitiesResponse_ModelVersion *smithy.Schema

var DetectEntitiesV2Request = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectEntitiesV2Request",
}, smithy.ShapeTypeStructure, 1)
var DetectEntitiesV2Request_Text *smithy.Schema

var DetectEntitiesV2Response = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectEntitiesV2Response",
}, smithy.ShapeTypeStructure, 4)
var DetectEntitiesV2Response_Entities *smithy.Schema

var DetectEntitiesV2Response_UnmappedAttributes *smithy.Schema

var DetectEntitiesV2Response_PaginationToken *smithy.Schema

var DetectEntitiesV2Response_ModelVersion *smithy.Schema

var DetectPHIRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectPHIRequest",
}, smithy.ShapeTypeStructure, 1)
var DetectPHIRequest_Text *smithy.Schema

var DetectPHIResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "DetectPHIResponse",
}, smithy.ShapeTypeStructure, 3)
var DetectPHIResponse_Entities *smithy.Schema

var DetectPHIResponse_PaginationToken *smithy.Schema

var DetectPHIResponse_ModelVersion *smithy.Schema

var InferICD10CMRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferICD10CMRequest",
}, smithy.ShapeTypeStructure, 1)
var InferICD10CMRequest_Text *smithy.Schema

var InferICD10CMResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferICD10CMResponse",
}, smithy.ShapeTypeStructure, 3)
var InferICD10CMResponse_Entities *smithy.Schema

var InferICD10CMResponse_PaginationToken *smithy.Schema

var InferICD10CMResponse_ModelVersion *smithy.Schema

var InferRxNormRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferRxNormRequest",
}, smithy.ShapeTypeStructure, 1)
var InferRxNormRequest_Text *smithy.Schema

var InferRxNormResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferRxNormResponse",
}, smithy.ShapeTypeStructure, 3)
var InferRxNormResponse_Entities *smithy.Schema

var InferRxNormResponse_PaginationToken *smithy.Schema

var InferRxNormResponse_ModelVersion *smithy.Schema

var InferSNOMEDCTRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferSNOMEDCTRequest",
}, smithy.ShapeTypeStructure, 1)
var InferSNOMEDCTRequest_Text *smithy.Schema

var InferSNOMEDCTResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "InferSNOMEDCTResponse",
}, smithy.ShapeTypeStructure, 5)
var InferSNOMEDCTResponse_Entities *smithy.Schema

var InferSNOMEDCTResponse_PaginationToken *smithy.Schema

var InferSNOMEDCTResponse_ModelVersion *smithy.Schema

var InferSNOMEDCTResponse_SNOMEDCTDetails *smithy.Schema

var InferSNOMEDCTResponse_Characters *smithy.Schema

var ListEntitiesDetectionV2JobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListEntitiesDetectionV2JobsRequest",
}, smithy.ShapeTypeStructure, 3)
var ListEntitiesDetectionV2JobsRequest_Filter *smithy.Schema

var ListEntitiesDetectionV2JobsRequest_NextToken *smithy.Schema

var ListEntitiesDetectionV2JobsRequest_MaxResults *smithy.Schema

var ListEntitiesDetectionV2JobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListEntitiesDetectionV2JobsResponse",
}, smithy.ShapeTypeStructure, 2)
var ListEntitiesDetectionV2JobsResponse_ComprehendMedicalAsyncJobPropertiesList *smithy.Schema

var ListEntitiesDetectionV2JobsResponse_NextToken *smithy.Schema

var ListICD10CMInferenceJobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListICD10CMInferenceJobsRequest",
}, smithy.ShapeTypeStructure, 3)
var ListICD10CMInferenceJobsRequest_Filter *smithy.Schema

var ListICD10CMInferenceJobsRequest_NextToken *smithy.Schema

var ListICD10CMInferenceJobsRequest_MaxResults *smithy.Schema

var ListICD10CMInferenceJobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListICD10CMInferenceJobsResponse",
}, smithy.ShapeTypeStructure, 2)
var ListICD10CMInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList *smithy.Schema

var ListICD10CMInferenceJobsResponse_NextToken *smithy.Schema

var ListPHIDetectionJobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListPHIDetectionJobsRequest",
}, smithy.ShapeTypeStructure, 3)
var ListPHIDetectionJobsRequest_Filter *smithy.Schema

var ListPHIDetectionJobsRequest_NextToken *smithy.Schema

var ListPHIDetectionJobsRequest_MaxResults *smithy.Schema

var ListPHIDetectionJobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListPHIDetectionJobsResponse",
}, smithy.ShapeTypeStructure, 2)
var ListPHIDetectionJobsResponse_ComprehendMedicalAsyncJobPropertiesList *smithy.Schema

var ListPHIDetectionJobsResponse_NextToken *smithy.Schema

var ListRxNormInferenceJobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListRxNormInferenceJobsRequest",
}, smithy.ShapeTypeStructure, 3)
var ListRxNormInferenceJobsRequest_Filter *smithy.Schema

var ListRxNormInferenceJobsRequest_NextToken *smithy.Schema

var ListRxNormInferenceJobsRequest_MaxResults *smithy.Schema

var ListRxNormInferenceJobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListRxNormInferenceJobsResponse",
}, smithy.ShapeTypeStructure, 2)
var ListRxNormInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList *smithy.Schema

var ListRxNormInferenceJobsResponse_NextToken *smithy.Schema

var ListSNOMEDCTInferenceJobsRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListSNOMEDCTInferenceJobsRequest",
}, smithy.ShapeTypeStructure, 3)
var ListSNOMEDCTInferenceJobsRequest_Filter *smithy.Schema

var ListSNOMEDCTInferenceJobsRequest_NextToken *smithy.Schema

var ListSNOMEDCTInferenceJobsRequest_MaxResults *smithy.Schema

var ListSNOMEDCTInferenceJobsResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "ListSNOMEDCTInferenceJobsResponse",
}, smithy.ShapeTypeStructure, 2)
var ListSNOMEDCTInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList *smithy.Schema

var ListSNOMEDCTInferenceJobsResponse_NextToken *smithy.Schema

var StartEntitiesDetectionV2JobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartEntitiesDetectionV2JobRequest",
}, smithy.ShapeTypeStructure, 7)
var StartEntitiesDetectionV2JobRequest_InputDataConfig *smithy.Schema

var StartEntitiesDetectionV2JobRequest_OutputDataConfig *smithy.Schema

var StartEntitiesDetectionV2JobRequest_DataAccessRoleArn *smithy.Schema

var StartEntitiesDetectionV2JobRequest_JobName *smithy.Schema

var StartEntitiesDetectionV2JobRequest_ClientRequestToken *smithy.Schema

var StartEntitiesDetectionV2JobRequest_KMSKey *smithy.Schema

var StartEntitiesDetectionV2JobRequest_LanguageCode *smithy.Schema

var StartEntitiesDetectionV2JobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartEntitiesDetectionV2JobResponse",
}, smithy.ShapeTypeStructure, 1)
var StartEntitiesDetectionV2JobResponse_JobId *smithy.Schema

var StartICD10CMInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartICD10CMInferenceJobRequest",
}, smithy.ShapeTypeStructure, 7)
var StartICD10CMInferenceJobRequest_InputDataConfig *smithy.Schema

var StartICD10CMInferenceJobRequest_OutputDataConfig *smithy.Schema

var StartICD10CMInferenceJobRequest_DataAccessRoleArn *smithy.Schema

var StartICD10CMInferenceJobRequest_JobName *smithy.Schema

var StartICD10CMInferenceJobRequest_ClientRequestToken *smithy.Schema

var StartICD10CMInferenceJobRequest_KMSKey *smithy.Schema

var StartICD10CMInferenceJobRequest_LanguageCode *smithy.Schema

var StartICD10CMInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartICD10CMInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StartICD10CMInferenceJobResponse_JobId *smithy.Schema

var StartPHIDetectionJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartPHIDetectionJobRequest",
}, smithy.ShapeTypeStructure, 7)
var StartPHIDetectionJobRequest_InputDataConfig *smithy.Schema

var StartPHIDetectionJobRequest_OutputDataConfig *smithy.Schema

var StartPHIDetectionJobRequest_DataAccessRoleArn *smithy.Schema

var StartPHIDetectionJobRequest_JobName *smithy.Schema

var StartPHIDetectionJobRequest_ClientRequestToken *smithy.Schema

var StartPHIDetectionJobRequest_KMSKey *smithy.Schema

var StartPHIDetectionJobRequest_LanguageCode *smithy.Schema

var StartPHIDetectionJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartPHIDetectionJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StartPHIDetectionJobResponse_JobId *smithy.Schema

var StartRxNormInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartRxNormInferenceJobRequest",
}, smithy.ShapeTypeStructure, 7)
var StartRxNormInferenceJobRequest_InputDataConfig *smithy.Schema

var StartRxNormInferenceJobRequest_OutputDataConfig *smithy.Schema

var StartRxNormInferenceJobRequest_DataAccessRoleArn *smithy.Schema

var StartRxNormInferenceJobRequest_JobName *smithy.Schema

var StartRxNormInferenceJobRequest_ClientRequestToken *smithy.Schema

var StartRxNormInferenceJobRequest_KMSKey *smithy.Schema

var StartRxNormInferenceJobRequest_LanguageCode *smithy.Schema

var StartRxNormInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartRxNormInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StartRxNormInferenceJobResponse_JobId *smithy.Schema

var StartSNOMEDCTInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartSNOMEDCTInferenceJobRequest",
}, smithy.ShapeTypeStructure, 7)
var StartSNOMEDCTInferenceJobRequest_InputDataConfig *smithy.Schema

var StartSNOMEDCTInferenceJobRequest_OutputDataConfig *smithy.Schema

var StartSNOMEDCTInferenceJobRequest_DataAccessRoleArn *smithy.Schema

var StartSNOMEDCTInferenceJobRequest_JobName *smithy.Schema

var StartSNOMEDCTInferenceJobRequest_ClientRequestToken *smithy.Schema

var StartSNOMEDCTInferenceJobRequest_KMSKey *smithy.Schema

var StartSNOMEDCTInferenceJobRequest_LanguageCode *smithy.Schema

var StartSNOMEDCTInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StartSNOMEDCTInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StartSNOMEDCTInferenceJobResponse_JobId *smithy.Schema

var StopEntitiesDetectionV2JobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopEntitiesDetectionV2JobRequest",
}, smithy.ShapeTypeStructure, 1)
var StopEntitiesDetectionV2JobRequest_JobId *smithy.Schema

var StopEntitiesDetectionV2JobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopEntitiesDetectionV2JobResponse",
}, smithy.ShapeTypeStructure, 1)
var StopEntitiesDetectionV2JobResponse_JobId *smithy.Schema

var StopICD10CMInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopICD10CMInferenceJobRequest",
}, smithy.ShapeTypeStructure, 1)
var StopICD10CMInferenceJobRequest_JobId *smithy.Schema

var StopICD10CMInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopICD10CMInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StopICD10CMInferenceJobResponse_JobId *smithy.Schema

var StopPHIDetectionJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopPHIDetectionJobRequest",
}, smithy.ShapeTypeStructure, 1)
var StopPHIDetectionJobRequest_JobId *smithy.Schema

var StopPHIDetectionJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopPHIDetectionJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StopPHIDetectionJobResponse_JobId *smithy.Schema

var StopRxNormInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopRxNormInferenceJobRequest",
}, smithy.ShapeTypeStructure, 1)
var StopRxNormInferenceJobRequest_JobId *smithy.Schema

var StopRxNormInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopRxNormInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StopRxNormInferenceJobResponse_JobId *smithy.Schema

var StopSNOMEDCTInferenceJobRequest = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopSNOMEDCTInferenceJobRequest",
}, smithy.ShapeTypeStructure, 1)
var StopSNOMEDCTInferenceJobRequest_JobId *smithy.Schema

var StopSNOMEDCTInferenceJobResponse = smithy.NewSchema(smithy.ShapeID{
	Namespace: "com.amazonaws.comprehendmedical",
	Name:      "StopSNOMEDCTInferenceJobResponse",
}, smithy.ShapeTypeStructure, 1)
var StopSNOMEDCTInferenceJobResponse_JobId *smithy.Schema

// Initialize schema members after all schemas are declared to avoid
// initialization cycles
func init() {
	EntitySubType_NAME = EntitySubType.AddMember("NAME", smithyprelude.Unit)

	EntitySubType_DX_NAME = EntitySubType.AddMember("DX_NAME", smithyprelude.Unit)

	EntitySubType_DOSAGE = EntitySubType.AddMember("DOSAGE", smithyprelude.Unit)

	EntitySubType_ROUTE_OR_MODE = EntitySubType.AddMember("ROUTE_OR_MODE", smithyprelude.Unit)

	EntitySubType_FORM = EntitySubType.AddMember("FORM", smithyprelude.Unit)

	EntitySubType_FREQUENCY = EntitySubType.AddMember("FREQUENCY", smithyprelude.Unit)

	EntitySubType_DURATION = EntitySubType.AddMember("DURATION", smithyprelude.Unit)

	EntitySubType_GENERIC_NAME = EntitySubType.AddMember("GENERIC_NAME", smithyprelude.Unit)

	EntitySubType_BRAND_NAME = EntitySubType.AddMember("BRAND_NAME", smithyprelude.Unit)

	EntitySubType_STRENGTH = EntitySubType.AddMember("STRENGTH", smithyprelude.Unit)

	EntitySubType_RATE = EntitySubType.AddMember("RATE", smithyprelude.Unit)

	EntitySubType_ACUITY = EntitySubType.AddMember("ACUITY", smithyprelude.Unit)

	EntitySubType_TEST_NAME = EntitySubType.AddMember("TEST_NAME", smithyprelude.Unit)

	EntitySubType_TEST_VALUE = EntitySubType.AddMember("TEST_VALUE", smithyprelude.Unit)

	EntitySubType_TEST_UNITS = EntitySubType.AddMember("TEST_UNITS", smithyprelude.Unit)

	EntitySubType_TEST_UNIT = EntitySubType.AddMember("TEST_UNIT", smithyprelude.Unit)

	EntitySubType_PROCEDURE_NAME = EntitySubType.AddMember("PROCEDURE_NAME", smithyprelude.Unit)

	EntitySubType_TREATMENT_NAME = EntitySubType.AddMember("TREATMENT_NAME", smithyprelude.Unit)

	EntitySubType_DATE = EntitySubType.AddMember("DATE", smithyprelude.Unit)

	EntitySubType_AGE = EntitySubType.AddMember("AGE", smithyprelude.Unit)

	EntitySubType_CONTACT_POINT = EntitySubType.AddMember("CONTACT_POINT", smithyprelude.Unit)

	EntitySubType_PHONE_OR_FAX = EntitySubType.AddMember("PHONE_OR_FAX", smithyprelude.Unit)

	EntitySubType_EMAIL = EntitySubType.AddMember("EMAIL", smithyprelude.Unit)

	EntitySubType_IDENTIFIER = EntitySubType.AddMember("IDENTIFIER", smithyprelude.Unit)

	EntitySubType_ID = EntitySubType.AddMember("ID", smithyprelude.Unit)

	EntitySubType_URL = EntitySubType.AddMember("URL", smithyprelude.Unit)

	EntitySubType_ADDRESS = EntitySubType.AddMember("ADDRESS", smithyprelude.Unit)

	EntitySubType_PROFESSION = EntitySubType.AddMember("PROFESSION", smithyprelude.Unit)

	EntitySubType_SYSTEM_ORGAN_SITE = EntitySubType.AddMember("SYSTEM_ORGAN_SITE", smithyprelude.Unit)

	EntitySubType_DIRECTION = EntitySubType.AddMember("DIRECTION", smithyprelude.Unit)

	EntitySubType_QUALITY = EntitySubType.AddMember("QUALITY", smithyprelude.Unit)

	EntitySubType_QUANTITY = EntitySubType.AddMember("QUANTITY", smithyprelude.Unit)

	EntitySubType_TIME_EXPRESSION = EntitySubType.AddMember("TIME_EXPRESSION", smithyprelude.Unit)

	EntitySubType_TIME_TO_MEDICATION_NAME = EntitySubType.AddMember("TIME_TO_MEDICATION_NAME", smithyprelude.Unit)

	EntitySubType_TIME_TO_DX_NAME = EntitySubType.AddMember("TIME_TO_DX_NAME", smithyprelude.Unit)

	EntitySubType_TIME_TO_TEST_NAME = EntitySubType.AddMember("TIME_TO_TEST_NAME", smithyprelude.Unit)

	EntitySubType_TIME_TO_PROCEDURE_NAME = EntitySubType.AddMember("TIME_TO_PROCEDURE_NAME", smithyprelude.Unit)

	EntitySubType_TIME_TO_TREATMENT_NAME = EntitySubType.AddMember("TIME_TO_TREATMENT_NAME", smithyprelude.Unit)

	EntitySubType_AMOUNT = EntitySubType.AddMember("AMOUNT", smithyprelude.Unit)

	EntitySubType_GENDER = EntitySubType.AddMember("GENDER", smithyprelude.Unit)

	EntitySubType_RACE_ETHNICITY = EntitySubType.AddMember("RACE_ETHNICITY", smithyprelude.Unit)

	EntitySubType_ALLERGIES = EntitySubType.AddMember("ALLERGIES", smithyprelude.Unit)

	EntitySubType_TOBACCO_USE = EntitySubType.AddMember("TOBACCO_USE", smithyprelude.Unit)

	EntitySubType_ALCOHOL_CONSUMPTION = EntitySubType.AddMember("ALCOHOL_CONSUMPTION", smithyprelude.Unit)

	EntitySubType_REC_DRUG_USE = EntitySubType.AddMember("REC_DRUG_USE", smithyprelude.Unit)

	RelationshipType_EVERY = RelationshipType.AddMember("EVERY", smithyprelude.Unit)

	RelationshipType_WITH_DOSAGE = RelationshipType.AddMember("WITH_DOSAGE", smithyprelude.Unit)

	RelationshipType_ADMINISTERED_VIA = RelationshipType.AddMember("ADMINISTERED_VIA", smithyprelude.Unit)

	RelationshipType_FOR = RelationshipType.AddMember("FOR", smithyprelude.Unit)

	RelationshipType_NEGATIVE = RelationshipType.AddMember("NEGATIVE", smithyprelude.Unit)

	RelationshipType_OVERLAP = RelationshipType.AddMember("OVERLAP", smithyprelude.Unit)

	RelationshipType_DOSAGE = RelationshipType.AddMember("DOSAGE", smithyprelude.Unit)

	RelationshipType_ROUTE_OR_MODE = RelationshipType.AddMember("ROUTE_OR_MODE", smithyprelude.Unit)

	RelationshipType_FORM = RelationshipType.AddMember("FORM", smithyprelude.Unit)

	RelationshipType_FREQUENCY = RelationshipType.AddMember("FREQUENCY", smithyprelude.Unit)

	RelationshipType_DURATION = RelationshipType.AddMember("DURATION", smithyprelude.Unit)

	RelationshipType_STRENGTH = RelationshipType.AddMember("STRENGTH", smithyprelude.Unit)

	RelationshipType_RATE = RelationshipType.AddMember("RATE", smithyprelude.Unit)

	RelationshipType_ACUITY = RelationshipType.AddMember("ACUITY", smithyprelude.Unit)

	RelationshipType_TEST_VALUE = RelationshipType.AddMember("TEST_VALUE", smithyprelude.Unit)

	RelationshipType_TEST_UNITS = RelationshipType.AddMember("TEST_UNITS", smithyprelude.Unit)

	RelationshipType_TEST_UNIT = RelationshipType.AddMember("TEST_UNIT", smithyprelude.Unit)

	RelationshipType_DIRECTION = RelationshipType.AddMember("DIRECTION", smithyprelude.Unit)

	RelationshipType_SYSTEM_ORGAN_SITE = RelationshipType.AddMember("SYSTEM_ORGAN_SITE", smithyprelude.Unit)

	RelationshipType_AMOUNT = RelationshipType.AddMember("AMOUNT", smithyprelude.Unit)

	RelationshipType_USAGE = RelationshipType.AddMember("USAGE", smithyprelude.Unit)

	RelationshipType_QUALITY = RelationshipType.AddMember("QUALITY", smithyprelude.Unit)

	EntityType_MEDICATION = EntityType.AddMember("MEDICATION", smithyprelude.Unit)

	EntityType_MEDICAL_CONDITION = EntityType.AddMember("MEDICAL_CONDITION", smithyprelude.Unit)

	EntityType_PROTECTED_HEALTH_INFORMATION = EntityType.AddMember("PROTECTED_HEALTH_INFORMATION", smithyprelude.Unit)

	EntityType_TEST_TREATMENT_PROCEDURE = EntityType.AddMember("TEST_TREATMENT_PROCEDURE", smithyprelude.Unit)

	EntityType_ANATOMY = EntityType.AddMember("ANATOMY", smithyprelude.Unit)

	EntityType_TIME_EXPRESSION = EntityType.AddMember("TIME_EXPRESSION", smithyprelude.Unit)

	EntityType_BEHAVIORAL_ENVIRONMENTAL_SOCIAL = EntityType.AddMember("BEHAVIORAL_ENVIRONMENTAL_SOCIAL", smithyprelude.Unit)

	AttributeName_SIGN = AttributeName.AddMember("SIGN", smithyprelude.Unit)

	AttributeName_SYMPTOM = AttributeName.AddMember("SYMPTOM", smithyprelude.Unit)

	AttributeName_DIAGNOSIS = AttributeName.AddMember("DIAGNOSIS", smithyprelude.Unit)

	AttributeName_NEGATION = AttributeName.AddMember("NEGATION", smithyprelude.Unit)

	AttributeName_PERTAINS_TO_FAMILY = AttributeName.AddMember("PERTAINS_TO_FAMILY", smithyprelude.Unit)

	AttributeName_HYPOTHETICAL = AttributeName.AddMember("HYPOTHETICAL", smithyprelude.Unit)

	AttributeName_LOW_CONFIDENCE = AttributeName.AddMember("LOW_CONFIDENCE", smithyprelude.Unit)

	AttributeName_PAST_HISTORY = AttributeName.AddMember("PAST_HISTORY", smithyprelude.Unit)

	AttributeName_FUTURE = AttributeName.AddMember("FUTURE", smithyprelude.Unit)

	Trait_Name = Trait.AddMember("Name", AttributeName)

	Trait_Score = Trait.AddMember("Score", _Float)

	_TraitList_member = _TraitList.AddMember("member", Trait)

	Attribute_Type = Attribute.AddMember("Type", EntitySubType)

	Attribute_Score = Attribute.AddMember("Score", _Float)

	Attribute_RelationshipScore = Attribute.AddMember("RelationshipScore", _Float)

	Attribute_RelationshipType = Attribute.AddMember("RelationshipType", RelationshipType)

	Attribute_Id = Attribute.AddMember("Id", _Integer)

	Attribute_BeginOffset = Attribute.AddMember("BeginOffset", _Integer)

	Attribute_EndOffset = Attribute.AddMember("EndOffset", _Integer)

	Attribute_Text = Attribute.AddMember("Text", _String)

	Attribute_Category = Attribute.AddMember("Category", EntityType)

	Attribute_Traits = Attribute.AddMember("Traits", _TraitList)

	_AttributeList_member = _AttributeList.AddMember("member", Attribute)

	Characters_OriginalTextCharacters = Characters.AddMember("OriginalTextCharacters", _Integer)

	JobStatus_SUBMITTED = JobStatus.AddMember("SUBMITTED", smithyprelude.Unit)

	JobStatus_IN_PROGRESS = JobStatus.AddMember("IN_PROGRESS", smithyprelude.Unit)

	JobStatus_COMPLETED = JobStatus.AddMember("COMPLETED", smithyprelude.Unit)

	JobStatus_PARTIAL_SUCCESS = JobStatus.AddMember("PARTIAL_SUCCESS", smithyprelude.Unit)

	JobStatus_FAILED = JobStatus.AddMember("FAILED", smithyprelude.Unit)

	JobStatus_STOP_REQUESTED = JobStatus.AddMember("STOP_REQUESTED", smithyprelude.Unit)

	JobStatus_STOPPED = JobStatus.AddMember("STOPPED", smithyprelude.Unit)

	ComprehendMedicalAsyncJobFilter_JobName = ComprehendMedicalAsyncJobFilter.AddMember("JobName", _JobName)

	ComprehendMedicalAsyncJobFilter_JobStatus = ComprehendMedicalAsyncJobFilter.AddMember("JobStatus", JobStatus)

	ComprehendMedicalAsyncJobFilter_SubmitTimeBefore = ComprehendMedicalAsyncJobFilter.AddMember("SubmitTimeBefore", _Timestamp)

	ComprehendMedicalAsyncJobFilter_SubmitTimeAfter = ComprehendMedicalAsyncJobFilter.AddMember("SubmitTimeAfter", _Timestamp)

	InputDataConfig_S3Bucket = InputDataConfig.AddMember("S3Bucket", _S3Bucket)

	InputDataConfig_S3Key = InputDataConfig.AddMember("S3Key", _S3Key)

	OutputDataConfig_S3Bucket = OutputDataConfig.AddMember("S3Bucket", _S3Bucket)

	OutputDataConfig_S3Key = OutputDataConfig.AddMember("S3Key", _S3Key)

	LanguageCode_EN = LanguageCode.AddMember("EN", smithyprelude.Unit)

	ComprehendMedicalAsyncJobProperties_JobId = ComprehendMedicalAsyncJobProperties.AddMember("JobId", _JobId)

	ComprehendMedicalAsyncJobProperties_JobName = ComprehendMedicalAsyncJobProperties.AddMember("JobName", _JobName)

	ComprehendMedicalAsyncJobProperties_JobStatus = ComprehendMedicalAsyncJobProperties.AddMember("JobStatus", JobStatus)

	ComprehendMedicalAsyncJobProperties_Message = ComprehendMedicalAsyncJobProperties.AddMember("Message", _AnyLengthString)

	ComprehendMedicalAsyncJobProperties_SubmitTime = ComprehendMedicalAsyncJobProperties.AddMember("SubmitTime", _Timestamp)

	ComprehendMedicalAsyncJobProperties_EndTime = ComprehendMedicalAsyncJobProperties.AddMember("EndTime", _Timestamp)

	ComprehendMedicalAsyncJobProperties_ExpirationTime = ComprehendMedicalAsyncJobProperties.AddMember("ExpirationTime", _Timestamp)

	ComprehendMedicalAsyncJobProperties_InputDataConfig = ComprehendMedicalAsyncJobProperties.AddMember("InputDataConfig", InputDataConfig)

	ComprehendMedicalAsyncJobProperties_OutputDataConfig = ComprehendMedicalAsyncJobProperties.AddMember("OutputDataConfig", OutputDataConfig)

	ComprehendMedicalAsyncJobProperties_LanguageCode = ComprehendMedicalAsyncJobProperties.AddMember("LanguageCode", LanguageCode)

	ComprehendMedicalAsyncJobProperties_DataAccessRoleArn = ComprehendMedicalAsyncJobProperties.AddMember("DataAccessRoleArn", _IamRoleArn)

	ComprehendMedicalAsyncJobProperties_ManifestFilePath = ComprehendMedicalAsyncJobProperties.AddMember("ManifestFilePath", _ManifestFilePath)

	ComprehendMedicalAsyncJobProperties_KMSKey = ComprehendMedicalAsyncJobProperties.AddMember("KMSKey", _KMSKey)

	ComprehendMedicalAsyncJobProperties_ModelVersion = ComprehendMedicalAsyncJobProperties.AddMember("ModelVersion", _ModelVersion)

	_ComprehendMedicalAsyncJobPropertiesList_member = _ComprehendMedicalAsyncJobPropertiesList.AddMember("member", ComprehendMedicalAsyncJobProperties)

	Entity_Id = Entity.AddMember("Id", _Integer)

	Entity_BeginOffset = Entity.AddMember("BeginOffset", _Integer)

	Entity_EndOffset = Entity.AddMember("EndOffset", _Integer)

	Entity_Score = Entity.AddMember("Score", _Float)

	Entity_Text = Entity.AddMember("Text", _String)

	Entity_Category = Entity.AddMember("Category", EntityType)

	Entity_Type = Entity.AddMember("Type", EntitySubType)

	Entity_Traits = Entity.AddMember("Traits", _TraitList)

	Entity_Attributes = Entity.AddMember("Attributes", _AttributeList)

	_EntityList_member = _EntityList.AddMember("member", Entity)

	ICD10CMAttributeType_ACUITY = ICD10CMAttributeType.AddMember("ACUITY", smithyprelude.Unit)

	ICD10CMAttributeType_DIRECTION = ICD10CMAttributeType.AddMember("DIRECTION", smithyprelude.Unit)

	ICD10CMAttributeType_SYSTEM_ORGAN_SITE = ICD10CMAttributeType.AddMember("SYSTEM_ORGAN_SITE", smithyprelude.Unit)

	ICD10CMAttributeType_QUALITY = ICD10CMAttributeType.AddMember("QUALITY", smithyprelude.Unit)

	ICD10CMAttributeType_QUANTITY = ICD10CMAttributeType.AddMember("QUANTITY", smithyprelude.Unit)

	ICD10CMAttributeType_TIME_TO_DX_NAME = ICD10CMAttributeType.AddMember("TIME_TO_DX_NAME", smithyprelude.Unit)

	ICD10CMAttributeType_TIME_EXPRESSION = ICD10CMAttributeType.AddMember("TIME_EXPRESSION", smithyprelude.Unit)

	ICD10CMTraitName_NEGATION = ICD10CMTraitName.AddMember("NEGATION", smithyprelude.Unit)

	ICD10CMTraitName_DIAGNOSIS = ICD10CMTraitName.AddMember("DIAGNOSIS", smithyprelude.Unit)

	ICD10CMTraitName_SIGN = ICD10CMTraitName.AddMember("SIGN", smithyprelude.Unit)

	ICD10CMTraitName_SYMPTOM = ICD10CMTraitName.AddMember("SYMPTOM", smithyprelude.Unit)

	ICD10CMTraitName_PERTAINS_TO_FAMILY = ICD10CMTraitName.AddMember("PERTAINS_TO_FAMILY", smithyprelude.Unit)

	ICD10CMTraitName_HYPOTHETICAL = ICD10CMTraitName.AddMember("HYPOTHETICAL", smithyprelude.Unit)

	ICD10CMTraitName_LOW_CONFIDENCE = ICD10CMTraitName.AddMember("LOW_CONFIDENCE", smithyprelude.Unit)

	ICD10CMTrait_Name = ICD10CMTrait.AddMember("Name", ICD10CMTraitName)

	ICD10CMTrait_Score = ICD10CMTrait.AddMember("Score", _Float)

	_ICD10CMTraitList_member = _ICD10CMTraitList.AddMember("member", ICD10CMTrait)

	ICD10CMEntityType_DX_NAME = ICD10CMEntityType.AddMember("DX_NAME", smithyprelude.Unit)

	ICD10CMEntityType_TIME_EXPRESSION = ICD10CMEntityType.AddMember("TIME_EXPRESSION", smithyprelude.Unit)

	ICD10CMRelationshipType_OVERLAP = ICD10CMRelationshipType.AddMember("OVERLAP", smithyprelude.Unit)

	ICD10CMRelationshipType_SYSTEM_ORGAN_SITE = ICD10CMRelationshipType.AddMember("SYSTEM_ORGAN_SITE", smithyprelude.Unit)

	ICD10CMRelationshipType_QUALITY = ICD10CMRelationshipType.AddMember("QUALITY", smithyprelude.Unit)

	ICD10CMAttribute_Type = ICD10CMAttribute.AddMember("Type", ICD10CMAttributeType)

	ICD10CMAttribute_Score = ICD10CMAttribute.AddMember("Score", _Float)

	ICD10CMAttribute_RelationshipScore = ICD10CMAttribute.AddMember("RelationshipScore", _Float)

	ICD10CMAttribute_Id = ICD10CMAttribute.AddMember("Id", _Integer)

	ICD10CMAttribute_BeginOffset = ICD10CMAttribute.AddMember("BeginOffset", _Integer)

	ICD10CMAttribute_EndOffset = ICD10CMAttribute.AddMember("EndOffset", _Integer)

	ICD10CMAttribute_Text = ICD10CMAttribute.AddMember("Text", _String)

	ICD10CMAttribute_Traits = ICD10CMAttribute.AddMember("Traits", _ICD10CMTraitList)

	ICD10CMAttribute_Category = ICD10CMAttribute.AddMember("Category", ICD10CMEntityType)

	ICD10CMAttribute_RelationshipType = ICD10CMAttribute.AddMember("RelationshipType", ICD10CMRelationshipType)

	_ICD10CMAttributeList_member = _ICD10CMAttributeList.AddMember("member", ICD10CMAttribute)

	ICD10CMConcept_Description = ICD10CMConcept.AddMember("Description", _String)

	ICD10CMConcept_Code = ICD10CMConcept.AddMember("Code", _String)

	ICD10CMConcept_Score = ICD10CMConcept.AddMember("Score", _Float)

	_ICD10CMConceptList_member = _ICD10CMConceptList.AddMember("member", ICD10CMConcept)

	ICD10CMEntityCategory_MEDICAL_CONDITION = ICD10CMEntityCategory.AddMember("MEDICAL_CONDITION", smithyprelude.Unit)

	ICD10CMEntity_Id = ICD10CMEntity.AddMember("Id", _Integer)

	ICD10CMEntity_Text = ICD10CMEntity.AddMember("Text", _OntologyLinkingBoundedLengthString)

	ICD10CMEntity_Category = ICD10CMEntity.AddMember("Category", ICD10CMEntityCategory)

	ICD10CMEntity_Type = ICD10CMEntity.AddMember("Type", ICD10CMEntityType)

	ICD10CMEntity_Score = ICD10CMEntity.AddMember("Score", _Float)

	ICD10CMEntity_BeginOffset = ICD10CMEntity.AddMember("BeginOffset", _Integer)

	ICD10CMEntity_EndOffset = ICD10CMEntity.AddMember("EndOffset", _Integer)

	ICD10CMEntity_Attributes = ICD10CMEntity.AddMember("Attributes", _ICD10CMAttributeList)

	ICD10CMEntity_Traits = ICD10CMEntity.AddMember("Traits", _ICD10CMTraitList)

	ICD10CMEntity_ICD10CMConcepts = ICD10CMEntity.AddMember("ICD10CMConcepts", _ICD10CMConceptList)

	_ICD10CMEntityList_member = _ICD10CMEntityList.AddMember("member", ICD10CMEntity)

	InternalServerException_Message = InternalServerException.AddMember("Message", _String)

	InvalidEncodingException_Message = InvalidEncodingException.AddMember("Message", _String)

	InvalidRequestException_Message = InvalidRequestException.AddMember("Message", _String)

	ResourceNotFoundException_Message = ResourceNotFoundException.AddMember("Message", _String)

	RxNormAttributeType_DOSAGE = RxNormAttributeType.AddMember("DOSAGE", smithyprelude.Unit)

	RxNormAttributeType_DURATION = RxNormAttributeType.AddMember("DURATION", smithyprelude.Unit)

	RxNormAttributeType_FORM = RxNormAttributeType.AddMember("FORM", smithyprelude.Unit)

	RxNormAttributeType_FREQUENCY = RxNormAttributeType.AddMember("FREQUENCY", smithyprelude.Unit)

	RxNormAttributeType_RATE = RxNormAttributeType.AddMember("RATE", smithyprelude.Unit)

	RxNormAttributeType_ROUTE_OR_MODE = RxNormAttributeType.AddMember("ROUTE_OR_MODE", smithyprelude.Unit)

	RxNormAttributeType_STRENGTH = RxNormAttributeType.AddMember("STRENGTH", smithyprelude.Unit)

	RxNormTraitName_NEGATION = RxNormTraitName.AddMember("NEGATION", smithyprelude.Unit)

	RxNormTraitName_PAST_HISTORY = RxNormTraitName.AddMember("PAST_HISTORY", smithyprelude.Unit)

	RxNormTrait_Name = RxNormTrait.AddMember("Name", RxNormTraitName)

	RxNormTrait_Score = RxNormTrait.AddMember("Score", _Float)

	_RxNormTraitList_member = _RxNormTraitList.AddMember("member", RxNormTrait)

	RxNormAttribute_Type = RxNormAttribute.AddMember("Type", RxNormAttributeType)

	RxNormAttribute_Score = RxNormAttribute.AddMember("Score", _Float)

	RxNormAttribute_RelationshipScore = RxNormAttribute.AddMember("RelationshipScore", _Float)

	RxNormAttribute_Id = RxNormAttribute.AddMember("Id", _Integer)

	RxNormAttribute_BeginOffset = RxNormAttribute.AddMember("BeginOffset", _Integer)

	RxNormAttribute_EndOffset = RxNormAttribute.AddMember("EndOffset", _Integer)

	RxNormAttribute_Text = RxNormAttribute.AddMember("Text", _String)

	RxNormAttribute_Traits = RxNormAttribute.AddMember("Traits", _RxNormTraitList)

	_RxNormAttributeList_member = _RxNormAttributeList.AddMember("member", RxNormAttribute)

	RxNormConcept_Description = RxNormConcept.AddMember("Description", _String)

	RxNormConcept_Code = RxNormConcept.AddMember("Code", _String)

	RxNormConcept_Score = RxNormConcept.AddMember("Score", _Float)

	_RxNormConceptList_member = _RxNormConceptList.AddMember("member", RxNormConcept)

	RxNormEntityCategory_MEDICATION = RxNormEntityCategory.AddMember("MEDICATION", smithyprelude.Unit)

	RxNormEntityType_BRAND_NAME = RxNormEntityType.AddMember("BRAND_NAME", smithyprelude.Unit)

	RxNormEntityType_GENERIC_NAME = RxNormEntityType.AddMember("GENERIC_NAME", smithyprelude.Unit)

	RxNormEntity_Id = RxNormEntity.AddMember("Id", _Integer)

	RxNormEntity_Text = RxNormEntity.AddMember("Text", _OntologyLinkingBoundedLengthString)

	RxNormEntity_Category = RxNormEntity.AddMember("Category", RxNormEntityCategory)

	RxNormEntity_Type = RxNormEntity.AddMember("Type", RxNormEntityType)

	RxNormEntity_Score = RxNormEntity.AddMember("Score", _Float)

	RxNormEntity_BeginOffset = RxNormEntity.AddMember("BeginOffset", _Integer)

	RxNormEntity_EndOffset = RxNormEntity.AddMember("EndOffset", _Integer)

	RxNormEntity_Attributes = RxNormEntity.AddMember("Attributes", _RxNormAttributeList)

	RxNormEntity_Traits = RxNormEntity.AddMember("Traits", _RxNormTraitList)

	RxNormEntity_RxNormConcepts = RxNormEntity.AddMember("RxNormConcepts", _RxNormConceptList)

	_RxNormEntityList_member = _RxNormEntityList.AddMember("member", RxNormEntity)

	ServiceUnavailableException_Message = ServiceUnavailableException.AddMember("Message", _String)

	SNOMEDCTEntityCategory_MEDICAL_CONDITION = SNOMEDCTEntityCategory.AddMember("MEDICAL_CONDITION", smithyprelude.Unit)

	SNOMEDCTEntityCategory_ANATOMY = SNOMEDCTEntityCategory.AddMember("ANATOMY", smithyprelude.Unit)

	SNOMEDCTEntityCategory_TEST_TREATMENT_PROCEDURE = SNOMEDCTEntityCategory.AddMember("TEST_TREATMENT_PROCEDURE", smithyprelude.Unit)

	SNOMEDCTAttributeType_ACUITY = SNOMEDCTAttributeType.AddMember("ACUITY", smithyprelude.Unit)

	SNOMEDCTAttributeType_QUALITY = SNOMEDCTAttributeType.AddMember("QUALITY", smithyprelude.Unit)

	SNOMEDCTAttributeType_DIRECTION = SNOMEDCTAttributeType.AddMember("DIRECTION", smithyprelude.Unit)

	SNOMEDCTAttributeType_SYSTEM_ORGAN_SITE = SNOMEDCTAttributeType.AddMember("SYSTEM_ORGAN_SITE", smithyprelude.Unit)

	SNOMEDCTAttributeType_TEST_VALUE = SNOMEDCTAttributeType.AddMember("TEST_VALUE", smithyprelude.Unit)

	SNOMEDCTAttributeType_TEST_UNIT = SNOMEDCTAttributeType.AddMember("TEST_UNIT", smithyprelude.Unit)

	SNOMEDCTRelationshipType_ACUITY = SNOMEDCTRelationshipType.AddMember("ACUITY", smithyprelude.Unit)

	SNOMEDCTRelationshipType_QUALITY = SNOMEDCTRelationshipType.AddMember("QUALITY", smithyprelude.Unit)

	SNOMEDCTRelationshipType_TEST_VALUE = SNOMEDCTRelationshipType.AddMember("TEST_VALUE", smithyprelude.Unit)

	SNOMEDCTRelationshipType_TEST_UNITS = SNOMEDCTRelationshipType.AddMember("TEST_UNITS", smithyprelude.Unit)

	SNOMEDCTRelationshipType_DIRECTION = SNOMEDCTRelationshipType.AddMember("DIRECTION", smithyprelude.Unit)

	SNOMEDCTRelationshipType_SYSTEM_ORGAN_SITE = SNOMEDCTRelationshipType.AddMember("SYSTEM_ORGAN_SITE", smithyprelude.Unit)

	SNOMEDCTRelationshipType_TEST_UNIT = SNOMEDCTRelationshipType.AddMember("TEST_UNIT", smithyprelude.Unit)

	SNOMEDCTTraitName_NEGATION = SNOMEDCTTraitName.AddMember("NEGATION", smithyprelude.Unit)

	SNOMEDCTTraitName_DIAGNOSIS = SNOMEDCTTraitName.AddMember("DIAGNOSIS", smithyprelude.Unit)

	SNOMEDCTTraitName_SIGN = SNOMEDCTTraitName.AddMember("SIGN", smithyprelude.Unit)

	SNOMEDCTTraitName_SYMPTOM = SNOMEDCTTraitName.AddMember("SYMPTOM", smithyprelude.Unit)

	SNOMEDCTTraitName_PERTAINS_TO_FAMILY = SNOMEDCTTraitName.AddMember("PERTAINS_TO_FAMILY", smithyprelude.Unit)

	SNOMEDCTTraitName_HYPOTHETICAL = SNOMEDCTTraitName.AddMember("HYPOTHETICAL", smithyprelude.Unit)

	SNOMEDCTTraitName_LOW_CONFIDENCE = SNOMEDCTTraitName.AddMember("LOW_CONFIDENCE", smithyprelude.Unit)

	SNOMEDCTTraitName_PAST_HISTORY = SNOMEDCTTraitName.AddMember("PAST_HISTORY", smithyprelude.Unit)

	SNOMEDCTTraitName_FUTURE = SNOMEDCTTraitName.AddMember("FUTURE", smithyprelude.Unit)

	SNOMEDCTTrait_Name = SNOMEDCTTrait.AddMember("Name", SNOMEDCTTraitName)

	SNOMEDCTTrait_Score = SNOMEDCTTrait.AddMember("Score", _Float)

	_SNOMEDCTTraitList_member = _SNOMEDCTTraitList.AddMember("member", SNOMEDCTTrait)

	SNOMEDCTConcept_Description = SNOMEDCTConcept.AddMember("Description", _String)

	SNOMEDCTConcept_Code = SNOMEDCTConcept.AddMember("Code", _String)

	SNOMEDCTConcept_Score = SNOMEDCTConcept.AddMember("Score", _Float)

	_SNOMEDCTConceptList_member = _SNOMEDCTConceptList.AddMember("member", SNOMEDCTConcept)

	SNOMEDCTAttribute_Category = SNOMEDCTAttribute.AddMember("Category", SNOMEDCTEntityCategory)

	SNOMEDCTAttribute_Type = SNOMEDCTAttribute.AddMember("Type", SNOMEDCTAttributeType)

	SNOMEDCTAttribute_Score = SNOMEDCTAttribute.AddMember("Score", _Float)

	SNOMEDCTAttribute_RelationshipScore = SNOMEDCTAttribute.AddMember("RelationshipScore", _Float)

	SNOMEDCTAttribute_RelationshipType = SNOMEDCTAttribute.AddMember("RelationshipType", SNOMEDCTRelationshipType)

	SNOMEDCTAttribute_Id = SNOMEDCTAttribute.AddMember("Id", _Integer)

	SNOMEDCTAttribute_BeginOffset = SNOMEDCTAttribute.AddMember("BeginOffset", _Integer)

	SNOMEDCTAttribute_EndOffset = SNOMEDCTAttribute.AddMember("EndOffset", _Integer)

	SNOMEDCTAttribute_Text = SNOMEDCTAttribute.AddMember("Text", _String)

	SNOMEDCTAttribute_Traits = SNOMEDCTAttribute.AddMember("Traits", _SNOMEDCTTraitList)

	SNOMEDCTAttribute_SNOMEDCTConcepts = SNOMEDCTAttribute.AddMember("SNOMEDCTConcepts", _SNOMEDCTConceptList)

	_SNOMEDCTAttributeList_member = _SNOMEDCTAttributeList.AddMember("member", SNOMEDCTAttribute)

	SNOMEDCTDetails_Edition = SNOMEDCTDetails.AddMember("Edition", _String)

	SNOMEDCTDetails_Language = SNOMEDCTDetails.AddMember("Language", _String)

	SNOMEDCTDetails_VersionDate = SNOMEDCTDetails.AddMember("VersionDate", _String)

	SNOMEDCTEntityType_DX_NAME = SNOMEDCTEntityType.AddMember("DX_NAME", smithyprelude.Unit)

	SNOMEDCTEntityType_TEST_NAME = SNOMEDCTEntityType.AddMember("TEST_NAME", smithyprelude.Unit)

	SNOMEDCTEntityType_PROCEDURE_NAME = SNOMEDCTEntityType.AddMember("PROCEDURE_NAME", smithyprelude.Unit)

	SNOMEDCTEntityType_TREATMENT_NAME = SNOMEDCTEntityType.AddMember("TREATMENT_NAME", smithyprelude.Unit)

	SNOMEDCTEntity_Id = SNOMEDCTEntity.AddMember("Id", _Integer)

	SNOMEDCTEntity_Text = SNOMEDCTEntity.AddMember("Text", _OntologyLinkingBoundedLengthString)

	SNOMEDCTEntity_Category = SNOMEDCTEntity.AddMember("Category", SNOMEDCTEntityCategory)

	SNOMEDCTEntity_Type = SNOMEDCTEntity.AddMember("Type", SNOMEDCTEntityType)

	SNOMEDCTEntity_Score = SNOMEDCTEntity.AddMember("Score", _Float)

	SNOMEDCTEntity_BeginOffset = SNOMEDCTEntity.AddMember("BeginOffset", _Integer)

	SNOMEDCTEntity_EndOffset = SNOMEDCTEntity.AddMember("EndOffset", _Integer)

	SNOMEDCTEntity_Attributes = SNOMEDCTEntity.AddMember("Attributes", _SNOMEDCTAttributeList)

	SNOMEDCTEntity_Traits = SNOMEDCTEntity.AddMember("Traits", _SNOMEDCTTraitList)

	SNOMEDCTEntity_SNOMEDCTConcepts = SNOMEDCTEntity.AddMember("SNOMEDCTConcepts", _SNOMEDCTConceptList)

	_SNOMEDCTEntityList_member = _SNOMEDCTEntityList.AddMember("member", SNOMEDCTEntity)

	TextSizeLimitExceededException_Message = TextSizeLimitExceededException.AddMember("Message", _String)

	TooManyRequestsException_Message = TooManyRequestsException.AddMember("Message", _String)

	UnmappedAttribute_Type = UnmappedAttribute.AddMember("Type", EntityType)

	UnmappedAttribute_Attribute = UnmappedAttribute.AddMember("Attribute", Attribute)

	_UnmappedAttributeList_member = _UnmappedAttributeList.AddMember("member", UnmappedAttribute)

	ValidationException_Message = ValidationException.AddMember("Message", _String)

	DescribeEntitiesDetectionV2JobRequest_JobId = DescribeEntitiesDetectionV2JobRequest.AddMember("JobId", _JobId)

	DescribeEntitiesDetectionV2JobResponse_ComprehendMedicalAsyncJobProperties = DescribeEntitiesDetectionV2JobResponse.AddMember("ComprehendMedicalAsyncJobProperties", ComprehendMedicalAsyncJobProperties)

	DescribeICD10CMInferenceJobRequest_JobId = DescribeICD10CMInferenceJobRequest.AddMember("JobId", _JobId)

	DescribeICD10CMInferenceJobResponse_ComprehendMedicalAsyncJobProperties = DescribeICD10CMInferenceJobResponse.AddMember("ComprehendMedicalAsyncJobProperties", ComprehendMedicalAsyncJobProperties)

	DescribePHIDetectionJobRequest_JobId = DescribePHIDetectionJobRequest.AddMember("JobId", _JobId)

	DescribePHIDetectionJobResponse_ComprehendMedicalAsyncJobProperties = DescribePHIDetectionJobResponse.AddMember("ComprehendMedicalAsyncJobProperties", ComprehendMedicalAsyncJobProperties)

	DescribeRxNormInferenceJobRequest_JobId = DescribeRxNormInferenceJobRequest.AddMember("JobId", _JobId)

	DescribeRxNormInferenceJobResponse_ComprehendMedicalAsyncJobProperties = DescribeRxNormInferenceJobResponse.AddMember("ComprehendMedicalAsyncJobProperties", ComprehendMedicalAsyncJobProperties)

	DescribeSNOMEDCTInferenceJobRequest_JobId = DescribeSNOMEDCTInferenceJobRequest.AddMember("JobId", _JobId)

	DescribeSNOMEDCTInferenceJobResponse_ComprehendMedicalAsyncJobProperties = DescribeSNOMEDCTInferenceJobResponse.AddMember("ComprehendMedicalAsyncJobProperties", ComprehendMedicalAsyncJobProperties)

	DetectEntitiesRequest_Text = DetectEntitiesRequest.AddMember("Text", _BoundedLengthString)

	DetectEntitiesResponse_Entities = DetectEntitiesResponse.AddMember("Entities", _EntityList)

	DetectEntitiesResponse_UnmappedAttributes = DetectEntitiesResponse.AddMember("UnmappedAttributes", _UnmappedAttributeList)

	DetectEntitiesResponse_PaginationToken = DetectEntitiesResponse.AddMember("PaginationToken", _String)

	DetectEntitiesResponse_ModelVersion = DetectEntitiesResponse.AddMember("ModelVersion", _String)

	DetectEntitiesV2Request_Text = DetectEntitiesV2Request.AddMember("Text", _BoundedLengthString)

	DetectEntitiesV2Response_Entities = DetectEntitiesV2Response.AddMember("Entities", _EntityList)

	DetectEntitiesV2Response_UnmappedAttributes = DetectEntitiesV2Response.AddMember("UnmappedAttributes", _UnmappedAttributeList)

	DetectEntitiesV2Response_PaginationToken = DetectEntitiesV2Response.AddMember("PaginationToken", _String)

	DetectEntitiesV2Response_ModelVersion = DetectEntitiesV2Response.AddMember("ModelVersion", _String)

	DetectPHIRequest_Text = DetectPHIRequest.AddMember("Text", _BoundedLengthString)

	DetectPHIResponse_Entities = DetectPHIResponse.AddMember("Entities", _EntityList)

	DetectPHIResponse_PaginationToken = DetectPHIResponse.AddMember("PaginationToken", _String)

	DetectPHIResponse_ModelVersion = DetectPHIResponse.AddMember("ModelVersion", _String)

	InferICD10CMRequest_Text = InferICD10CMRequest.AddMember("Text", _OntologyLinkingBoundedLengthString)

	InferICD10CMResponse_Entities = InferICD10CMResponse.AddMember("Entities", _ICD10CMEntityList)

	InferICD10CMResponse_PaginationToken = InferICD10CMResponse.AddMember("PaginationToken", _String)

	InferICD10CMResponse_ModelVersion = InferICD10CMResponse.AddMember("ModelVersion", _String)

	InferRxNormRequest_Text = InferRxNormRequest.AddMember("Text", _OntologyLinkingBoundedLengthString)

	InferRxNormResponse_Entities = InferRxNormResponse.AddMember("Entities", _RxNormEntityList)

	InferRxNormResponse_PaginationToken = InferRxNormResponse.AddMember("PaginationToken", _String)

	InferRxNormResponse_ModelVersion = InferRxNormResponse.AddMember("ModelVersion", _String)

	InferSNOMEDCTRequest_Text = InferSNOMEDCTRequest.AddMember("Text", _OntologyLinkingBoundedLengthString)

	InferSNOMEDCTResponse_Entities = InferSNOMEDCTResponse.AddMember("Entities", _SNOMEDCTEntityList)

	InferSNOMEDCTResponse_PaginationToken = InferSNOMEDCTResponse.AddMember("PaginationToken", _String)

	InferSNOMEDCTResponse_ModelVersion = InferSNOMEDCTResponse.AddMember("ModelVersion", _String)

	InferSNOMEDCTResponse_SNOMEDCTDetails = InferSNOMEDCTResponse.AddMember("SNOMEDCTDetails", SNOMEDCTDetails)

	InferSNOMEDCTResponse_Characters = InferSNOMEDCTResponse.AddMember("Characters", Characters)

	ListEntitiesDetectionV2JobsRequest_Filter = ListEntitiesDetectionV2JobsRequest.AddMember("Filter", ComprehendMedicalAsyncJobFilter)

	ListEntitiesDetectionV2JobsRequest_NextToken = ListEntitiesDetectionV2JobsRequest.AddMember("NextToken", _String)

	ListEntitiesDetectionV2JobsRequest_MaxResults = ListEntitiesDetectionV2JobsRequest.AddMember("MaxResults", _MaxResultsInteger)

	ListEntitiesDetectionV2JobsResponse_ComprehendMedicalAsyncJobPropertiesList = ListEntitiesDetectionV2JobsResponse.AddMember("ComprehendMedicalAsyncJobPropertiesList", _ComprehendMedicalAsyncJobPropertiesList)

	ListEntitiesDetectionV2JobsResponse_NextToken = ListEntitiesDetectionV2JobsResponse.AddMember("NextToken", _String)

	ListICD10CMInferenceJobsRequest_Filter = ListICD10CMInferenceJobsRequest.AddMember("Filter", ComprehendMedicalAsyncJobFilter)

	ListICD10CMInferenceJobsRequest_NextToken = ListICD10CMInferenceJobsRequest.AddMember("NextToken", _String)

	ListICD10CMInferenceJobsRequest_MaxResults = ListICD10CMInferenceJobsRequest.AddMember("MaxResults", _MaxResultsInteger)

	ListICD10CMInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList = ListICD10CMInferenceJobsResponse.AddMember("ComprehendMedicalAsyncJobPropertiesList", _ComprehendMedicalAsyncJobPropertiesList)

	ListICD10CMInferenceJobsResponse_NextToken = ListICD10CMInferenceJobsResponse.AddMember("NextToken", _String)

	ListPHIDetectionJobsRequest_Filter = ListPHIDetectionJobsRequest.AddMember("Filter", ComprehendMedicalAsyncJobFilter)

	ListPHIDetectionJobsRequest_NextToken = ListPHIDetectionJobsRequest.AddMember("NextToken", _String)

	ListPHIDetectionJobsRequest_MaxResults = ListPHIDetectionJobsRequest.AddMember("MaxResults", _MaxResultsInteger)

	ListPHIDetectionJobsResponse_ComprehendMedicalAsyncJobPropertiesList = ListPHIDetectionJobsResponse.AddMember("ComprehendMedicalAsyncJobPropertiesList", _ComprehendMedicalAsyncJobPropertiesList)

	ListPHIDetectionJobsResponse_NextToken = ListPHIDetectionJobsResponse.AddMember("NextToken", _String)

	ListRxNormInferenceJobsRequest_Filter = ListRxNormInferenceJobsRequest.AddMember("Filter", ComprehendMedicalAsyncJobFilter)

	ListRxNormInferenceJobsRequest_NextToken = ListRxNormInferenceJobsRequest.AddMember("NextToken", _String)

	ListRxNormInferenceJobsRequest_MaxResults = ListRxNormInferenceJobsRequest.AddMember("MaxResults", _MaxResultsInteger)

	ListRxNormInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList = ListRxNormInferenceJobsResponse.AddMember("ComprehendMedicalAsyncJobPropertiesList", _ComprehendMedicalAsyncJobPropertiesList)

	ListRxNormInferenceJobsResponse_NextToken = ListRxNormInferenceJobsResponse.AddMember("NextToken", _String)

	ListSNOMEDCTInferenceJobsRequest_Filter = ListSNOMEDCTInferenceJobsRequest.AddMember("Filter", ComprehendMedicalAsyncJobFilter)

	ListSNOMEDCTInferenceJobsRequest_NextToken = ListSNOMEDCTInferenceJobsRequest.AddMember("NextToken", _String)

	ListSNOMEDCTInferenceJobsRequest_MaxResults = ListSNOMEDCTInferenceJobsRequest.AddMember("MaxResults", _MaxResultsInteger)

	ListSNOMEDCTInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList = ListSNOMEDCTInferenceJobsResponse.AddMember("ComprehendMedicalAsyncJobPropertiesList", _ComprehendMedicalAsyncJobPropertiesList)

	ListSNOMEDCTInferenceJobsResponse_NextToken = ListSNOMEDCTInferenceJobsResponse.AddMember("NextToken", _String)

	StartEntitiesDetectionV2JobRequest_InputDataConfig = StartEntitiesDetectionV2JobRequest.AddMember("InputDataConfig", InputDataConfig)

	StartEntitiesDetectionV2JobRequest_OutputDataConfig = StartEntitiesDetectionV2JobRequest.AddMember("OutputDataConfig", OutputDataConfig)

	StartEntitiesDetectionV2JobRequest_DataAccessRoleArn = StartEntitiesDetectionV2JobRequest.AddMember("DataAccessRoleArn", _IamRoleArn)

	StartEntitiesDetectionV2JobRequest_JobName = StartEntitiesDetectionV2JobRequest.AddMember("JobName", _JobName)

	StartEntitiesDetectionV2JobRequest_ClientRequestToken = StartEntitiesDetectionV2JobRequest.AddMember("ClientRequestToken", _ClientRequestTokenString)

	StartEntitiesDetectionV2JobRequest_KMSKey = StartEntitiesDetectionV2JobRequest.AddMember("KMSKey", _KMSKey)

	StartEntitiesDetectionV2JobRequest_LanguageCode = StartEntitiesDetectionV2JobRequest.AddMember("LanguageCode", LanguageCode)

	StartEntitiesDetectionV2JobResponse_JobId = StartEntitiesDetectionV2JobResponse.AddMember("JobId", _JobId)

	StartICD10CMInferenceJobRequest_InputDataConfig = StartICD10CMInferenceJobRequest.AddMember("InputDataConfig", InputDataConfig)

	StartICD10CMInferenceJobRequest_OutputDataConfig = StartICD10CMInferenceJobRequest.AddMember("OutputDataConfig", OutputDataConfig)

	StartICD10CMInferenceJobRequest_DataAccessRoleArn = StartICD10CMInferenceJobRequest.AddMember("DataAccessRoleArn", _IamRoleArn)

	StartICD10CMInferenceJobRequest_JobName = StartICD10CMInferenceJobRequest.AddMember("JobName", _JobName)

	StartICD10CMInferenceJobRequest_ClientRequestToken = StartICD10CMInferenceJobRequest.AddMember("ClientRequestToken", _ClientRequestTokenString)

	StartICD10CMInferenceJobRequest_KMSKey = StartICD10CMInferenceJobRequest.AddMember("KMSKey", _KMSKey)

	StartICD10CMInferenceJobRequest_LanguageCode = StartICD10CMInferenceJobRequest.AddMember("LanguageCode", LanguageCode)

	StartICD10CMInferenceJobResponse_JobId = StartICD10CMInferenceJobResponse.AddMember("JobId", _JobId)

	StartPHIDetectionJobRequest_InputDataConfig = StartPHIDetectionJobRequest.AddMember("InputDataConfig", InputDataConfig)

	StartPHIDetectionJobRequest_OutputDataConfig = StartPHIDetectionJobRequest.AddMember("OutputDataConfig", OutputDataConfig)

	StartPHIDetectionJobRequest_DataAccessRoleArn = StartPHIDetectionJobRequest.AddMember("DataAccessRoleArn", _IamRoleArn)

	StartPHIDetectionJobRequest_JobName = StartPHIDetectionJobRequest.AddMember("JobName", _JobName)

	StartPHIDetectionJobRequest_ClientRequestToken = StartPHIDetectionJobRequest.AddMember("ClientRequestToken", _ClientRequestTokenString)

	StartPHIDetectionJobRequest_KMSKey = StartPHIDetectionJobRequest.AddMember("KMSKey", _KMSKey)

	StartPHIDetectionJobRequest_LanguageCode = StartPHIDetectionJobRequest.AddMember("LanguageCode", LanguageCode)

	StartPHIDetectionJobResponse_JobId = StartPHIDetectionJobResponse.AddMember("JobId", _JobId)

	StartRxNormInferenceJobRequest_InputDataConfig = StartRxNormInferenceJobRequest.AddMember("InputDataConfig", InputDataConfig)

	StartRxNormInferenceJobRequest_OutputDataConfig = StartRxNormInferenceJobRequest.AddMember("OutputDataConfig", OutputDataConfig)

	StartRxNormInferenceJobRequest_DataAccessRoleArn = StartRxNormInferenceJobRequest.AddMember("DataAccessRoleArn", _IamRoleArn)

	StartRxNormInferenceJobRequest_JobName = StartRxNormInferenceJobRequest.AddMember("JobName", _JobName)

	StartRxNormInferenceJobRequest_ClientRequestToken = StartRxNormInferenceJobRequest.AddMember("ClientRequestToken", _ClientRequestTokenString)

	StartRxNormInferenceJobRequest_KMSKey = StartRxNormInferenceJobRequest.AddMember("KMSKey", _KMSKey)

	StartRxNormInferenceJobRequest_LanguageCode = StartRxNormInferenceJobRequest.AddMember("LanguageCode", LanguageCode)

	StartRxNormInferenceJobResponse_JobId = StartRxNormInferenceJobResponse.AddMember("JobId", _JobId)

	StartSNOMEDCTInferenceJobRequest_InputDataConfig = StartSNOMEDCTInferenceJobRequest.AddMember("InputDataConfig", InputDataConfig)

	StartSNOMEDCTInferenceJobRequest_OutputDataConfig = StartSNOMEDCTInferenceJobRequest.AddMember("OutputDataConfig", OutputDataConfig)

	StartSNOMEDCTInferenceJobRequest_DataAccessRoleArn = StartSNOMEDCTInferenceJobRequest.AddMember("DataAccessRoleArn", _IamRoleArn)

	StartSNOMEDCTInferenceJobRequest_JobName = StartSNOMEDCTInferenceJobRequest.AddMember("JobName", _JobName)

	StartSNOMEDCTInferenceJobRequest_ClientRequestToken = StartSNOMEDCTInferenceJobRequest.AddMember("ClientRequestToken", _ClientRequestTokenString)

	StartSNOMEDCTInferenceJobRequest_KMSKey = StartSNOMEDCTInferenceJobRequest.AddMember("KMSKey", _KMSKey)

	StartSNOMEDCTInferenceJobRequest_LanguageCode = StartSNOMEDCTInferenceJobRequest.AddMember("LanguageCode", LanguageCode)

	StartSNOMEDCTInferenceJobResponse_JobId = StartSNOMEDCTInferenceJobResponse.AddMember("JobId", _JobId)

	StopEntitiesDetectionV2JobRequest_JobId = StopEntitiesDetectionV2JobRequest.AddMember("JobId", _JobId)

	StopEntitiesDetectionV2JobResponse_JobId = StopEntitiesDetectionV2JobResponse.AddMember("JobId", _JobId)

	StopICD10CMInferenceJobRequest_JobId = StopICD10CMInferenceJobRequest.AddMember("JobId", _JobId)

	StopICD10CMInferenceJobResponse_JobId = StopICD10CMInferenceJobResponse.AddMember("JobId", _JobId)

	StopPHIDetectionJobRequest_JobId = StopPHIDetectionJobRequest.AddMember("JobId", _JobId)

	StopPHIDetectionJobResponse_JobId = StopPHIDetectionJobResponse.AddMember("JobId", _JobId)

	StopRxNormInferenceJobRequest_JobId = StopRxNormInferenceJobRequest.AddMember("JobId", _JobId)

	StopRxNormInferenceJobResponse_JobId = StopRxNormInferenceJobResponse.AddMember("JobId", _JobId)

	StopSNOMEDCTInferenceJobRequest_JobId = StopSNOMEDCTInferenceJobRequest.AddMember("JobId", _JobId)

	StopSNOMEDCTInferenceJobResponse_JobId = StopSNOMEDCTInferenceJobResponse.AddMember("JobId", _JobId)

}
