// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudwatchlogs

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns the storage tier policy for your account.
func (c *Client) GetStorageTierPolicy(ctx context.Context, params *GetStorageTierPolicyInput, optFns ...func(*Options)) (*GetStorageTierPolicyOutput, error) {
	if params == nil {
		params = &GetStorageTierPolicyInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetStorageTierPolicy", params, optFns, c.addOperationGetStorageTierPolicyMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetStorageTierPolicyOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetStorageTierPolicyInput struct {
	noSmithyDocumentSerde
}

type GetStorageTierPolicyOutput struct {

	// The time when the storage tier policy was last updated, expressed as the number
	// of milliseconds after Jan 1, 1970 00:00:00 UTC .
	LastUpdatedTime *int64

	// The current storage tier for the account.
	StorageTier types.StorageTier

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetStorageTierPolicyMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpGetStorageTierPolicy{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpGetStorageTierPolicy{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetStorageTierPolicy"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
