// Code generated by smithy-go-codegen DO NOT EDIT.

package schemas

import (
	smithy "github.com/aws/smithy-go"
	smithyprelude "github.com/aws/smithy-go/prelude"
	smithytraits "github.com/aws/smithy-go/traits"
)

var DatetimeOffsets = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "DatetimeOffsets",
}, smithy.ShapeTypeOperation, 0)

var EmptyInputAndEmptyOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "EmptyInputAndEmptyOutput",
}, smithy.ShapeTypeOperation, 0)

var EndpointOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "EndpointOperation",
}, smithy.ShapeTypeOperation, 0)

var EndpointWithHostLabelOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "EndpointWithHostLabelOperation",
}, smithy.ShapeTypeOperation, 0)

var FractionalSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "FractionalSeconds",
}, smithy.ShapeTypeOperation, 0)

var GreetingWithErrors = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "GreetingWithErrors",
}, smithy.ShapeTypeOperation, 0)

var HostWithPathOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "HostWithPathOperation",
}, smithy.ShapeTypeOperation, 0)

var IgnoresWrappingXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "IgnoresWrappingXmlName",
}, smithy.ShapeTypeOperation, 0)

var NestedStructures = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "NestedStructures",
}, smithy.ShapeTypeOperation, 0)

var NoInputAndOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "NoInputAndOutput",
}, smithy.ShapeTypeOperation, 0)

var PutWithContentEncoding = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "PutWithContentEncoding",
}, smithy.ShapeTypeOperation, 0)

var QueryIdempotencyTokenAutoFill = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "QueryIdempotencyTokenAutoFill",
}, smithy.ShapeTypeOperation, 0)

var QueryLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "QueryLists",
}, smithy.ShapeTypeOperation, 0)

var QueryTimestamps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "QueryTimestamps",
}, smithy.ShapeTypeOperation, 0)

var RecursiveXmlShapes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "RecursiveXmlShapes",
}, smithy.ShapeTypeOperation, 0)

var SimpleInputParams = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "SimpleInputParams",
}, smithy.ShapeTypeOperation, 0)

var SimpleScalarXmlProperties = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "SimpleScalarXmlProperties",
}, smithy.ShapeTypeOperation, 0)

var XmlBlobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlBlobs",
}, smithy.ShapeTypeOperation, 0)

var XmlEmptyBlobs = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlEmptyBlobs",
}, smithy.ShapeTypeOperation, 0)

var XmlEmptyLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlEmptyLists",
}, smithy.ShapeTypeOperation, 0)

var XmlEnums = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlEnums",
}, smithy.ShapeTypeOperation, 0)

var XmlIntEnums = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlIntEnums",
}, smithy.ShapeTypeOperation, 0)

var XmlLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlLists",
}, smithy.ShapeTypeOperation, 0)

var XmlNamespaces = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlNamespaces",
}, smithy.ShapeTypeOperation, 0)

var XmlTimestamps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlTimestamps",
}, smithy.ShapeTypeOperation, 0)

var _AwsEc2 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "AwsEc2",
}, smithy.ShapeTypeService, 0, &smithytraits.XMLNamespace{URI: "https://example.com/"})

var AwsEc2 = smithy.NewServiceSchema(_AwsEc2, "2020-01-08")

var ComplexError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "ComplexError",
}, smithy.ShapeTypeStructure, 2)
var ComplexError_TopLevel *smithy.Schema

var ComplexError_Nested *smithy.Schema

var ComplexNestedErrorData = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "ComplexNestedErrorData",
}, smithy.ShapeTypeStructure, 1)
var ComplexNestedErrorData_Foo *smithy.Schema

var InvalidGreeting = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "InvalidGreeting",
}, smithy.ShapeTypeStructure, 1)
var InvalidGreeting_Message *smithy.Schema

var _ListWithMemberNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "ListWithMemberNamespace",
}, smithy.ShapeTypeList, 1, &smithytraits.XMLNamespace{URI: "https://xml-list.example.com"})
var _ListWithMemberNamespace_member *smithy.Schema

var _ListWithNamespace = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "ListWithNamespace",
}, smithy.ShapeTypeList, 1, &smithytraits.XMLNamespace{URI: "https://xml-list.example.com"})
var _ListWithNamespace_member *smithy.Schema

var _ListWithXmlName = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "ListWithXmlName",
}, smithy.ShapeTypeList, 1)
var _ListWithXmlName_member *smithy.Schema

var NestedStructWithList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "NestedStructWithList",
}, smithy.ShapeTypeStructure, 1)
var NestedStructWithList_ListArg *smithy.Schema

var RecursiveXmlShapesOutputNested1 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "RecursiveXmlShapesOutputNested1",
}, smithy.ShapeTypeStructure, 2)
var RecursiveXmlShapesOutputNested1_foo *smithy.Schema

var RecursiveXmlShapesOutputNested1_nested *smithy.Schema

var RecursiveXmlShapesOutputNested2 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "RecursiveXmlShapesOutputNested2",
}, smithy.ShapeTypeStructure, 2)
var RecursiveXmlShapesOutputNested2_bar *smithy.Schema

var RecursiveXmlShapesOutputNested2_recursiveMember *smithy.Schema

var _RenamedListMembers = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "RenamedListMembers",
}, smithy.ShapeTypeList, 1)
var _RenamedListMembers_member *smithy.Schema

var StructArg = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "StructArg",
}, smithy.ShapeTypeStructure, 3)
var StructArg_StringArg *smithy.Schema

var StructArg_OtherArg *smithy.Schema

var StructArg_RecursiveArg *smithy.Schema

var _StructureList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "StructureList",
}, smithy.ShapeTypeList, 1)
var _StructureList_member *smithy.Schema

var StructureListMember = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "StructureListMember",
}, smithy.ShapeTypeStructure, 2)
var StructureListMember_a *smithy.Schema

var StructureListMember_b *smithy.Schema

var _XmlNamespacedList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlNamespacedList",
}, smithy.ShapeTypeList, 1)
var _XmlNamespacedList_member *smithy.Schema

var XmlNamespaceNested = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlNamespaceNested",
}, smithy.ShapeTypeStructure, 2, &smithytraits.XMLNamespace{URI: "http://foo.com"})
var XmlNamespaceNested_foo *smithy.Schema

var XmlNamespaceNested_values *smithy.Schema

var _BooleanList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "BooleanList",
}, smithy.ShapeTypeList, 1)
var _BooleanList_member *smithy.Schema

var _DateTime = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "DateTime",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "date-time"})

var _EpochSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "EpochSeconds",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

var FooEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnum",
}, smithy.ShapeTypeEnum, 5)
var FooEnum_FOO *smithy.Schema

var FooEnum_BAZ *smithy.Schema

var FooEnum_BAR *smithy.Schema

var FooEnum_ONE *smithy.Schema

var FooEnum_ZERO *smithy.Schema

var _FooEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumList",
}, smithy.ShapeTypeList, 1)
var _FooEnumList_member *smithy.Schema

var _FooEnumMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumMap",
}, smithy.ShapeTypeMap, 2)
var _FooEnumMap_key *smithy.Schema

var _FooEnumMap_value *smithy.Schema

var _FooEnumSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "FooEnumSet",
}, smithy.ShapeTypeList, 1)
var _FooEnumSet_member *smithy.Schema

var _GreetingList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "GreetingList",
}, smithy.ShapeTypeList, 1)
var _GreetingList_member *smithy.Schema

var GreetingStruct = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "GreetingStruct",
}, smithy.ShapeTypeStructure, 1)
var GreetingStruct_hi *smithy.Schema

var _HttpDate = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "HttpDate",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "http-date"})

var _IntegerEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnum",
}, smithy.ShapeTypeIntEnum, 3)
var _IntegerEnum_A *smithy.Schema

var _IntegerEnum_B *smithy.Schema

var _IntegerEnum_C *smithy.Schema

var _IntegerEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumList",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumList_member *smithy.Schema

var _IntegerEnumMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumMap",
}, smithy.ShapeTypeMap, 2)
var _IntegerEnumMap_key *smithy.Schema

var _IntegerEnumMap_value *smithy.Schema

var _IntegerEnumSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerEnumSet",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumSet_member *smithy.Schema

var _IntegerList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "IntegerList",
}, smithy.ShapeTypeList, 1)
var _IntegerList_member *smithy.Schema

var _NestedStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "NestedStringList",
}, smithy.ShapeTypeList, 1)
var _NestedStringList_member *smithy.Schema

var _StringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringList",
}, smithy.ShapeTypeList, 1)
var _StringList_member *smithy.Schema

var _StringSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "StringSet",
}, smithy.ShapeTypeList, 1)
var _StringSet_member *smithy.Schema

var _TimestampList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.shared",
	Name:      "TimestampList",
}, smithy.ShapeTypeList, 1)
var _TimestampList_member *smithy.Schema

var DatetimeOffsetsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "DatetimeOffsetsOutput",
}, smithy.ShapeTypeStructure, 1)
var DatetimeOffsetsOutput_datetime *smithy.Schema

var EmptyInputAndEmptyOutputInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "EmptyInputAndEmptyOutputInput",
}, smithy.ShapeTypeStructure, 0)

var EmptyInputAndEmptyOutputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "EmptyInputAndEmptyOutputOutput",
}, smithy.ShapeTypeStructure, 0)

var HostLabelInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "HostLabelInput",
}, smithy.ShapeTypeStructure, 1)
var HostLabelInput_label *smithy.Schema

var FractionalSecondsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "FractionalSecondsOutput",
}, smithy.ShapeTypeStructure, 1)
var FractionalSecondsOutput_datetime *smithy.Schema

var GreetingWithErrorsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "GreetingWithErrorsOutput",
}, smithy.ShapeTypeStructure, 1)
var GreetingWithErrorsOutput_greeting *smithy.Schema

var IgnoresWrappingXmlNameOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "IgnoresWrappingXmlNameOutput",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLName{Name: "IgnoreMe"})
var IgnoresWrappingXmlNameOutput_foo *smithy.Schema

var NestedStructuresInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "NestedStructuresInput",
}, smithy.ShapeTypeStructure, 1)
var NestedStructuresInput_Nested *smithy.Schema

var NoInputAndOutputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "NoInputAndOutputOutput",
}, smithy.ShapeTypeStructure, 0)

var PutWithContentEncodingInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "PutWithContentEncodingInput",
}, smithy.ShapeTypeStructure, 2)
var PutWithContentEncodingInput_encoding *smithy.Schema

var PutWithContentEncodingInput_data *smithy.Schema

var QueryIdempotencyTokenAutoFillInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "QueryIdempotencyTokenAutoFillInput",
}, smithy.ShapeTypeStructure, 1)
var QueryIdempotencyTokenAutoFillInput_token *smithy.Schema

var QueryListsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "QueryListsInput",
}, smithy.ShapeTypeStructure, 5)
var QueryListsInput_ListArg *smithy.Schema

var QueryListsInput_ComplexListArg *smithy.Schema

var QueryListsInput_ListArgWithXmlNameMember *smithy.Schema

var QueryListsInput_ListArgWithXmlName *smithy.Schema

var QueryListsInput_NestedWithList *smithy.Schema

var QueryTimestampsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "QueryTimestampsInput",
}, smithy.ShapeTypeStructure, 3)
var QueryTimestampsInput_normalFormat *smithy.Schema

var QueryTimestampsInput_epochMember *smithy.Schema

var QueryTimestampsInput_epochTarget *smithy.Schema

var RecursiveXmlShapesOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "RecursiveXmlShapesOutput",
}, smithy.ShapeTypeStructure, 1)
var RecursiveXmlShapesOutput_nested *smithy.Schema

var SimpleInputParamsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "SimpleInputParamsInput",
}, smithy.ShapeTypeStructure, 14)
var SimpleInputParamsInput_Foo *smithy.Schema

var SimpleInputParamsInput_Bar *smithy.Schema

var SimpleInputParamsInput_Baz *smithy.Schema

var SimpleInputParamsInput_Bam *smithy.Schema

var SimpleInputParamsInput_FloatValue *smithy.Schema

var SimpleInputParamsInput_Boo *smithy.Schema

var SimpleInputParamsInput_Qux *smithy.Schema

var SimpleInputParamsInput_FooEnum *smithy.Schema

var SimpleInputParamsInput_HasQueryName *smithy.Schema

var SimpleInputParamsInput_HasQueryAndXmlName *smithy.Schema

var SimpleInputParamsInput_UsesXmlName *smithy.Schema

var SimpleInputParamsInput_DistinctQueryName *smithy.Schema

var SimpleInputParamsInput_DistinctQueryAndXmlName *smithy.Schema

var SimpleInputParamsInput_DistinctXmlName *smithy.Schema

var SimpleScalarXmlPropertiesOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "SimpleScalarXmlPropertiesOutput",
}, smithy.ShapeTypeStructure, 10)
var SimpleScalarXmlPropertiesOutput_stringValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_emptyStringValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_trueBooleanValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_falseBooleanValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_byteValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_shortValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_integerValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_longValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_floatValue *smithy.Schema

var SimpleScalarXmlPropertiesOutput_doubleValue *smithy.Schema

var XmlBlobsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlBlobsOutput",
}, smithy.ShapeTypeStructure, 1)
var XmlBlobsOutput_data *smithy.Schema

var XmlListsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlListsOutput",
}, smithy.ShapeTypeStructure, 14)
var XmlListsOutput_stringList *smithy.Schema

var XmlListsOutput_stringSet *smithy.Schema

var XmlListsOutput_integerList *smithy.Schema

var XmlListsOutput_booleanList *smithy.Schema

var XmlListsOutput_timestampList *smithy.Schema

var XmlListsOutput_enumList *smithy.Schema

var XmlListsOutput_intEnumList *smithy.Schema

var XmlListsOutput_nestedStringList *smithy.Schema

var XmlListsOutput_renamedListMembers *smithy.Schema

var XmlListsOutput_flattenedList *smithy.Schema

var XmlListsOutput_flattenedList2 *smithy.Schema

var XmlListsOutput_flattenedListWithMemberNamespace *smithy.Schema

var XmlListsOutput_flattenedListWithNamespace *smithy.Schema

var XmlListsOutput_structureList *smithy.Schema

var XmlEnumsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlEnumsOutput",
}, smithy.ShapeTypeStructure, 6)
var XmlEnumsOutput_fooEnum1 *smithy.Schema

var XmlEnumsOutput_fooEnum2 *smithy.Schema

var XmlEnumsOutput_fooEnum3 *smithy.Schema

var XmlEnumsOutput_fooEnumList *smithy.Schema

var XmlEnumsOutput_fooEnumSet *smithy.Schema

var XmlEnumsOutput_fooEnumMap *smithy.Schema

var XmlIntEnumsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlIntEnumsOutput",
}, smithy.ShapeTypeStructure, 6)
var XmlIntEnumsOutput_intEnum1 *smithy.Schema

var XmlIntEnumsOutput_intEnum2 *smithy.Schema

var XmlIntEnumsOutput_intEnum3 *smithy.Schema

var XmlIntEnumsOutput_intEnumList *smithy.Schema

var XmlIntEnumsOutput_intEnumSet *smithy.Schema

var XmlIntEnumsOutput_intEnumMap *smithy.Schema

var XmlNamespacesOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlNamespacesOutput",
}, smithy.ShapeTypeStructure, 1, &smithytraits.XMLNamespace{URI: "http://foo.com"})
var XmlNamespacesOutput_nested *smithy.Schema

var XmlTimestampsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "aws.protocoltests.ec2",
	Name:      "XmlTimestampsOutput",
}, smithy.ShapeTypeStructure, 7)
var XmlTimestampsOutput_normal *smithy.Schema

var XmlTimestampsOutput_dateTime *smithy.Schema

var XmlTimestampsOutput_dateTimeOnTarget *smithy.Schema

var XmlTimestampsOutput_epochSeconds *smithy.Schema

var XmlTimestampsOutput_epochSecondsOnTarget *smithy.Schema

var XmlTimestampsOutput_httpDate *smithy.Schema

var XmlTimestampsOutput_httpDateOnTarget *smithy.Schema

// Initialize schema members after all schemas are declared to avoid
// initialization cycles
func init() {
	ComplexNestedErrorData_Foo = ComplexNestedErrorData.AddMember("Foo", smithyprelude.String)

	ComplexError_TopLevel = ComplexError.AddMember("TopLevel", smithyprelude.String)

	ComplexError_Nested = ComplexError.AddMember("Nested", ComplexNestedErrorData)

	InvalidGreeting_Message = InvalidGreeting.AddMember("Message", smithyprelude.String)

	_ListWithMemberNamespace_member = _ListWithMemberNamespace.AddMember("member", smithyprelude.String, &smithytraits.XMLNamespace{URI: "https://xml-member.example.com"})

	_ListWithNamespace_member = _ListWithNamespace.AddMember("member", smithyprelude.String)

	_ListWithXmlName_member = _ListWithXmlName.AddMember("member", smithyprelude.String, &smithytraits.XMLName{Name: "item"})

	_StringList_member = _StringList.AddMember("member", smithyprelude.String)

	NestedStructWithList_ListArg = NestedStructWithList.AddMember("ListArg", _StringList)

	RecursiveXmlShapesOutputNested2_bar = RecursiveXmlShapesOutputNested2.AddMember("bar", smithyprelude.String)

	RecursiveXmlShapesOutputNested2_recursiveMember = RecursiveXmlShapesOutputNested2.AddMember("recursiveMember", RecursiveXmlShapesOutputNested1)

	RecursiveXmlShapesOutputNested1_foo = RecursiveXmlShapesOutputNested1.AddMember("foo", smithyprelude.String)

	RecursiveXmlShapesOutputNested1_nested = RecursiveXmlShapesOutputNested1.AddMember("nested", RecursiveXmlShapesOutputNested2)

	_RenamedListMembers_member = _RenamedListMembers.AddMember("member", smithyprelude.String, &smithytraits.XMLName{Name: "item"})

	StructArg_StringArg = StructArg.AddMember("StringArg", smithyprelude.String)

	StructArg_OtherArg = StructArg.AddMember("OtherArg", smithyprelude.Boolean)

	StructArg_RecursiveArg = StructArg.AddMember("RecursiveArg", StructArg)

	StructureListMember_a = StructureListMember.AddMember("a", smithyprelude.String, &smithytraits.XMLName{Name: "value"})

	StructureListMember_b = StructureListMember.AddMember("b", smithyprelude.String, &smithytraits.XMLName{Name: "other"})

	_StructureList_member = _StructureList.AddMember("member", StructureListMember, &smithytraits.XMLName{Name: "item"})

	_XmlNamespacedList_member = _XmlNamespacedList.AddMember("member", smithyprelude.String, &smithytraits.XMLNamespace{URI: "http://bux.com"})

	XmlNamespaceNested_foo = XmlNamespaceNested.AddMember("foo", smithyprelude.String, &smithytraits.XMLNamespace{URI: "http://baz.com",
		Prefix: "baz"})

	XmlNamespaceNested_values = XmlNamespaceNested.AddMember("values", _XmlNamespacedList, &smithytraits.XMLNamespace{URI: "http://qux.com"})

	_BooleanList_member = _BooleanList.AddMember("member", smithyprelude.Boolean)

	FooEnum_FOO = FooEnum.AddMember("FOO", smithyprelude.Unit)

	FooEnum_BAZ = FooEnum.AddMember("BAZ", smithyprelude.Unit)

	FooEnum_BAR = FooEnum.AddMember("BAR", smithyprelude.Unit)

	FooEnum_ONE = FooEnum.AddMember("ONE", smithyprelude.Unit)

	FooEnum_ZERO = FooEnum.AddMember("ZERO", smithyprelude.Unit)

	_FooEnumList_member = _FooEnumList.AddMember("member", FooEnum)

	_FooEnumMap_key = _FooEnumMap.AddMember("key", smithyprelude.String)

	_FooEnumMap_value = _FooEnumMap.AddMember("value", FooEnum)

	_FooEnumSet_member = _FooEnumSet.AddMember("member", FooEnum)

	GreetingStruct_hi = GreetingStruct.AddMember("hi", smithyprelude.String)

	_GreetingList_member = _GreetingList.AddMember("member", GreetingStruct)

	_IntegerEnum_A = _IntegerEnum.AddMember("A", smithyprelude.Unit)

	_IntegerEnum_B = _IntegerEnum.AddMember("B", smithyprelude.Unit)

	_IntegerEnum_C = _IntegerEnum.AddMember("C", smithyprelude.Unit)

	_IntegerEnumList_member = _IntegerEnumList.AddMember("member", _IntegerEnum)

	_IntegerEnumMap_key = _IntegerEnumMap.AddMember("key", smithyprelude.String)

	_IntegerEnumMap_value = _IntegerEnumMap.AddMember("value", _IntegerEnum)

	_IntegerEnumSet_member = _IntegerEnumSet.AddMember("member", _IntegerEnum)

	_IntegerList_member = _IntegerList.AddMember("member", smithyprelude.Integer)

	_NestedStringList_member = _NestedStringList.AddMember("member", _StringList)

	_StringSet_member = _StringSet.AddMember("member", smithyprelude.String)

	_TimestampList_member = _TimestampList.AddMember("member", smithyprelude.Timestamp)

	DatetimeOffsetsOutput_datetime = DatetimeOffsetsOutput.AddMember("datetime", _DateTime)

	HostLabelInput_label = HostLabelInput.AddMember("label", smithyprelude.String, &smithytraits.HostLabel{})

	FractionalSecondsOutput_datetime = FractionalSecondsOutput.AddMember("datetime", _DateTime)

	GreetingWithErrorsOutput_greeting = GreetingWithErrorsOutput.AddMember("greeting", smithyprelude.String)

	IgnoresWrappingXmlNameOutput_foo = IgnoresWrappingXmlNameOutput.AddMember("foo", smithyprelude.String)

	NestedStructuresInput_Nested = NestedStructuresInput.AddMember("Nested", StructArg)

	PutWithContentEncodingInput_encoding = PutWithContentEncodingInput.AddMember("encoding", smithyprelude.String, &smithytraits.HTTPHeader{Name: "Content-Encoding"})

	PutWithContentEncodingInput_data = PutWithContentEncodingInput.AddMember("data", smithyprelude.String)

	QueryIdempotencyTokenAutoFillInput_token = QueryIdempotencyTokenAutoFillInput.AddMember("token", smithyprelude.String)

	QueryListsInput_ListArg = QueryListsInput.AddMember("ListArg", _StringList)

	QueryListsInput_ComplexListArg = QueryListsInput.AddMember("ComplexListArg", _GreetingList)

	QueryListsInput_ListArgWithXmlNameMember = QueryListsInput.AddMember("ListArgWithXmlNameMember", _ListWithXmlName)

	QueryListsInput_ListArgWithXmlName = QueryListsInput.AddMember("ListArgWithXmlName", _ListWithXmlName, &smithytraits.XMLName{Name: "Hi"})

	QueryListsInput_NestedWithList = QueryListsInput.AddMember("NestedWithList", NestedStructWithList)

	QueryTimestampsInput_normalFormat = QueryTimestampsInput.AddMember("normalFormat", smithyprelude.Timestamp)

	QueryTimestampsInput_epochMember = QueryTimestampsInput.AddMember("epochMember", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

	QueryTimestampsInput_epochTarget = QueryTimestampsInput.AddMember("epochTarget", _EpochSeconds)

	RecursiveXmlShapesOutput_nested = RecursiveXmlShapesOutput.AddMember("nested", RecursiveXmlShapesOutputNested1)

	SimpleInputParamsInput_Foo = SimpleInputParamsInput.AddMember("Foo", smithyprelude.String)

	SimpleInputParamsInput_Bar = SimpleInputParamsInput.AddMember("Bar", smithyprelude.String)

	SimpleInputParamsInput_Baz = SimpleInputParamsInput.AddMember("Baz", smithyprelude.Boolean)

	SimpleInputParamsInput_Bam = SimpleInputParamsInput.AddMember("Bam", smithyprelude.Integer)

	SimpleInputParamsInput_FloatValue = SimpleInputParamsInput.AddMember("FloatValue", smithyprelude.Float)

	SimpleInputParamsInput_Boo = SimpleInputParamsInput.AddMember("Boo", smithyprelude.Double)

	SimpleInputParamsInput_Qux = SimpleInputParamsInput.AddMember("Qux", smithyprelude.Blob)

	SimpleInputParamsInput_FooEnum = SimpleInputParamsInput.AddMember("FooEnum", FooEnum)

	SimpleInputParamsInput_HasQueryName = SimpleInputParamsInput.AddMember("HasQueryName", smithyprelude.String, &smithytraits.EC2QueryName{Name: "HasQueryName"})

	SimpleInputParamsInput_HasQueryAndXmlName = SimpleInputParamsInput.AddMember("HasQueryAndXmlName", smithyprelude.String, &smithytraits.EC2QueryName{Name: "HasQueryAndXmlName"},
		&smithytraits.XMLName{Name: "hasQueryAndXmlName"})

	SimpleInputParamsInput_UsesXmlName = SimpleInputParamsInput.AddMember("UsesXmlName", smithyprelude.String, &smithytraits.XMLName{Name: "usesXmlName"})

	SimpleInputParamsInput_DistinctQueryName = SimpleInputParamsInput.AddMember("DistinctQueryName", smithyprelude.String, &smithytraits.EC2QueryName{Name: "QueryName"})

	SimpleInputParamsInput_DistinctQueryAndXmlName = SimpleInputParamsInput.AddMember("DistinctQueryAndXmlName", smithyprelude.String, &smithytraits.EC2QueryName{Name: "queryAndXmlName"},
		&smithytraits.XMLName{Name: "xmlAndQueryName"})

	SimpleInputParamsInput_DistinctXmlName = SimpleInputParamsInput.AddMember("DistinctXmlName", smithyprelude.String, &smithytraits.XMLName{Name: "xmlNameOnly"})

	SimpleScalarXmlPropertiesOutput_stringValue = SimpleScalarXmlPropertiesOutput.AddMember("stringValue", smithyprelude.String, &smithytraits.EC2QueryName{Name: "IgnoreMe"})

	SimpleScalarXmlPropertiesOutput_emptyStringValue = SimpleScalarXmlPropertiesOutput.AddMember("emptyStringValue", smithyprelude.String)

	SimpleScalarXmlPropertiesOutput_trueBooleanValue = SimpleScalarXmlPropertiesOutput.AddMember("trueBooleanValue", smithyprelude.Boolean)

	SimpleScalarXmlPropertiesOutput_falseBooleanValue = SimpleScalarXmlPropertiesOutput.AddMember("falseBooleanValue", smithyprelude.Boolean)

	SimpleScalarXmlPropertiesOutput_byteValue = SimpleScalarXmlPropertiesOutput.AddMember("byteValue", smithyprelude.Byte)

	SimpleScalarXmlPropertiesOutput_shortValue = SimpleScalarXmlPropertiesOutput.AddMember("shortValue", smithyprelude.Short)

	SimpleScalarXmlPropertiesOutput_integerValue = SimpleScalarXmlPropertiesOutput.AddMember("integerValue", smithyprelude.Integer)

	SimpleScalarXmlPropertiesOutput_longValue = SimpleScalarXmlPropertiesOutput.AddMember("longValue", smithyprelude.Long)

	SimpleScalarXmlPropertiesOutput_floatValue = SimpleScalarXmlPropertiesOutput.AddMember("floatValue", smithyprelude.Float)

	SimpleScalarXmlPropertiesOutput_doubleValue = SimpleScalarXmlPropertiesOutput.AddMember("doubleValue", smithyprelude.Double, &smithytraits.XMLName{Name: "DoubleDribble"})

	XmlBlobsOutput_data = XmlBlobsOutput.AddMember("data", smithyprelude.Blob)

	XmlListsOutput_stringList = XmlListsOutput.AddMember("stringList", _StringList)

	XmlListsOutput_stringSet = XmlListsOutput.AddMember("stringSet", _StringSet)

	XmlListsOutput_integerList = XmlListsOutput.AddMember("integerList", _IntegerList)

	XmlListsOutput_booleanList = XmlListsOutput.AddMember("booleanList", _BooleanList)

	XmlListsOutput_timestampList = XmlListsOutput.AddMember("timestampList", _TimestampList)

	XmlListsOutput_enumList = XmlListsOutput.AddMember("enumList", _FooEnumList)

	XmlListsOutput_intEnumList = XmlListsOutput.AddMember("intEnumList", _IntegerEnumList)

	XmlListsOutput_nestedStringList = XmlListsOutput.AddMember("nestedStringList", _NestedStringList)

	XmlListsOutput_renamedListMembers = XmlListsOutput.AddMember("renamedListMembers", _RenamedListMembers, &smithytraits.XMLName{Name: "renamed"})

	XmlListsOutput_flattenedList = XmlListsOutput.AddMember("flattenedList", _RenamedListMembers, &smithytraits.XMLFlattened{})

	XmlListsOutput_flattenedList2 = XmlListsOutput.AddMember("flattenedList2", _RenamedListMembers, &smithytraits.XMLName{Name: "customName"},
		&smithytraits.XMLFlattened{})

	XmlListsOutput_flattenedListWithMemberNamespace = XmlListsOutput.AddMember("flattenedListWithMemberNamespace", _ListWithMemberNamespace, &smithytraits.XMLFlattened{})

	XmlListsOutput_flattenedListWithNamespace = XmlListsOutput.AddMember("flattenedListWithNamespace", _ListWithNamespace, &smithytraits.XMLFlattened{})

	XmlListsOutput_structureList = XmlListsOutput.AddMember("structureList", _StructureList, &smithytraits.XMLName{Name: "myStructureList"})

	XmlEnumsOutput_fooEnum1 = XmlEnumsOutput.AddMember("fooEnum1", FooEnum)

	XmlEnumsOutput_fooEnum2 = XmlEnumsOutput.AddMember("fooEnum2", FooEnum)

	XmlEnumsOutput_fooEnum3 = XmlEnumsOutput.AddMember("fooEnum3", FooEnum)

	XmlEnumsOutput_fooEnumList = XmlEnumsOutput.AddMember("fooEnumList", _FooEnumList)

	XmlEnumsOutput_fooEnumSet = XmlEnumsOutput.AddMember("fooEnumSet", _FooEnumSet)

	XmlEnumsOutput_fooEnumMap = XmlEnumsOutput.AddMember("fooEnumMap", _FooEnumMap)

	XmlIntEnumsOutput_intEnum1 = XmlIntEnumsOutput.AddMember("intEnum1", _IntegerEnum)

	XmlIntEnumsOutput_intEnum2 = XmlIntEnumsOutput.AddMember("intEnum2", _IntegerEnum)

	XmlIntEnumsOutput_intEnum3 = XmlIntEnumsOutput.AddMember("intEnum3", _IntegerEnum)

	XmlIntEnumsOutput_intEnumList = XmlIntEnumsOutput.AddMember("intEnumList", _IntegerEnumList)

	XmlIntEnumsOutput_intEnumSet = XmlIntEnumsOutput.AddMember("intEnumSet", _IntegerEnumSet)

	XmlIntEnumsOutput_intEnumMap = XmlIntEnumsOutput.AddMember("intEnumMap", _IntegerEnumMap)

	XmlNamespacesOutput_nested = XmlNamespacesOutput.AddMember("nested", XmlNamespaceNested)

	XmlTimestampsOutput_normal = XmlTimestampsOutput.AddMember("normal", smithyprelude.Timestamp)

	XmlTimestampsOutput_dateTime = XmlTimestampsOutput.AddMember("dateTime", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "date-time"})

	XmlTimestampsOutput_dateTimeOnTarget = XmlTimestampsOutput.AddMember("dateTimeOnTarget", _DateTime)

	XmlTimestampsOutput_epochSeconds = XmlTimestampsOutput.AddMember("epochSeconds", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "epoch-seconds"})

	XmlTimestampsOutput_epochSecondsOnTarget = XmlTimestampsOutput.AddMember("epochSecondsOnTarget", _EpochSeconds)

	XmlTimestampsOutput_httpDate = XmlTimestampsOutput.AddMember("httpDate", smithyprelude.Timestamp, &smithytraits.TimestampFormat{Format: "http-date"})

	XmlTimestampsOutput_httpDateOnTarget = XmlTimestampsOutput.AddMember("httpDateOnTarget", _HttpDate)

}
