// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanroomsml

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanroomsml/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Returns information about a specific ML configuration.
func (c *Client) GetMLConfiguration(ctx context.Context, params *GetMLConfigurationInput, optFns ...func(*Options)) (*GetMLConfigurationOutput, error) {
	if params == nil {
		params = &GetMLConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetMLConfiguration", params, optFns, c.addOperationGetMLConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetMLConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetMLConfigurationInput struct {

	// The membership ID of the member that owns the ML configuration you want to
	// return information about.
	//
	// This member is required.
	MembershipIdentifier *string

	noSmithyDocumentSerde
}

type GetMLConfigurationOutput struct {

	// The time at which the ML configuration was created.
	//
	// This member is required.
	CreateTime *time.Time

	// The Amazon S3 location where ML model output is stored.
	//
	// This member is required.
	DefaultOutputLocation *types.MLOutputConfiguration

	// The membership ID of the member that owns the ML configuration you requested.
	//
	// This member is required.
	MembershipIdentifier *string

	// The most recent time at which the ML configuration was updated.
	//
	// This member is required.
	UpdateTime *time.Time

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetMLConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetMLConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetMLConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetMLConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetMLConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
