// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type ActorTokenContentType string

// Enum values for ActorTokenContentType
const (
	ActorTokenContentTypeNone             ActorTokenContentType = "NONE"
	ActorTokenContentTypeM2m              ActorTokenContentType = "M2M"
	ActorTokenContentTypeAwsIamIdTokenJwt ActorTokenContentType = "AWS_IAM_ID_TOKEN_JWT"
)

// Values returns all known values for ActorTokenContentType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ActorTokenContentType) Values() []ActorTokenContentType {
	return []ActorTokenContentType{
		"NONE",
		"M2M",
		"AWS_IAM_ID_TOKEN_JWT",
	}
}

type AgentManagedRuntimeType string

// Enum values for AgentManagedRuntimeType
const (
	AgentManagedRuntimeTypePython310 AgentManagedRuntimeType = "PYTHON_3_10"
	AgentManagedRuntimeTypePython311 AgentManagedRuntimeType = "PYTHON_3_11"
	AgentManagedRuntimeTypePython312 AgentManagedRuntimeType = "PYTHON_3_12"
	AgentManagedRuntimeTypePython313 AgentManagedRuntimeType = "PYTHON_3_13"
	AgentManagedRuntimeTypePython314 AgentManagedRuntimeType = "PYTHON_3_14"
	AgentManagedRuntimeTypeNode22    AgentManagedRuntimeType = "NODE_22"
)

// Values returns all known values for AgentManagedRuntimeType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AgentManagedRuntimeType) Values() []AgentManagedRuntimeType {
	return []AgentManagedRuntimeType{
		"PYTHON_3_10",
		"PYTHON_3_11",
		"PYTHON_3_12",
		"PYTHON_3_13",
		"PYTHON_3_14",
		"NODE_22",
	}
}

type AgentRuntimeEndpointStatus string

// Enum values for AgentRuntimeEndpointStatus
const (
	AgentRuntimeEndpointStatusCreating     AgentRuntimeEndpointStatus = "CREATING"
	AgentRuntimeEndpointStatusCreateFailed AgentRuntimeEndpointStatus = "CREATE_FAILED"
	AgentRuntimeEndpointStatusUpdating     AgentRuntimeEndpointStatus = "UPDATING"
	AgentRuntimeEndpointStatusUpdateFailed AgentRuntimeEndpointStatus = "UPDATE_FAILED"
	AgentRuntimeEndpointStatusReady        AgentRuntimeEndpointStatus = "READY"
	AgentRuntimeEndpointStatusDeleting     AgentRuntimeEndpointStatus = "DELETING"
)

// Values returns all known values for AgentRuntimeEndpointStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AgentRuntimeEndpointStatus) Values() []AgentRuntimeEndpointStatus {
	return []AgentRuntimeEndpointStatus{
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"READY",
		"DELETING",
	}
}

type AgentRuntimeStatus string

// Enum values for AgentRuntimeStatus
const (
	AgentRuntimeStatusCreating     AgentRuntimeStatus = "CREATING"
	AgentRuntimeStatusCreateFailed AgentRuntimeStatus = "CREATE_FAILED"
	AgentRuntimeStatusUpdating     AgentRuntimeStatus = "UPDATING"
	AgentRuntimeStatusUpdateFailed AgentRuntimeStatus = "UPDATE_FAILED"
	AgentRuntimeStatusReady        AgentRuntimeStatus = "READY"
	AgentRuntimeStatusDeleting     AgentRuntimeStatus = "DELETING"
)

// Values returns all known values for AgentRuntimeStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AgentRuntimeStatus) Values() []AgentRuntimeStatus {
	return []AgentRuntimeStatus{
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"READY",
		"DELETING",
	}
}

type ApiKeyCredentialLocation string

// Enum values for ApiKeyCredentialLocation
const (
	ApiKeyCredentialLocationHeader         ApiKeyCredentialLocation = "HEADER"
	ApiKeyCredentialLocationQueryParameter ApiKeyCredentialLocation = "QUERY_PARAMETER"
)

// Values returns all known values for ApiKeyCredentialLocation. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ApiKeyCredentialLocation) Values() []ApiKeyCredentialLocation {
	return []ApiKeyCredentialLocation{
		"HEADER",
		"QUERY_PARAMETER",
	}
}

type AuthorizerType string

// Enum values for AuthorizerType
const (
	AuthorizerTypeCustomJwt        AuthorizerType = "CUSTOM_JWT"
	AuthorizerTypeAwsIam           AuthorizerType = "AWS_IAM"
	AuthorizerTypeNone             AuthorizerType = "NONE"
	AuthorizerTypeAuthenticateOnly AuthorizerType = "AUTHENTICATE_ONLY"
)

// Values returns all known values for AuthorizerType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AuthorizerType) Values() []AuthorizerType {
	return []AuthorizerType{
		"CUSTOM_JWT",
		"AWS_IAM",
		"NONE",
		"AUTHENTICATE_ONLY",
	}
}

type BrowserEnterprisePolicyType string

// Enum values for BrowserEnterprisePolicyType
const (
	BrowserEnterprisePolicyTypeManaged     BrowserEnterprisePolicyType = "MANAGED"
	BrowserEnterprisePolicyTypeRecommended BrowserEnterprisePolicyType = "RECOMMENDED"
)

// Values returns all known values for BrowserEnterprisePolicyType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserEnterprisePolicyType) Values() []BrowserEnterprisePolicyType {
	return []BrowserEnterprisePolicyType{
		"MANAGED",
		"RECOMMENDED",
	}
}

type BrowserNetworkMode string

// Enum values for BrowserNetworkMode
const (
	BrowserNetworkModePublic BrowserNetworkMode = "PUBLIC"
	BrowserNetworkModeVpc    BrowserNetworkMode = "VPC"
)

// Values returns all known values for BrowserNetworkMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserNetworkMode) Values() []BrowserNetworkMode {
	return []BrowserNetworkMode{
		"PUBLIC",
		"VPC",
	}
}

type BrowserProfileStatus string

// Enum values for BrowserProfileStatus
const (
	BrowserProfileStatusReady    BrowserProfileStatus = "READY"
	BrowserProfileStatusDeleting BrowserProfileStatus = "DELETING"
	BrowserProfileStatusDeleted  BrowserProfileStatus = "DELETED"
	BrowserProfileStatusSaving   BrowserProfileStatus = "SAVING"
)

// Values returns all known values for BrowserProfileStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserProfileStatus) Values() []BrowserProfileStatus {
	return []BrowserProfileStatus{
		"READY",
		"DELETING",
		"DELETED",
		"SAVING",
	}
}

type BrowserStatus string

// Enum values for BrowserStatus
const (
	BrowserStatusCreating     BrowserStatus = "CREATING"
	BrowserStatusCreateFailed BrowserStatus = "CREATE_FAILED"
	BrowserStatusReady        BrowserStatus = "READY"
	BrowserStatusDeleting     BrowserStatus = "DELETING"
	BrowserStatusDeleteFailed BrowserStatus = "DELETE_FAILED"
	BrowserStatusDeleted      BrowserStatus = "DELETED"
)

// Values returns all known values for BrowserStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BrowserStatus) Values() []BrowserStatus {
	return []BrowserStatus{
		"CREATING",
		"CREATE_FAILED",
		"READY",
		"DELETING",
		"DELETE_FAILED",
		"DELETED",
	}
}

type ClaimMatchOperatorType string

// Enum values for ClaimMatchOperatorType
const (
	ClaimMatchOperatorTypeEquals      ClaimMatchOperatorType = "EQUALS"
	ClaimMatchOperatorTypeContains    ClaimMatchOperatorType = "CONTAINS"
	ClaimMatchOperatorTypeContainsAny ClaimMatchOperatorType = "CONTAINS_ANY"
)

// Values returns all known values for ClaimMatchOperatorType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ClaimMatchOperatorType) Values() []ClaimMatchOperatorType {
	return []ClaimMatchOperatorType{
		"EQUALS",
		"CONTAINS",
		"CONTAINS_ANY",
	}
}

type ClientAuthenticationMethodType string

// Enum values for ClientAuthenticationMethodType
const (
	ClientAuthenticationMethodTypeClientSecretBasic ClientAuthenticationMethodType = "CLIENT_SECRET_BASIC"
	ClientAuthenticationMethodTypeClientSecretPost  ClientAuthenticationMethodType = "CLIENT_SECRET_POST"
	ClientAuthenticationMethodTypeAwsIamIdTokenJwt  ClientAuthenticationMethodType = "AWS_IAM_ID_TOKEN_JWT"
)

// Values returns all known values for ClientAuthenticationMethodType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ClientAuthenticationMethodType) Values() []ClientAuthenticationMethodType {
	return []ClientAuthenticationMethodType{
		"CLIENT_SECRET_BASIC",
		"CLIENT_SECRET_POST",
		"AWS_IAM_ID_TOKEN_JWT",
	}
}

type ClusteringFrequency string

// Enum values for ClusteringFrequency
const (
	ClusteringFrequencyDaily   ClusteringFrequency = "DAILY"
	ClusteringFrequencyWeekly  ClusteringFrequency = "WEEKLY"
	ClusteringFrequencyMonthly ClusteringFrequency = "MONTHLY"
)

// Values returns all known values for ClusteringFrequency. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ClusteringFrequency) Values() []ClusteringFrequency {
	return []ClusteringFrequency{
		"DAILY",
		"WEEKLY",
		"MONTHLY",
	}
}

type CodeInterpreterNetworkMode string

// Enum values for CodeInterpreterNetworkMode
const (
	CodeInterpreterNetworkModePublic  CodeInterpreterNetworkMode = "PUBLIC"
	CodeInterpreterNetworkModeSandbox CodeInterpreterNetworkMode = "SANDBOX"
	CodeInterpreterNetworkModeVpc     CodeInterpreterNetworkMode = "VPC"
)

// Values returns all known values for CodeInterpreterNetworkMode. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CodeInterpreterNetworkMode) Values() []CodeInterpreterNetworkMode {
	return []CodeInterpreterNetworkMode{
		"PUBLIC",
		"SANDBOX",
		"VPC",
	}
}

type CodeInterpreterStatus string

// Enum values for CodeInterpreterStatus
const (
	CodeInterpreterStatusCreating     CodeInterpreterStatus = "CREATING"
	CodeInterpreterStatusCreateFailed CodeInterpreterStatus = "CREATE_FAILED"
	CodeInterpreterStatusReady        CodeInterpreterStatus = "READY"
	CodeInterpreterStatusDeleting     CodeInterpreterStatus = "DELETING"
	CodeInterpreterStatusDeleteFailed CodeInterpreterStatus = "DELETE_FAILED"
	CodeInterpreterStatusDeleted      CodeInterpreterStatus = "DELETED"
)

// Values returns all known values for CodeInterpreterStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CodeInterpreterStatus) Values() []CodeInterpreterStatus {
	return []CodeInterpreterStatus{
		"CREATING",
		"CREATE_FAILED",
		"READY",
		"DELETING",
		"DELETE_FAILED",
		"DELETED",
	}
}

type ConfigurationBundleStatus string

// Enum values for ConfigurationBundleStatus
const (
	ConfigurationBundleStatusActive       ConfigurationBundleStatus = "ACTIVE"
	ConfigurationBundleStatusCreating     ConfigurationBundleStatus = "CREATING"
	ConfigurationBundleStatusCreateFailed ConfigurationBundleStatus = "CREATE_FAILED"
	ConfigurationBundleStatusUpdating     ConfigurationBundleStatus = "UPDATING"
	ConfigurationBundleStatusUpdateFailed ConfigurationBundleStatus = "UPDATE_FAILED"
	ConfigurationBundleStatusDeleting     ConfigurationBundleStatus = "DELETING"
	ConfigurationBundleStatusDeleteFailed ConfigurationBundleStatus = "DELETE_FAILED"
)

// Values returns all known values for ConfigurationBundleStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConfigurationBundleStatus) Values() []ConfigurationBundleStatus {
	return []ConfigurationBundleStatus{
		"ACTIVE",
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"DELETING",
		"DELETE_FAILED",
	}
}

type ContentLevel string

// Enum values for ContentLevel
const (
	ContentLevelMetadataOnly ContentLevel = "METADATA_ONLY"
	ContentLevelFullContent  ContentLevel = "FULL_CONTENT"
)

// Values returns all known values for ContentLevel. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ContentLevel) Values() []ContentLevel {
	return []ContentLevel{
		"METADATA_ONLY",
		"FULL_CONTENT",
	}
}

type ContentType string

// Enum values for ContentType
const (
	ContentTypeMemoryRecords ContentType = "MEMORY_RECORDS"
)

// Values returns all known values for ContentType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ContentType) Values() []ContentType {
	return []ContentType{
		"MEMORY_RECORDS",
	}
}

type CredentialProviderType string

// Enum values for CredentialProviderType
const (
	CredentialProviderTypeGatewayIamRole       CredentialProviderType = "GATEWAY_IAM_ROLE"
	CredentialProviderTypeOauth                CredentialProviderType = "OAUTH"
	CredentialProviderTypeApiKey               CredentialProviderType = "API_KEY"
	CredentialProviderTypeCallerIamCredentials CredentialProviderType = "CALLER_IAM_CREDENTIALS"
	CredentialProviderTypeJwtPassthrough       CredentialProviderType = "JWT_PASSTHROUGH"
)

// Values returns all known values for CredentialProviderType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CredentialProviderType) Values() []CredentialProviderType {
	return []CredentialProviderType{
		"GATEWAY_IAM_ROLE",
		"OAUTH",
		"API_KEY",
		"CALLER_IAM_CREDENTIALS",
		"JWT_PASSTHROUGH",
	}
}

type CredentialProviderVendorType string

// Enum values for CredentialProviderVendorType
const (
	CredentialProviderVendorTypeGoogleOauth2     CredentialProviderVendorType = "GoogleOauth2"
	CredentialProviderVendorTypeGithubOauth2     CredentialProviderVendorType = "GithubOauth2"
	CredentialProviderVendorTypeSlackOauth2      CredentialProviderVendorType = "SlackOauth2"
	CredentialProviderVendorTypeSalesforceOauth2 CredentialProviderVendorType = "SalesforceOauth2"
	CredentialProviderVendorTypeMicrosoftOauth2  CredentialProviderVendorType = "MicrosoftOauth2"
	CredentialProviderVendorTypeCustomOauth2     CredentialProviderVendorType = "CustomOauth2"
	CredentialProviderVendorTypeAtlassianOauth2  CredentialProviderVendorType = "AtlassianOauth2"
	CredentialProviderVendorTypeLinkedinOauth2   CredentialProviderVendorType = "LinkedinOauth2"
	CredentialProviderVendorTypeXOauth2          CredentialProviderVendorType = "XOauth2"
	CredentialProviderVendorTypeOktaOauth2       CredentialProviderVendorType = "OktaOauth2"
	CredentialProviderVendorTypeOneLoginOauth2   CredentialProviderVendorType = "OneLoginOauth2"
	CredentialProviderVendorTypePingOneOauth2    CredentialProviderVendorType = "PingOneOauth2"
	CredentialProviderVendorTypeFacebookOauth2   CredentialProviderVendorType = "FacebookOauth2"
	CredentialProviderVendorTypeYandexOauth2     CredentialProviderVendorType = "YandexOauth2"
	CredentialProviderVendorTypeRedditOauth2     CredentialProviderVendorType = "RedditOauth2"
	CredentialProviderVendorTypeZoomOauth2       CredentialProviderVendorType = "ZoomOauth2"
	CredentialProviderVendorTypeTwitchOauth2     CredentialProviderVendorType = "TwitchOauth2"
	CredentialProviderVendorTypeSpotifyOauth2    CredentialProviderVendorType = "SpotifyOauth2"
	CredentialProviderVendorTypeDropboxOauth2    CredentialProviderVendorType = "DropboxOauth2"
	CredentialProviderVendorTypeNotionOauth2     CredentialProviderVendorType = "NotionOauth2"
	CredentialProviderVendorTypeHubspotOauth2    CredentialProviderVendorType = "HubspotOauth2"
	CredentialProviderVendorTypeCyberArkOauth2   CredentialProviderVendorType = "CyberArkOauth2"
	CredentialProviderVendorTypeFusionAuthOauth2 CredentialProviderVendorType = "FusionAuthOauth2"
	CredentialProviderVendorTypeAuth0Oauth2      CredentialProviderVendorType = "Auth0Oauth2"
	CredentialProviderVendorTypeCognitoOauth2    CredentialProviderVendorType = "CognitoOauth2"
)

// Values returns all known values for CredentialProviderVendorType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CredentialProviderVendorType) Values() []CredentialProviderVendorType {
	return []CredentialProviderVendorType{
		"GoogleOauth2",
		"GithubOauth2",
		"SlackOauth2",
		"SalesforceOauth2",
		"MicrosoftOauth2",
		"CustomOauth2",
		"AtlassianOauth2",
		"LinkedinOauth2",
		"XOauth2",
		"OktaOauth2",
		"OneLoginOauth2",
		"PingOneOauth2",
		"FacebookOauth2",
		"YandexOauth2",
		"RedditOauth2",
		"ZoomOauth2",
		"TwitchOauth2",
		"SpotifyOauth2",
		"DropboxOauth2",
		"NotionOauth2",
		"HubspotOauth2",
		"CyberArkOauth2",
		"FusionAuthOauth2",
		"Auth0Oauth2",
		"CognitoOauth2",
	}
}

type DatasetSchemaType string

// Enum values for DatasetSchemaType
const (
	//  AgentCore predefined evaluation schema, version 1. Dataset with pre-written
	// inputs per conversation turn.
	DatasetSchemaTypeAgentcoreEvaluationPredefinedV1 DatasetSchemaType = "AGENTCORE_EVALUATION_PREDEFINED_V1"
	//  AgentCore simulated evaluation schema, version 1. Dataset for synthetic data
	// generation where each example is a scenario used to generate full conversations.
	DatasetSchemaTypeAgentcoreEvaluationSimulatedV1 DatasetSchemaType = "AGENTCORE_EVALUATION_SIMULATED_V1"
)

// Values returns all known values for DatasetSchemaType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DatasetSchemaType) Values() []DatasetSchemaType {
	return []DatasetSchemaType{
		"AGENTCORE_EVALUATION_PREDEFINED_V1",
		"AGENTCORE_EVALUATION_SIMULATED_V1",
	}
}

type DatasetStatus string

// Enum values for DatasetStatus
const (
	//  CreateDataset async ingestion in progress. All writes are blocked.
	DatasetStatusCreating DatasetStatus = "CREATING"
	//  An async example mutation or CreateDatasetVersion is in progress. All writes
	// are blocked.
	DatasetStatusUpdating DatasetStatus = "UPDATING"
	//  Full or version-specific delete is in progress. Read operations are still
	// allowed.
	DatasetStatusDeleting DatasetStatus = "DELETING"
	//  Dataset is stable. All operations are allowed per operation-specific guards.
	DatasetStatusActive DatasetStatus = "ACTIVE"
	//  Initial ingestion failed. DRAFT record exists but contains no examples.
	DatasetStatusCreateFailed DatasetStatus = "CREATE_FAILED"
	//  Last example mutation or CreateDatasetVersion failed. DRAFT may be partially
	// modified.
	DatasetStatusUpdateFailed DatasetStatus = "UPDATE_FAILED"
	//  Delete failed after retries. Dataset record may be in an inconsistent state.
	DatasetStatusDeleteFailed DatasetStatus = "DELETE_FAILED"
)

// Values returns all known values for DatasetStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DatasetStatus) Values() []DatasetStatus {
	return []DatasetStatus{
		"CREATING",
		"UPDATING",
		"DELETING",
		"ACTIVE",
		"CREATE_FAILED",
		"UPDATE_FAILED",
		"DELETE_FAILED",
	}
}

type DescriptorType string

// Enum values for DescriptorType
const (
	DescriptorTypeMcp         DescriptorType = "MCP"
	DescriptorTypeA2a         DescriptorType = "A2A"
	DescriptorTypeCustom      DescriptorType = "CUSTOM"
	DescriptorTypeAgentSkills DescriptorType = "AGENT_SKILLS"
)

// Values returns all known values for DescriptorType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DescriptorType) Values() []DescriptorType {
	return []DescriptorType{
		"MCP",
		"A2A",
		"CUSTOM",
		"AGENT_SKILLS",
	}
}

type DraftStatus string

// Enum values for DraftStatus
const (
	//  DRAFT has changes not yet reflected in any published version, or no versions
	// have been published yet.
	DraftStatusModified DraftStatus = "MODIFIED"
	//  DRAFT content matches the latest published version exactly.
	DraftStatusUnmodified DraftStatus = "UNMODIFIED"
)

// Values returns all known values for DraftStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DraftStatus) Values() []DraftStatus {
	return []DraftStatus{
		"MODIFIED",
		"UNMODIFIED",
	}
}

type EndpointIpAddressType string

// Enum values for EndpointIpAddressType
const (
	EndpointIpAddressTypeIpv4 EndpointIpAddressType = "IPV4"
	EndpointIpAddressTypeIpv6 EndpointIpAddressType = "IPV6"
)

// Values returns all known values for EndpointIpAddressType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EndpointIpAddressType) Values() []EndpointIpAddressType {
	return []EndpointIpAddressType{
		"IPV4",
		"IPV6",
	}
}

type EnforcementMode string

// Enum values for EnforcementMode
const (
	EnforcementModeActive  EnforcementMode = "ACTIVE"
	EnforcementModeLogOnly EnforcementMode = "LOG_ONLY"
)

// Values returns all known values for EnforcementMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EnforcementMode) Values() []EnforcementMode {
	return []EnforcementMode{
		"ACTIVE",
		"LOG_ONLY",
	}
}

type EvaluatorLevel string

// Enum values for EvaluatorLevel
const (
	EvaluatorLevelToolCall EvaluatorLevel = "TOOL_CALL"
	EvaluatorLevelTrace    EvaluatorLevel = "TRACE"
	EvaluatorLevelSession  EvaluatorLevel = "SESSION"
)

// Values returns all known values for EvaluatorLevel. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluatorLevel) Values() []EvaluatorLevel {
	return []EvaluatorLevel{
		"TOOL_CALL",
		"TRACE",
		"SESSION",
	}
}

type EvaluatorStatus string

// Enum values for EvaluatorStatus
const (
	EvaluatorStatusActive       EvaluatorStatus = "ACTIVE"
	EvaluatorStatusCreating     EvaluatorStatus = "CREATING"
	EvaluatorStatusCreateFailed EvaluatorStatus = "CREATE_FAILED"
	EvaluatorStatusUpdating     EvaluatorStatus = "UPDATING"
	EvaluatorStatusUpdateFailed EvaluatorStatus = "UPDATE_FAILED"
	EvaluatorStatusDeleting     EvaluatorStatus = "DELETING"
)

// Values returns all known values for EvaluatorStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluatorStatus) Values() []EvaluatorStatus {
	return []EvaluatorStatus{
		"ACTIVE",
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"DELETING",
	}
}

type EvaluatorType string

// Enum values for EvaluatorType
const (
	EvaluatorTypeBuiltin EvaluatorType = "Builtin"
	EvaluatorTypeCustom  EvaluatorType = "Custom"
	EvaluatorTypeCode    EvaluatorType = "CustomCode"
)

// Values returns all known values for EvaluatorType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluatorType) Values() []EvaluatorType {
	return []EvaluatorType{
		"Builtin",
		"Custom",
		"CustomCode",
	}
}

type ExceptionLevel string

// Enum values for ExceptionLevel
const (
	ExceptionLevelDebug ExceptionLevel = "DEBUG"
)

// Values returns all known values for ExceptionLevel. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExceptionLevel) Values() []ExceptionLevel {
	return []ExceptionLevel{
		"DEBUG",
	}
}

type ExtractionType string

// Enum values for ExtractionType
const (
	ExtractionTypeLlmInferred        ExtractionType = "LLM_INFERRED"
	ExtractionTypeStrictlyConsistent ExtractionType = "STRICTLY_CONSISTENT"
)

// Values returns all known values for ExtractionType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExtractionType) Values() []ExtractionType {
	return []ExtractionType{
		"LLM_INFERRED",
		"STRICTLY_CONSISTENT",
	}
}

type FilterOperator string

// Enum values for FilterOperator
const (
	FilterOperatorEquals             FilterOperator = "Equals"
	FilterOperatorNotEquals          FilterOperator = "NotEquals"
	FilterOperatorGreaterThan        FilterOperator = "GreaterThan"
	FilterOperatorLessThan           FilterOperator = "LessThan"
	FilterOperatorGreaterThanOrEqual FilterOperator = "GreaterThanOrEqual"
	FilterOperatorLessThanOrEqual    FilterOperator = "LessThanOrEqual"
	FilterOperatorContains           FilterOperator = "Contains"
	FilterOperatorNotContains        FilterOperator = "NotContains"
)

// Values returns all known values for FilterOperator. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FilterOperator) Values() []FilterOperator {
	return []FilterOperator{
		"Equals",
		"NotEquals",
		"GreaterThan",
		"LessThan",
		"GreaterThanOrEqual",
		"LessThanOrEqual",
		"Contains",
		"NotContains",
	}
}

type FindingType string

// Enum values for FindingType
const (
	FindingTypeValid           FindingType = "VALID"
	FindingTypeInvalid         FindingType = "INVALID"
	FindingTypeNotTranslatable FindingType = "NOT_TRANSLATABLE"
	FindingTypeAllowAll        FindingType = "ALLOW_ALL"
	FindingTypeAllowNone       FindingType = "ALLOW_NONE"
	FindingTypeDenyAll         FindingType = "DENY_ALL"
	FindingTypeDenyNone        FindingType = "DENY_NONE"
)

// Values returns all known values for FindingType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FindingType) Values() []FindingType {
	return []FindingType{
		"VALID",
		"INVALID",
		"NOT_TRANSLATABLE",
		"ALLOW_ALL",
		"ALLOW_NONE",
		"DENY_ALL",
		"DENY_NONE",
	}
}

type GatewayInterceptionPoint string

// Enum values for GatewayInterceptionPoint
const (
	GatewayInterceptionPointRequest  GatewayInterceptionPoint = "REQUEST"
	GatewayInterceptionPointResponse GatewayInterceptionPoint = "RESPONSE"
)

// Values returns all known values for GatewayInterceptionPoint. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GatewayInterceptionPoint) Values() []GatewayInterceptionPoint {
	return []GatewayInterceptionPoint{
		"REQUEST",
		"RESPONSE",
	}
}

type GatewayPolicyEngineMode string

// Enum values for GatewayPolicyEngineMode
const (
	GatewayPolicyEngineModeLogOnly GatewayPolicyEngineMode = "LOG_ONLY"
	GatewayPolicyEngineModeEnforce GatewayPolicyEngineMode = "ENFORCE"
)

// Values returns all known values for GatewayPolicyEngineMode. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GatewayPolicyEngineMode) Values() []GatewayPolicyEngineMode {
	return []GatewayPolicyEngineMode{
		"LOG_ONLY",
		"ENFORCE",
	}
}

type GatewayProtocolType string

// Enum values for GatewayProtocolType
const (
	GatewayProtocolTypeMcp GatewayProtocolType = "MCP"
)

// Values returns all known values for GatewayProtocolType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GatewayProtocolType) Values() []GatewayProtocolType {
	return []GatewayProtocolType{
		"MCP",
	}
}

type GatewayRuleStatus string

// Enum values for GatewayRuleStatus
const (
	GatewayRuleStatusCreating GatewayRuleStatus = "CREATING"
	GatewayRuleStatusActive   GatewayRuleStatus = "ACTIVE"
	GatewayRuleStatusUpdating GatewayRuleStatus = "UPDATING"
	GatewayRuleStatusDeleting GatewayRuleStatus = "DELETING"
)

// Values returns all known values for GatewayRuleStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GatewayRuleStatus) Values() []GatewayRuleStatus {
	return []GatewayRuleStatus{
		"CREATING",
		"ACTIVE",
		"UPDATING",
		"DELETING",
	}
}

type GatewayStatus string

// Enum values for GatewayStatus
const (
	GatewayStatusCreating           GatewayStatus = "CREATING"
	GatewayStatusUpdating           GatewayStatus = "UPDATING"
	GatewayStatusUpdateUnsuccessful GatewayStatus = "UPDATE_UNSUCCESSFUL"
	GatewayStatusDeleting           GatewayStatus = "DELETING"
	GatewayStatusReady              GatewayStatus = "READY"
	GatewayStatusFailed             GatewayStatus = "FAILED"
)

// Values returns all known values for GatewayStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GatewayStatus) Values() []GatewayStatus {
	return []GatewayStatus{
		"CREATING",
		"UPDATING",
		"UPDATE_UNSUCCESSFUL",
		"DELETING",
		"READY",
		"FAILED",
	}
}

type HarnessBedrockApiFormat string

// Enum values for HarnessBedrockApiFormat
const (
	// Use the Bedrock Converse Stream API format.
	HarnessBedrockApiFormatConverseStream HarnessBedrockApiFormat = "converse_stream"
	// Use the Responses API format.
	HarnessBedrockApiFormatResponses HarnessBedrockApiFormat = "responses"
	// Use the Chat Completions API format.
	HarnessBedrockApiFormatChatCompletions HarnessBedrockApiFormat = "chat_completions"
)

// Values returns all known values for HarnessBedrockApiFormat. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessBedrockApiFormat) Values() []HarnessBedrockApiFormat {
	return []HarnessBedrockApiFormat{
		"converse_stream",
		"responses",
		"chat_completions",
	}
}

type HarnessEndpointStatus string

// Enum values for HarnessEndpointStatus
const (
	HarnessEndpointStatusCreating     HarnessEndpointStatus = "CREATING"
	HarnessEndpointStatusCreateFailed HarnessEndpointStatus = "CREATE_FAILED"
	HarnessEndpointStatusUpdating     HarnessEndpointStatus = "UPDATING"
	HarnessEndpointStatusUpdateFailed HarnessEndpointStatus = "UPDATE_FAILED"
	HarnessEndpointStatusReady        HarnessEndpointStatus = "READY"
	HarnessEndpointStatusDeleting     HarnessEndpointStatus = "DELETING"
	HarnessEndpointStatusDeleteFailed HarnessEndpointStatus = "DELETE_FAILED"
)

// Values returns all known values for HarnessEndpointStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessEndpointStatus) Values() []HarnessEndpointStatus {
	return []HarnessEndpointStatus{
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"READY",
		"DELETING",
		"DELETE_FAILED",
	}
}

type HarnessManagedMemoryStrategyType string

// Enum values for HarnessManagedMemoryStrategyType
const (
	HarnessManagedMemoryStrategyTypeSemantic       HarnessManagedMemoryStrategyType = "SEMANTIC"
	HarnessManagedMemoryStrategyTypeSummarization  HarnessManagedMemoryStrategyType = "SUMMARIZATION"
	HarnessManagedMemoryStrategyTypeUserPreference HarnessManagedMemoryStrategyType = "USER_PREFERENCE"
	HarnessManagedMemoryStrategyTypeEpisodic       HarnessManagedMemoryStrategyType = "EPISODIC"
)

// Values returns all known values for HarnessManagedMemoryStrategyType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessManagedMemoryStrategyType) Values() []HarnessManagedMemoryStrategyType {
	return []HarnessManagedMemoryStrategyType{
		"SEMANTIC",
		"SUMMARIZATION",
		"USER_PREFERENCE",
		"EPISODIC",
	}
}

type HarnessOpenAiApiFormat string

// Enum values for HarnessOpenAiApiFormat
const (
	// Use the Chat Completions API format.
	HarnessOpenAiApiFormatChatCompletions HarnessOpenAiApiFormat = "chat_completions"
	// Use the Responses API format.
	HarnessOpenAiApiFormatResponses HarnessOpenAiApiFormat = "responses"
)

// Values returns all known values for HarnessOpenAiApiFormat. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessOpenAiApiFormat) Values() []HarnessOpenAiApiFormat {
	return []HarnessOpenAiApiFormat{
		"chat_completions",
		"responses",
	}
}

type HarnessStatus string

// Enum values for HarnessStatus
const (
	HarnessStatusCreating     HarnessStatus = "CREATING"
	HarnessStatusCreateFailed HarnessStatus = "CREATE_FAILED"
	HarnessStatusUpdating     HarnessStatus = "UPDATING"
	HarnessStatusUpdateFailed HarnessStatus = "UPDATE_FAILED"
	HarnessStatusReady        HarnessStatus = "READY"
	HarnessStatusDeleting     HarnessStatus = "DELETING"
	HarnessStatusDeleteFailed HarnessStatus = "DELETE_FAILED"
)

// Values returns all known values for HarnessStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessStatus) Values() []HarnessStatus {
	return []HarnessStatus{
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"READY",
		"DELETING",
		"DELETE_FAILED",
	}
}

type HarnessToolType string

// Enum values for HarnessToolType
const (
	HarnessToolTypeRemoteMcp                HarnessToolType = "remote_mcp"
	HarnessToolTypeAgentcoreBrowser         HarnessToolType = "agentcore_browser"
	HarnessToolTypeAgentcoreGateway         HarnessToolType = "agentcore_gateway"
	HarnessToolTypeInlineFunction           HarnessToolType = "inline_function"
	HarnessToolTypeAgentcoreCodeInterpreter HarnessToolType = "agentcore_code_interpreter"
)

// Values returns all known values for HarnessToolType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessToolType) Values() []HarnessToolType {
	return []HarnessToolType{
		"remote_mcp",
		"agentcore_browser",
		"agentcore_gateway",
		"inline_function",
		"agentcore_code_interpreter",
	}
}

type HarnessTruncationStrategy string

// Enum values for HarnessTruncationStrategy
const (
	HarnessTruncationStrategySlidingWindow HarnessTruncationStrategy = "sliding_window"
	HarnessTruncationStrategySummarization HarnessTruncationStrategy = "summarization"
	HarnessTruncationStrategyNone          HarnessTruncationStrategy = "none"
)

// Values returns all known values for HarnessTruncationStrategy. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (HarnessTruncationStrategy) Values() []HarnessTruncationStrategy {
	return []HarnessTruncationStrategy{
		"sliding_window",
		"summarization",
		"none",
	}
}

type InboundTokenClaimValueType string

// Enum values for InboundTokenClaimValueType
const (
	InboundTokenClaimValueTypeString      InboundTokenClaimValueType = "STRING"
	InboundTokenClaimValueTypeStringArray InboundTokenClaimValueType = "STRING_ARRAY"
)

// Values returns all known values for InboundTokenClaimValueType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InboundTokenClaimValueType) Values() []InboundTokenClaimValueType {
	return []InboundTokenClaimValueType{
		"STRING",
		"STRING_ARRAY",
	}
}

type IncludedData string

// Enum values for IncludedData
const (
	IncludedDataAllData      IncludedData = "ALL_DATA"
	IncludedDataMetadataOnly IncludedData = "METADATA_ONLY"
)

// Values returns all known values for IncludedData. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (IncludedData) Values() []IncludedData {
	return []IncludedData{
		"ALL_DATA",
		"METADATA_ONLY",
	}
}

type InterceptorPayloadExclusion string

// Enum values for InterceptorPayloadExclusion
const (
	InterceptorPayloadExclusionResponseBody InterceptorPayloadExclusion = "RESPONSE_BODY"
)

// Values returns all known values for InterceptorPayloadExclusion. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InterceptorPayloadExclusion) Values() []InterceptorPayloadExclusion {
	return []InterceptorPayloadExclusion{
		"RESPONSE_BODY",
	}
}

type KeyType string

// Enum values for KeyType
const (
	KeyTypeCustomerManagedKey KeyType = "CustomerManagedKey"
	KeyTypeServiceManagedKey  KeyType = "ServiceManagedKey"
)

// Values returns all known values for KeyType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (KeyType) Values() []KeyType {
	return []KeyType{
		"CustomerManagedKey",
		"ServiceManagedKey",
	}
}

type ListingMode string

// Enum values for ListingMode
const (
	ListingModeDefault ListingMode = "DEFAULT"
	ListingModeDynamic ListingMode = "DYNAMIC"
)

// Values returns all known values for ListingMode. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ListingMode) Values() []ListingMode {
	return []ListingMode{
		"DEFAULT",
		"DYNAMIC",
	}
}

type MemoryStatus string

// Enum values for MemoryStatus
const (
	MemoryStatusCreating MemoryStatus = "CREATING"
	MemoryStatusActive   MemoryStatus = "ACTIVE"
	MemoryStatusFailed   MemoryStatus = "FAILED"
	MemoryStatusDeleting MemoryStatus = "DELETING"
	MemoryStatusUpdating MemoryStatus = "UPDATING"
)

// Values returns all known values for MemoryStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MemoryStatus) Values() []MemoryStatus {
	return []MemoryStatus{
		"CREATING",
		"ACTIVE",
		"FAILED",
		"DELETING",
		"UPDATING",
	}
}

type MemoryStrategyStatus string

// Enum values for MemoryStrategyStatus
const (
	MemoryStrategyStatusCreating MemoryStrategyStatus = "CREATING"
	MemoryStrategyStatusActive   MemoryStrategyStatus = "ACTIVE"
	MemoryStrategyStatusDeleting MemoryStrategyStatus = "DELETING"
	MemoryStrategyStatusFailed   MemoryStrategyStatus = "FAILED"
)

// Values returns all known values for MemoryStrategyStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MemoryStrategyStatus) Values() []MemoryStrategyStatus {
	return []MemoryStrategyStatus{
		"CREATING",
		"ACTIVE",
		"DELETING",
		"FAILED",
	}
}

type MemoryStrategyType string

// Enum values for MemoryStrategyType
const (
	MemoryStrategyTypeSemantic       MemoryStrategyType = "SEMANTIC"
	MemoryStrategyTypeSummarization  MemoryStrategyType = "SUMMARIZATION"
	MemoryStrategyTypeUserPreference MemoryStrategyType = "USER_PREFERENCE"
	MemoryStrategyTypeCustom         MemoryStrategyType = "CUSTOM"
	MemoryStrategyTypeEpisodic       MemoryStrategyType = "EPISODIC"
)

// Values returns all known values for MemoryStrategyType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MemoryStrategyType) Values() []MemoryStrategyType {
	return []MemoryStrategyType{
		"SEMANTIC",
		"SUMMARIZATION",
		"USER_PREFERENCE",
		"CUSTOM",
		"EPISODIC",
	}
}

type MemoryView string

// Enum values for MemoryView
const (
	MemoryViewFull              MemoryView = "full"
	MemoryViewWithoutDecryption MemoryView = "without_decryption"
)

// Values returns all known values for MemoryView. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MemoryView) Values() []MemoryView {
	return []MemoryView{
		"full",
		"without_decryption",
	}
}

type MetadataValueType string

// Enum values for MetadataValueType
const (
	MetadataValueTypeString     MetadataValueType = "STRING"
	MetadataValueTypeStringlist MetadataValueType = "STRINGLIST"
	MetadataValueTypeNumber     MetadataValueType = "NUMBER"
)

// Values returns all known values for MetadataValueType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MetadataValueType) Values() []MetadataValueType {
	return []MetadataValueType{
		"STRING",
		"STRINGLIST",
		"NUMBER",
	}
}

type NetworkMode string

// Enum values for NetworkMode
const (
	NetworkModePublic NetworkMode = "PUBLIC"
	NetworkModeVpc    NetworkMode = "VPC"
)

// Values returns all known values for NetworkMode. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (NetworkMode) Values() []NetworkMode {
	return []NetworkMode{
		"PUBLIC",
		"VPC",
	}
}

type OAuthGrantType string

// Enum values for OAuthGrantType
const (
	OAuthGrantTypeClientCredentials OAuthGrantType = "CLIENT_CREDENTIALS"
	OAuthGrantTypeAuthorizationCode OAuthGrantType = "AUTHORIZATION_CODE"
	OAuthGrantTypeTokenExchange     OAuthGrantType = "TOKEN_EXCHANGE"
)

// Values returns all known values for OAuthGrantType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OAuthGrantType) Values() []OAuthGrantType {
	return []OAuthGrantType{
		"CLIENT_CREDENTIALS",
		"AUTHORIZATION_CODE",
		"TOKEN_EXCHANGE",
	}
}

type OnBehalfOfTokenExchangeGrantTypeType string

// Enum values for OnBehalfOfTokenExchangeGrantTypeType
const (
	// RFC 8693 token exchange, adopted by the majority of identity providers
	// supporting on-behalf-of flows.
	OnBehalfOfTokenExchangeGrantTypeTypeTokenExchange OnBehalfOfTokenExchangeGrantTypeType = "TOKEN_EXCHANGE"
	// RFC 7523 JWT authorization grant, adopted by Microsoft Entra ID.
	OnBehalfOfTokenExchangeGrantTypeTypeJwtAuthorizationGrant OnBehalfOfTokenExchangeGrantTypeType = "JWT_AUTHORIZATION_GRANT"
)

// Values returns all known values for OnBehalfOfTokenExchangeGrantTypeType. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OnBehalfOfTokenExchangeGrantTypeType) Values() []OnBehalfOfTokenExchangeGrantTypeType {
	return []OnBehalfOfTokenExchangeGrantTypeType{
		"TOKEN_EXCHANGE",
		"JWT_AUTHORIZATION_GRANT",
	}
}

type OnlineEvaluationConfigStatus string

// Enum values for OnlineEvaluationConfigStatus
const (
	OnlineEvaluationConfigStatusActive       OnlineEvaluationConfigStatus = "ACTIVE"
	OnlineEvaluationConfigStatusCreating     OnlineEvaluationConfigStatus = "CREATING"
	OnlineEvaluationConfigStatusCreateFailed OnlineEvaluationConfigStatus = "CREATE_FAILED"
	OnlineEvaluationConfigStatusUpdating     OnlineEvaluationConfigStatus = "UPDATING"
	OnlineEvaluationConfigStatusUpdateFailed OnlineEvaluationConfigStatus = "UPDATE_FAILED"
	OnlineEvaluationConfigStatusDeleting     OnlineEvaluationConfigStatus = "DELETING"
	OnlineEvaluationConfigStatusError        OnlineEvaluationConfigStatus = "ERROR"
)

// Values returns all known values for OnlineEvaluationConfigStatus. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OnlineEvaluationConfigStatus) Values() []OnlineEvaluationConfigStatus {
	return []OnlineEvaluationConfigStatus{
		"ACTIVE",
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"DELETING",
		"ERROR",
	}
}

type OnlineEvaluationExecutionStatus string

// Enum values for OnlineEvaluationExecutionStatus
const (
	OnlineEvaluationExecutionStatusEnabled  OnlineEvaluationExecutionStatus = "ENABLED"
	OnlineEvaluationExecutionStatusDisabled OnlineEvaluationExecutionStatus = "DISABLED"
)

// Values returns all known values for OnlineEvaluationExecutionStatus. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OnlineEvaluationExecutionStatus) Values() []OnlineEvaluationExecutionStatus {
	return []OnlineEvaluationExecutionStatus{
		"ENABLED",
		"DISABLED",
	}
}

type OverrideType string

// Enum values for OverrideType
const (
	OverrideTypeSemanticOverride       OverrideType = "SEMANTIC_OVERRIDE"
	OverrideTypeSummaryOverride        OverrideType = "SUMMARY_OVERRIDE"
	OverrideTypeUserPreferenceOverride OverrideType = "USER_PREFERENCE_OVERRIDE"
	OverrideTypeSelfManaged            OverrideType = "SELF_MANAGED"
	OverrideTypeEpisodicOverride       OverrideType = "EPISODIC_OVERRIDE"
)

// Values returns all known values for OverrideType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OverrideType) Values() []OverrideType {
	return []OverrideType{
		"SEMANTIC_OVERRIDE",
		"SUMMARY_OVERRIDE",
		"USER_PREFERENCE_OVERRIDE",
		"SELF_MANAGED",
		"EPISODIC_OVERRIDE",
	}
}

type PassthroughProtocolType string

// Enum values for PassthroughProtocolType
const (
	PassthroughProtocolTypeMcp       PassthroughProtocolType = "MCP"
	PassthroughProtocolTypeA2a       PassthroughProtocolType = "A2A"
	PassthroughProtocolTypeInference PassthroughProtocolType = "INFERENCE"
	PassthroughProtocolTypeCustom    PassthroughProtocolType = "CUSTOM"
)

// Values returns all known values for PassthroughProtocolType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PassthroughProtocolType) Values() []PassthroughProtocolType {
	return []PassthroughProtocolType{
		"MCP",
		"A2A",
		"INFERENCE",
		"CUSTOM",
	}
}

type PaymentConnectorStatus string

// Enum values for PaymentConnectorStatus
const (
	PaymentConnectorStatusCreating     PaymentConnectorStatus = "CREATING"
	PaymentConnectorStatusUpdating     PaymentConnectorStatus = "UPDATING"
	PaymentConnectorStatusDeleting     PaymentConnectorStatus = "DELETING"
	PaymentConnectorStatusReady        PaymentConnectorStatus = "READY"
	PaymentConnectorStatusCreateFailed PaymentConnectorStatus = "CREATE_FAILED"
	PaymentConnectorStatusUpdateFailed PaymentConnectorStatus = "UPDATE_FAILED"
	PaymentConnectorStatusDeleteFailed PaymentConnectorStatus = "DELETE_FAILED"
)

// Values returns all known values for PaymentConnectorStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentConnectorStatus) Values() []PaymentConnectorStatus {
	return []PaymentConnectorStatus{
		"CREATING",
		"UPDATING",
		"DELETING",
		"READY",
		"CREATE_FAILED",
		"UPDATE_FAILED",
		"DELETE_FAILED",
	}
}

type PaymentConnectorType string

// Enum values for PaymentConnectorType
const (
	PaymentConnectorTypeCoinbaseCdp PaymentConnectorType = "CoinbaseCDP"
	PaymentConnectorTypeStripePrivy PaymentConnectorType = "StripePrivy"
)

// Values returns all known values for PaymentConnectorType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentConnectorType) Values() []PaymentConnectorType {
	return []PaymentConnectorType{
		"CoinbaseCDP",
		"StripePrivy",
	}
}

type PaymentCredentialProviderVendorType string

// Enum values for PaymentCredentialProviderVendorType
const (
	// Coinbase Developer Platform.
	PaymentCredentialProviderVendorTypeCoinbaseCDP PaymentCredentialProviderVendorType = "CoinbaseCDP"
	// Stripe and Privy.
	PaymentCredentialProviderVendorTypeStripePrivy PaymentCredentialProviderVendorType = "StripePrivy"
)

// Values returns all known values for PaymentCredentialProviderVendorType. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentCredentialProviderVendorType) Values() []PaymentCredentialProviderVendorType {
	return []PaymentCredentialProviderVendorType{
		"CoinbaseCDP",
		"StripePrivy",
	}
}

type PaymentManagerStatus string

// Enum values for PaymentManagerStatus
const (
	PaymentManagerStatusCreating     PaymentManagerStatus = "CREATING"
	PaymentManagerStatusUpdating     PaymentManagerStatus = "UPDATING"
	PaymentManagerStatusDeleting     PaymentManagerStatus = "DELETING"
	PaymentManagerStatusReady        PaymentManagerStatus = "READY"
	PaymentManagerStatusCreateFailed PaymentManagerStatus = "CREATE_FAILED"
	PaymentManagerStatusUpdateFailed PaymentManagerStatus = "UPDATE_FAILED"
	PaymentManagerStatusDeleteFailed PaymentManagerStatus = "DELETE_FAILED"
)

// Values returns all known values for PaymentManagerStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentManagerStatus) Values() []PaymentManagerStatus {
	return []PaymentManagerStatus{
		"CREATING",
		"UPDATING",
		"DELETING",
		"READY",
		"CREATE_FAILED",
		"UPDATE_FAILED",
		"DELETE_FAILED",
	}
}

type PaymentsAuthorizerType string

// Enum values for PaymentsAuthorizerType
const (
	PaymentsAuthorizerTypeCustomJwt PaymentsAuthorizerType = "CUSTOM_JWT"
	PaymentsAuthorizerTypeAwsIam    PaymentsAuthorizerType = "AWS_IAM"
)

// Values returns all known values for PaymentsAuthorizerType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PaymentsAuthorizerType) Values() []PaymentsAuthorizerType {
	return []PaymentsAuthorizerType{
		"CUSTOM_JWT",
		"AWS_IAM",
	}
}

type PolicyEngineStatus string

// Enum values for PolicyEngineStatus
const (
	PolicyEngineStatusCreating     PolicyEngineStatus = "CREATING"
	PolicyEngineStatusActive       PolicyEngineStatus = "ACTIVE"
	PolicyEngineStatusUpdating     PolicyEngineStatus = "UPDATING"
	PolicyEngineStatusDeleting     PolicyEngineStatus = "DELETING"
	PolicyEngineStatusCreateFailed PolicyEngineStatus = "CREATE_FAILED"
	PolicyEngineStatusUpdateFailed PolicyEngineStatus = "UPDATE_FAILED"
	PolicyEngineStatusDeleteFailed PolicyEngineStatus = "DELETE_FAILED"
)

// Values returns all known values for PolicyEngineStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PolicyEngineStatus) Values() []PolicyEngineStatus {
	return []PolicyEngineStatus{
		"CREATING",
		"ACTIVE",
		"UPDATING",
		"DELETING",
		"CREATE_FAILED",
		"UPDATE_FAILED",
		"DELETE_FAILED",
	}
}

type PolicyGenerationStatus string

// Enum values for PolicyGenerationStatus
const (
	PolicyGenerationStatusGenerating     PolicyGenerationStatus = "GENERATING"
	PolicyGenerationStatusGenerated      PolicyGenerationStatus = "GENERATED"
	PolicyGenerationStatusGenerateFailed PolicyGenerationStatus = "GENERATE_FAILED"
	PolicyGenerationStatusDeleteFailed   PolicyGenerationStatus = "DELETE_FAILED"
)

// Values returns all known values for PolicyGenerationStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PolicyGenerationStatus) Values() []PolicyGenerationStatus {
	return []PolicyGenerationStatus{
		"GENERATING",
		"GENERATED",
		"GENERATE_FAILED",
		"DELETE_FAILED",
	}
}

type PolicyStatus string

// Enum values for PolicyStatus
const (
	PolicyStatusCreating     PolicyStatus = "CREATING"
	PolicyStatusActive       PolicyStatus = "ACTIVE"
	PolicyStatusUpdating     PolicyStatus = "UPDATING"
	PolicyStatusDeleting     PolicyStatus = "DELETING"
	PolicyStatusCreateFailed PolicyStatus = "CREATE_FAILED"
	PolicyStatusUpdateFailed PolicyStatus = "UPDATE_FAILED"
	PolicyStatusDeleteFailed PolicyStatus = "DELETE_FAILED"
)

// Values returns all known values for PolicyStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PolicyStatus) Values() []PolicyStatus {
	return []PolicyStatus{
		"CREATING",
		"ACTIVE",
		"UPDATING",
		"DELETING",
		"CREATE_FAILED",
		"UPDATE_FAILED",
		"DELETE_FAILED",
	}
}

type PolicyValidationMode string

// Enum values for PolicyValidationMode
const (
	PolicyValidationModeFailOnAnyFindings PolicyValidationMode = "FAIL_ON_ANY_FINDINGS"
	PolicyValidationModeIgnoreAllFindings PolicyValidationMode = "IGNORE_ALL_FINDINGS"
)

// Values returns all known values for PolicyValidationMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PolicyValidationMode) Values() []PolicyValidationMode {
	return []PolicyValidationMode{
		"FAIL_ON_ANY_FINDINGS",
		"IGNORE_ALL_FINDINGS",
	}
}

type PrincipalMatchOperator string

// Enum values for PrincipalMatchOperator
const (
	PrincipalMatchOperatorStringEquals PrincipalMatchOperator = "StringEquals"
	PrincipalMatchOperatorStringLike   PrincipalMatchOperator = "StringLike"
)

// Values returns all known values for PrincipalMatchOperator. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PrincipalMatchOperator) Values() []PrincipalMatchOperator {
	return []PrincipalMatchOperator{
		"StringEquals",
		"StringLike",
	}
}

type RegistryAuthorizerType string

// Enum values for RegistryAuthorizerType
const (
	RegistryAuthorizerTypeCustomJwt RegistryAuthorizerType = "CUSTOM_JWT"
	RegistryAuthorizerTypeAwsIam    RegistryAuthorizerType = "AWS_IAM"
)

// Values returns all known values for RegistryAuthorizerType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegistryAuthorizerType) Values() []RegistryAuthorizerType {
	return []RegistryAuthorizerType{
		"CUSTOM_JWT",
		"AWS_IAM",
	}
}

type RegistryRecordCredentialProviderType string

// Enum values for RegistryRecordCredentialProviderType
const (
	RegistryRecordCredentialProviderTypeOauth RegistryRecordCredentialProviderType = "OAUTH"
	RegistryRecordCredentialProviderTypeIam   RegistryRecordCredentialProviderType = "IAM"
)

// Values returns all known values for RegistryRecordCredentialProviderType. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegistryRecordCredentialProviderType) Values() []RegistryRecordCredentialProviderType {
	return []RegistryRecordCredentialProviderType{
		"OAUTH",
		"IAM",
	}
}

type RegistryRecordOAuthGrantType string

// Enum values for RegistryRecordOAuthGrantType
const (
	RegistryRecordOAuthGrantTypeClientCredentials RegistryRecordOAuthGrantType = "CLIENT_CREDENTIALS"
)

// Values returns all known values for RegistryRecordOAuthGrantType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegistryRecordOAuthGrantType) Values() []RegistryRecordOAuthGrantType {
	return []RegistryRecordOAuthGrantType{
		"CLIENT_CREDENTIALS",
	}
}

type RegistryRecordStatus string

// Enum values for RegistryRecordStatus
const (
	RegistryRecordStatusDraft           RegistryRecordStatus = "DRAFT"
	RegistryRecordStatusPendingApproval RegistryRecordStatus = "PENDING_APPROVAL"
	RegistryRecordStatusApproved        RegistryRecordStatus = "APPROVED"
	RegistryRecordStatusRejected        RegistryRecordStatus = "REJECTED"
	RegistryRecordStatusDeprecated      RegistryRecordStatus = "DEPRECATED"
	RegistryRecordStatusCreating        RegistryRecordStatus = "CREATING"
	RegistryRecordStatusUpdating        RegistryRecordStatus = "UPDATING"
	RegistryRecordStatusCreateFailed    RegistryRecordStatus = "CREATE_FAILED"
	RegistryRecordStatusUpdateFailed    RegistryRecordStatus = "UPDATE_FAILED"
)

// Values returns all known values for RegistryRecordStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegistryRecordStatus) Values() []RegistryRecordStatus {
	return []RegistryRecordStatus{
		"DRAFT",
		"PENDING_APPROVAL",
		"APPROVED",
		"REJECTED",
		"DEPRECATED",
		"CREATING",
		"UPDATING",
		"CREATE_FAILED",
		"UPDATE_FAILED",
	}
}

type RegistryStatus string

// Enum values for RegistryStatus
const (
	RegistryStatusCreating     RegistryStatus = "CREATING"
	RegistryStatusReady        RegistryStatus = "READY"
	RegistryStatusUpdating     RegistryStatus = "UPDATING"
	RegistryStatusCreateFailed RegistryStatus = "CREATE_FAILED"
	RegistryStatusUpdateFailed RegistryStatus = "UPDATE_FAILED"
	RegistryStatusDeleting     RegistryStatus = "DELETING"
	RegistryStatusDeleteFailed RegistryStatus = "DELETE_FAILED"
)

// Values returns all known values for RegistryStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegistryStatus) Values() []RegistryStatus {
	return []RegistryStatus{
		"CREATING",
		"READY",
		"UPDATING",
		"CREATE_FAILED",
		"UPDATE_FAILED",
		"DELETING",
		"DELETE_FAILED",
	}
}

type ResourceType string

// Enum values for ResourceType
const (
	ResourceTypeSystem ResourceType = "SYSTEM"
	ResourceTypeCustom ResourceType = "CUSTOM"
)

// Values returns all known values for ResourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ResourceType) Values() []ResourceType {
	return []ResourceType{
		"SYSTEM",
		"CUSTOM",
	}
}

type RestApiMethod string

// Enum values for RestApiMethod
const (
	RestApiMethodGet     RestApiMethod = "GET"
	RestApiMethodDelete  RestApiMethod = "DELETE"
	RestApiMethodHead    RestApiMethod = "HEAD"
	RestApiMethodOptions RestApiMethod = "OPTIONS"
	RestApiMethodPatch   RestApiMethod = "PATCH"
	RestApiMethodPut     RestApiMethod = "PUT"
	RestApiMethodPost    RestApiMethod = "POST"
)

// Values returns all known values for RestApiMethod. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RestApiMethod) Values() []RestApiMethod {
	return []RestApiMethod{
		"GET",
		"DELETE",
		"HEAD",
		"OPTIONS",
		"PATCH",
		"PUT",
		"POST",
	}
}

type SchemaType string

// Enum values for SchemaType
const (
	SchemaTypeString  SchemaType = "string"
	SchemaTypeNumber  SchemaType = "number"
	SchemaTypeObject  SchemaType = "object"
	SchemaTypeArray   SchemaType = "array"
	SchemaTypeBoolean SchemaType = "boolean"
	SchemaTypeInteger SchemaType = "integer"
)

// Values returns all known values for SchemaType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SchemaType) Values() []SchemaType {
	return []SchemaType{
		"string",
		"number",
		"object",
		"array",
		"boolean",
		"integer",
	}
}

type SearchType string

// Enum values for SearchType
const (
	SearchTypeSemantic SearchType = "SEMANTIC"
)

// Values returns all known values for SearchType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SearchType) Values() []SearchType {
	return []SearchType{
		"SEMANTIC",
	}
}

type SecretSourceType string

// Enum values for SecretSourceType
const (
	SecretSourceTypeManaged  SecretSourceType = "MANAGED"
	SecretSourceTypeExternal SecretSourceType = "EXTERNAL"
)

// Values returns all known values for SecretSourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SecretSourceType) Values() []SecretSourceType {
	return []SecretSourceType{
		"MANAGED",
		"EXTERNAL",
	}
}

type ServerProtocol string

// Enum values for ServerProtocol
const (
	ServerProtocolMcp  ServerProtocol = "MCP"
	ServerProtocolHttp ServerProtocol = "HTTP"
	ServerProtocolA2a  ServerProtocol = "A2A"
	ServerProtocolAgui ServerProtocol = "AGUI"
)

// Values returns all known values for ServerProtocol. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ServerProtocol) Values() []ServerProtocol {
	return []ServerProtocol{
		"MCP",
		"HTTP",
		"A2A",
		"AGUI",
	}
}

type Status string

// Enum values for Status
const (
	StatusCreating     Status = "CREATING"
	StatusCreateFailed Status = "CREATE_FAILED"
	StatusUpdating     Status = "UPDATING"
	StatusUpdateFailed Status = "UPDATE_FAILED"
	StatusReady        Status = "READY"
	StatusDeleting     Status = "DELETING"
	StatusDeleteFailed Status = "DELETE_FAILED"
)

// Values returns all known values for Status. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Status) Values() []Status {
	return []Status{
		"CREATING",
		"CREATE_FAILED",
		"UPDATING",
		"UPDATE_FAILED",
		"READY",
		"DELETING",
		"DELETE_FAILED",
	}
}

type SynchronizationType string

// Enum values for SynchronizationType
const (
	SynchronizationTypeUrl SynchronizationType = "URL"
)

// Values returns all known values for SynchronizationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SynchronizationType) Values() []SynchronizationType {
	return []SynchronizationType{
		"URL",
	}
}

type TargetProtocolType string

// Enum values for TargetProtocolType
const (
	TargetProtocolTypeMcp  TargetProtocolType = "MCP"
	TargetProtocolTypeHttp TargetProtocolType = "HTTP"
)

// Values returns all known values for TargetProtocolType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TargetProtocolType) Values() []TargetProtocolType {
	return []TargetProtocolType{
		"MCP",
		"HTTP",
	}
}

type TargetStatus string

// Enum values for TargetStatus
const (
	TargetStatusCreating                TargetStatus = "CREATING"
	TargetStatusUpdating                TargetStatus = "UPDATING"
	TargetStatusUpdateUnsuccessful      TargetStatus = "UPDATE_UNSUCCESSFUL"
	TargetStatusDeleting                TargetStatus = "DELETING"
	TargetStatusReady                   TargetStatus = "READY"
	TargetStatusFailed                  TargetStatus = "FAILED"
	TargetStatusSynchronizing           TargetStatus = "SYNCHRONIZING"
	TargetStatusSynchronizeUnsuccessful TargetStatus = "SYNCHRONIZE_UNSUCCESSFUL"
	TargetStatusCreatePendingAuth       TargetStatus = "CREATE_PENDING_AUTH"
	TargetStatusUpdatePendingAuth       TargetStatus = "UPDATE_PENDING_AUTH"
	TargetStatusSynchronizePendingAuth  TargetStatus = "SYNCHRONIZE_PENDING_AUTH"
)

// Values returns all known values for TargetStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TargetStatus) Values() []TargetStatus {
	return []TargetStatus{
		"CREATING",
		"UPDATING",
		"UPDATE_UNSUCCESSFUL",
		"DELETING",
		"READY",
		"FAILED",
		"SYNCHRONIZING",
		"SYNCHRONIZE_UNSUCCESSFUL",
		"CREATE_PENDING_AUTH",
		"UPDATE_PENDING_AUTH",
		"SYNCHRONIZE_PENDING_AUTH",
	}
}

type TargetType string

// Enum values for TargetType
const (
	TargetTypeOpenApiSchema    TargetType = "OPEN_API_SCHEMA"
	TargetTypeSmithyModel      TargetType = "SMITHY_MODEL"
	TargetTypeMcpServer        TargetType = "MCP_SERVER"
	TargetTypeLambda           TargetType = "LAMBDA"
	TargetTypeApiGateway       TargetType = "API_GATEWAY"
	TargetTypeConnector        TargetType = "CONNECTOR"
	TargetTypeAgentcoreRuntime TargetType = "AGENTCORE_RUNTIME"
	TargetTypePassthrough      TargetType = "PASSTHROUGH"
	TargetTypeProvider         TargetType = "PROVIDER"
)

// Values returns all known values for TargetType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TargetType) Values() []TargetType {
	return []TargetType{
		"OPEN_API_SCHEMA",
		"SMITHY_MODEL",
		"MCP_SERVER",
		"LAMBDA",
		"API_GATEWAY",
		"CONNECTOR",
		"AGENTCORE_RUNTIME",
		"PASSTHROUGH",
		"PROVIDER",
	}
}

type ValidationExceptionReason string

// Enum values for ValidationExceptionReason
const (
	ValidationExceptionReasonCannotParse                          ValidationExceptionReason = "CannotParse"
	ValidationExceptionReasonFieldValidationFailed                ValidationExceptionReason = "FieldValidationFailed"
	ValidationExceptionReasonIdempotentParameterMismatchException ValidationExceptionReason = "IdempotentParameterMismatchException"
	ValidationExceptionReasonRootEventInOtherSession              ValidationExceptionReason = "EventInOtherSession"
	ValidationExceptionReasonResourceConflict                     ValidationExceptionReason = "ResourceConflict"
)

// Values returns all known values for ValidationExceptionReason. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ValidationExceptionReason) Values() []ValidationExceptionReason {
	return []ValidationExceptionReason{
		"CannotParse",
		"FieldValidationFailed",
		"IdempotentParameterMismatchException",
		"EventInOtherSession",
		"ResourceConflict",
	}
}

type WafFailureMode string

// Enum values for WafFailureMode
const (
	WafFailureModeFailClose WafFailureMode = "FAIL_CLOSE"
	WafFailureModeFailOpen  WafFailureMode = "FAIL_OPEN"
)

// Values returns all known values for WafFailureMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WafFailureMode) Values() []WafFailureMode {
	return []WafFailureMode{
		"FAIL_CLOSE",
		"FAIL_OPEN",
	}
}
