// Code generated by smithy-go-codegen DO NOT EDIT.

package codecommit

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/codecommit/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Replaces the contents of a comment.
func (c *Client) UpdateComment(ctx context.Context, params *UpdateCommentInput, optFns ...func(*Options)) (*UpdateCommentOutput, error) {
	if params == nil {
		params = &UpdateCommentInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateComment", params, optFns, c.addOperationUpdateCommentMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateCommentOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateCommentInput struct {

	// The system-generated ID of the comment you want to update. To get this ID, use GetCommentsForComparedCommit
	// or GetCommentsForPullRequest.
	//
	// This member is required.
	CommentId *string

	// The updated content to replace the existing content of the comment.
	//
	// This member is required.
	Content *string

	noSmithyDocumentSerde
}

type UpdateCommentOutput struct {

	// Information about the updated comment.
	Comment *types.Comment

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateCommentMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpUpdateComment{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpUpdateComment{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateCommentValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateComment"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
