// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type BatchDeleteErrorCode string

// Enum values for BatchDeleteErrorCode
const (
	// Configuration already deleted or expired.
	BatchDeleteErrorCodeResourceNotFound BatchDeleteErrorCode = "ResourceNotFoundException"
	// Insufficient permissions to delete the configuration.
	BatchDeleteErrorCodeAccessDenied BatchDeleteErrorCode = "AccessDeniedException"
	// Internal service error for this item.
	BatchDeleteErrorCodeInternalServiceError BatchDeleteErrorCode = "InternalServiceException"
)

// Values returns all known values for BatchDeleteErrorCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BatchDeleteErrorCode) Values() []BatchDeleteErrorCode {
	return []BatchDeleteErrorCode{
		"ResourceNotFoundException",
		"AccessDeniedException",
		"InternalServiceException",
	}
}

type ChangeEventType string

// Enum values for ChangeEventType
const (
	ChangeEventTypeDeployment    ChangeEventType = "DEPLOYMENT"
	ChangeEventTypeConfiguration ChangeEventType = "CONFIGURATION"
)

// Values returns all known values for ChangeEventType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ChangeEventType) Values() []ChangeEventType {
	return []ChangeEventType{
		"DEPLOYMENT",
		"CONFIGURATION",
	}
}

type ConnectionType string

// Enum values for ConnectionType
const (
	ConnectionTypeIndirect ConnectionType = "INDIRECT"
	ConnectionTypeDirect   ConnectionType = "DIRECT"
)

// Values returns all known values for ConnectionType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConnectionType) Values() []ConnectionType {
	return []ConnectionType{
		"INDIRECT",
		"DIRECT",
	}
}

type DetailLevel string

// Enum values for DetailLevel
const (
	DetailLevelBrief    DetailLevel = "BRIEF"
	DetailLevelDetailed DetailLevel = "DETAILED"
)

// Values returns all known values for DetailLevel. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DetailLevel) Values() []DetailLevel {
	return []DetailLevel{
		"BRIEF",
		"DETAILED",
	}
}

type DurationUnit string

// Enum values for DurationUnit
const (
	DurationUnitMinute DurationUnit = "MINUTE"
	DurationUnitHour   DurationUnit = "HOUR"
	DurationUnitDay    DurationUnit = "DAY"
	DurationUnitMonth  DurationUnit = "MONTH"
)

// Values returns all known values for DurationUnit. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DurationUnit) Values() []DurationUnit {
	return []DurationUnit{
		"MINUTE",
		"HOUR",
		"DAY",
		"MONTH",
	}
}

type DynamicInstrumentationDeletionStatus string

// Enum values for DynamicInstrumentationDeletionStatus
const (
	DynamicInstrumentationDeletionStatusDeleted DynamicInstrumentationDeletionStatus = "DELETED"
)

// Values returns all known values for DynamicInstrumentationDeletionStatus. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DynamicInstrumentationDeletionStatus) Values() []DynamicInstrumentationDeletionStatus {
	return []DynamicInstrumentationDeletionStatus{
		"DELETED",
	}
}

type DynamicInstrumentationSignalType string

// Enum values for DynamicInstrumentationSignalType
const (
	DynamicInstrumentationSignalTypeSnapshot DynamicInstrumentationSignalType = "SNAPSHOT"
)

// Values returns all known values for DynamicInstrumentationSignalType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DynamicInstrumentationSignalType) Values() []DynamicInstrumentationSignalType {
	return []DynamicInstrumentationSignalType{
		"SNAPSHOT",
	}
}

type EvaluationType string

// Enum values for EvaluationType
const (
	EvaluationTypePeriodBased  EvaluationType = "PeriodBased"
	EvaluationTypeRequestBased EvaluationType = "RequestBased"
)

// Values returns all known values for EvaluationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluationType) Values() []EvaluationType {
	return []EvaluationType{
		"PeriodBased",
		"RequestBased",
	}
}

type InstrumentationConfigurationStatus string

// Enum values for InstrumentationConfigurationStatus
const (
	InstrumentationConfigurationStatusReady    InstrumentationConfigurationStatus = "READY"
	InstrumentationConfigurationStatusError    InstrumentationConfigurationStatus = "ERROR"
	InstrumentationConfigurationStatusActive   InstrumentationConfigurationStatus = "ACTIVE"
	InstrumentationConfigurationStatusDisabled InstrumentationConfigurationStatus = "DISABLED"
)

// Values returns all known values for InstrumentationConfigurationStatus. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstrumentationConfigurationStatus) Values() []InstrumentationConfigurationStatus {
	return []InstrumentationConfigurationStatus{
		"READY",
		"ERROR",
		"ACTIVE",
		"DISABLED",
	}
}

type InstrumentationErrorCause string

// Enum values for InstrumentationErrorCause
const (
	InstrumentationErrorCauseFileNotFound      InstrumentationErrorCause = "FILE_NOT_FOUND"
	InstrumentationErrorCauseMethodNotFound    InstrumentationErrorCause = "METHOD_NOT_FOUND"
	InstrumentationErrorCauseLineNotExecutable InstrumentationErrorCause = "LINE_NOT_EXECUTABLE"
	InstrumentationErrorCauseOverloadedMethods InstrumentationErrorCause = "OVERLOADED_METHODS"
	InstrumentationErrorCauseLanguageMismatch  InstrumentationErrorCause = "LANGUAGE_MISMATCH"
	InstrumentationErrorCauseRuntimeError      InstrumentationErrorCause = "RUNTIME_ERROR"
)

// Values returns all known values for InstrumentationErrorCause. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstrumentationErrorCause) Values() []InstrumentationErrorCause {
	return []InstrumentationErrorCause{
		"FILE_NOT_FOUND",
		"METHOD_NOT_FOUND",
		"LINE_NOT_EXECUTABLE",
		"OVERLOADED_METHODS",
		"LANGUAGE_MISMATCH",
		"RUNTIME_ERROR",
	}
}

type InstrumentationType string

// Enum values for InstrumentationType
const (
	// Temporary instrumentation that expires automatically (default 24 hours)
	InstrumentationTypeBreakpoint InstrumentationType = "BREAKPOINT"
	// Permanent instrumentation that persists until explicitly deleted
	InstrumentationTypeProbe InstrumentationType = "PROBE"
)

// Values returns all known values for InstrumentationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstrumentationType) Values() []InstrumentationType {
	return []InstrumentationType{
		"BREAKPOINT",
		"PROBE",
	}
}

type MetricSourceType string

// Enum values for MetricSourceType
const (
	MetricSourceTypeServiceOperation  MetricSourceType = "ServiceOperation"
	MetricSourceTypeCloudwatchMetric  MetricSourceType = "CloudWatchMetric"
	MetricSourceTypeServiceDependency MetricSourceType = "ServiceDependency"
	MetricSourceTypeAppmonitor        MetricSourceType = "AppMonitor"
	MetricSourceTypeCanary            MetricSourceType = "Canary"
	MetricSourceTypeService           MetricSourceType = "Service"
)

// Values returns all known values for MetricSourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MetricSourceType) Values() []MetricSourceType {
	return []MetricSourceType{
		"ServiceOperation",
		"CloudWatchMetric",
		"ServiceDependency",
		"AppMonitor",
		"Canary",
		"Service",
	}
}

type ProgrammingLanguage string

// Enum values for ProgrammingLanguage
const (
	ProgrammingLanguageJava       ProgrammingLanguage = "Java"
	ProgrammingLanguagePython     ProgrammingLanguage = "Python"
	ProgrammingLanguageJavascript ProgrammingLanguage = "Javascript"
)

// Values returns all known values for ProgrammingLanguage. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ProgrammingLanguage) Values() []ProgrammingLanguage {
	return []ProgrammingLanguage{
		"Java",
		"Python",
		"Javascript",
	}
}

type SelectionType string

// Enum values for SelectionType
const (
	SelectionTypeExplicit SelectionType = "EXPLICIT"
	SelectionTypePrefix   SelectionType = "PREFIX"
	SelectionTypeRegex    SelectionType = "REGEX"
)

// Values returns all known values for SelectionType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SelectionType) Values() []SelectionType {
	return []SelectionType{
		"EXPLICIT",
		"PREFIX",
		"REGEX",
	}
}

type ServiceLevelIndicatorComparisonOperator string

// Enum values for ServiceLevelIndicatorComparisonOperator
const (
	ServiceLevelIndicatorComparisonOperatorGreaterThanOrEqualTo ServiceLevelIndicatorComparisonOperator = "GreaterThanOrEqualTo"
	ServiceLevelIndicatorComparisonOperatorGreaterThan          ServiceLevelIndicatorComparisonOperator = "GreaterThan"
	ServiceLevelIndicatorComparisonOperatorLessThan             ServiceLevelIndicatorComparisonOperator = "LessThan"
	ServiceLevelIndicatorComparisonOperatorLessThanOrEqualTo    ServiceLevelIndicatorComparisonOperator = "LessThanOrEqualTo"
)

// Values returns all known values for ServiceLevelIndicatorComparisonOperator.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ServiceLevelIndicatorComparisonOperator) Values() []ServiceLevelIndicatorComparisonOperator {
	return []ServiceLevelIndicatorComparisonOperator{
		"GreaterThanOrEqualTo",
		"GreaterThan",
		"LessThan",
		"LessThanOrEqualTo",
	}
}

type ServiceLevelIndicatorMetricType string

// Enum values for ServiceLevelIndicatorMetricType
const (
	ServiceLevelIndicatorMetricTypeLatency      ServiceLevelIndicatorMetricType = "LATENCY"
	ServiceLevelIndicatorMetricTypeAvailability ServiceLevelIndicatorMetricType = "AVAILABILITY"
)

// Values returns all known values for ServiceLevelIndicatorMetricType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ServiceLevelIndicatorMetricType) Values() []ServiceLevelIndicatorMetricType {
	return []ServiceLevelIndicatorMetricType{
		"LATENCY",
		"AVAILABILITY",
	}
}

type ServiceLevelObjectiveBudgetStatus string

// Enum values for ServiceLevelObjectiveBudgetStatus
const (
	ServiceLevelObjectiveBudgetStatusOk               ServiceLevelObjectiveBudgetStatus = "OK"
	ServiceLevelObjectiveBudgetStatusWarning          ServiceLevelObjectiveBudgetStatus = "WARNING"
	ServiceLevelObjectiveBudgetStatusBreached         ServiceLevelObjectiveBudgetStatus = "BREACHED"
	ServiceLevelObjectiveBudgetStatusInsufficientData ServiceLevelObjectiveBudgetStatus = "INSUFFICIENT_DATA"
)

// Values returns all known values for ServiceLevelObjectiveBudgetStatus. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ServiceLevelObjectiveBudgetStatus) Values() []ServiceLevelObjectiveBudgetStatus {
	return []ServiceLevelObjectiveBudgetStatus{
		"OK",
		"WARNING",
		"BREACHED",
		"INSUFFICIENT_DATA",
	}
}

type Severity string

// Enum values for Severity
const (
	SeverityCritical Severity = "CRITICAL"
	SeverityHigh     Severity = "HIGH"
	SeverityMedium   Severity = "MEDIUM"
	SeverityLow      Severity = "LOW"
	SeverityNone     Severity = "NONE"
)

// Values returns all known values for Severity. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Severity) Values() []Severity {
	return []Severity{
		"CRITICAL",
		"HIGH",
		"MEDIUM",
		"LOW",
		"NONE",
	}
}

type StandardUnit string

// Enum values for StandardUnit
const (
	StandardUnitMicroseconds    StandardUnit = "Microseconds"
	StandardUnitMilliseconds    StandardUnit = "Milliseconds"
	StandardUnitSeconds         StandardUnit = "Seconds"
	StandardUnitBytes           StandardUnit = "Bytes"
	StandardUnitKilobytes       StandardUnit = "Kilobytes"
	StandardUnitMegabytes       StandardUnit = "Megabytes"
	StandardUnitGigabytes       StandardUnit = "Gigabytes"
	StandardUnitTerabytes       StandardUnit = "Terabytes"
	StandardUnitBits            StandardUnit = "Bits"
	StandardUnitKilobits        StandardUnit = "Kilobits"
	StandardUnitMegabits        StandardUnit = "Megabits"
	StandardUnitGigabits        StandardUnit = "Gigabits"
	StandardUnitTerabits        StandardUnit = "Terabits"
	StandardUnitPercent         StandardUnit = "Percent"
	StandardUnitCount           StandardUnit = "Count"
	StandardUnitBytesSecond     StandardUnit = "Bytes/Second"
	StandardUnitKilobytesSecond StandardUnit = "Kilobytes/Second"
	StandardUnitMegabytesSecond StandardUnit = "Megabytes/Second"
	StandardUnitGigabytesSecond StandardUnit = "Gigabytes/Second"
	StandardUnitTerabytesSecond StandardUnit = "Terabytes/Second"
	StandardUnitBitsSecond      StandardUnit = "Bits/Second"
	StandardUnitKilobitsSecond  StandardUnit = "Kilobits/Second"
	StandardUnitMegabitsSecond  StandardUnit = "Megabits/Second"
	StandardUnitGigabitsSecond  StandardUnit = "Gigabits/Second"
	StandardUnitTerabitsSecond  StandardUnit = "Terabits/Second"
	StandardUnitCountSecond     StandardUnit = "Count/Second"
	StandardUnitNone            StandardUnit = "None"
)

// Values returns all known values for StandardUnit. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (StandardUnit) Values() []StandardUnit {
	return []StandardUnit{
		"Microseconds",
		"Milliseconds",
		"Seconds",
		"Bytes",
		"Kilobytes",
		"Megabytes",
		"Gigabytes",
		"Terabytes",
		"Bits",
		"Kilobits",
		"Megabits",
		"Gigabits",
		"Terabits",
		"Percent",
		"Count",
		"Bytes/Second",
		"Kilobytes/Second",
		"Megabytes/Second",
		"Gigabytes/Second",
		"Terabytes/Second",
		"Bits/Second",
		"Kilobits/Second",
		"Megabits/Second",
		"Gigabits/Second",
		"Terabits/Second",
		"Count/Second",
		"None",
	}
}

type UnprocessedStatusEventFailureReason string

// Enum values for UnprocessedStatusEventFailureReason
const (
	UnprocessedStatusEventFailureReasonThrottled       UnprocessedStatusEventFailureReason = "THROTTLED"
	UnprocessedStatusEventFailureReasonInternalError   UnprocessedStatusEventFailureReason = "INTERNAL_ERROR"
	UnprocessedStatusEventFailureReasonValidationError UnprocessedStatusEventFailureReason = "VALIDATION_ERROR"
)

// Values returns all known values for UnprocessedStatusEventFailureReason. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (UnprocessedStatusEventFailureReason) Values() []UnprocessedStatusEventFailureReason {
	return []UnprocessedStatusEventFailureReason{
		"THROTTLED",
		"INTERNAL_ERROR",
		"VALIDATION_ERROR",
	}
}
