// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrock

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrock/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Registers an existing Amazon SageMaker endpoint with Amazon Bedrock
// Marketplace, allowing it to be used with Amazon Bedrock APIs.
func (c *Client) RegisterMarketplaceModelEndpoint(ctx context.Context, params *RegisterMarketplaceModelEndpointInput, optFns ...func(*Options)) (*RegisterMarketplaceModelEndpointOutput, error) {
	if params == nil {
		params = &RegisterMarketplaceModelEndpointInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "RegisterMarketplaceModelEndpoint", params, optFns, c.addOperationRegisterMarketplaceModelEndpointMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*RegisterMarketplaceModelEndpointOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type RegisterMarketplaceModelEndpointInput struct {

	// The ARN of the Amazon SageMaker endpoint you want to register with Amazon
	// Bedrock Marketplace.
	//
	// This member is required.
	EndpointIdentifier *string

	// The ARN of the model from Amazon Bedrock Marketplace that is deployed on the
	// endpoint.
	//
	// This member is required.
	ModelSourceIdentifier *string

	noSmithyDocumentSerde
}

type RegisterMarketplaceModelEndpointOutput struct {

	// Details about the registered endpoint.
	//
	// This member is required.
	MarketplaceModelEndpoint *types.MarketplaceModelEndpoint

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationRegisterMarketplaceModelEndpointMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpRegisterMarketplaceModelEndpoint{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpRegisterMarketplaceModelEndpoint{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpRegisterMarketplaceModelEndpointValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "RegisterMarketplaceModelEndpoint"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
