// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcorecontrol

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcorecontrol/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Deletes an online evaluation configuration and stops any ongoing evaluation
//
// processes associated with it.
func (c *Client) DeleteOnlineEvaluationConfig(ctx context.Context, params *DeleteOnlineEvaluationConfigInput, optFns ...func(*Options)) (*DeleteOnlineEvaluationConfigOutput, error) {
	if params == nil {
		params = &DeleteOnlineEvaluationConfigInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteOnlineEvaluationConfig", params, optFns, c.addOperationDeleteOnlineEvaluationConfigMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteOnlineEvaluationConfigOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteOnlineEvaluationConfigInput struct {

	//  The unique identifier of the online evaluation configuration to delete.
	//
	// This member is required.
	OnlineEvaluationConfigId *string

	noSmithyDocumentSerde
}

type DeleteOnlineEvaluationConfigOutput struct {

	//  The Amazon Resource Name (ARN) of the deleted online evaluation configuration.
	//
	// This member is required.
	OnlineEvaluationConfigArn *string

	//  The unique identifier of the deleted online evaluation configuration.
	//
	// This member is required.
	OnlineEvaluationConfigId *string

	//  The status of the online evaluation configuration deletion operation.
	//
	// This member is required.
	Status types.OnlineEvaluationConfigStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteOnlineEvaluationConfigMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteOnlineEvaluationConfig{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteOnlineEvaluationConfig{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteOnlineEvaluationConfigValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteOnlineEvaluationConfig"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
