// Code generated by smithy-go-codegen DO NOT EDIT.

// Package batch provides the API client, operations, and parameter types for AWS
// Batch.
//
// # Batch
//
// Using Batch, you can run batch computing workloads on the Amazon Web Services
// Cloud. Batch computing is a common means for developers, scientists, and
// engineers to access large amounts of compute resources. Batch uses the
// advantages of the batch computing to remove the undifferentiated heavy lifting
// of configuring and managing required infrastructure. At the same time, it also
// adopts a familiar batch computing software approach. You can use Batch to
// efficiently provision resources, and work toward eliminating capacity
// constraints, reducing your overall compute costs, and delivering results more
// quickly.
//
// As a fully managed service, Batch can run batch computing workloads of any
// scale. Batch automatically provisions compute resources and optimizes workload
// distribution based on the quantity and scale of your specific workloads. With
// Batch, there's no need to install or manage batch computing software. This means
// that you can focus on analyzing results and solving your specific problems
// instead.
package batch
