// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanroomsml

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanroomsml/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates a configured model algorithm using a container image stored in an ECR
// repository.
func (c *Client) CreateConfiguredModelAlgorithm(ctx context.Context, params *CreateConfiguredModelAlgorithmInput, optFns ...func(*Options)) (*CreateConfiguredModelAlgorithmOutput, error) {
	if params == nil {
		params = &CreateConfiguredModelAlgorithmInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateConfiguredModelAlgorithm", params, optFns, c.addOperationCreateConfiguredModelAlgorithmMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateConfiguredModelAlgorithmOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateConfiguredModelAlgorithmInput struct {

	// The name of the configured model algorithm.
	//
	// This member is required.
	Name *string

	// The Amazon Resource Name (ARN) of the role that is used to access the
	// repository.
	//
	// This member is required.
	RoleArn *string

	// The description of the configured model algorithm.
	Description *string

	// Configuration information for the inference container that is used when you run
	// an inference job on a configured model algorithm.
	InferenceContainerConfig *types.InferenceContainerConfig

	// The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt and
	// decrypt customer-owned data in the configured ML model algorithm and associated
	// data.
	KmsKeyArn *string

	// The optional metadata that you apply to the resource to help you categorize and
	// organize them. Each tag consists of a key and an optional value, both of which
	// you define.
	//
	// The following basic restrictions apply to tags:
	//
	//   - Maximum number of tags per resource - 50.
	//
	//   - For each resource, each tag key must be unique, and each tag key can have
	//   only one value.
	//
	//   - Maximum key length - 128 Unicode characters in UTF-8.
	//
	//   - Maximum value length - 256 Unicode characters in UTF-8.
	//
	//   - If your tagging schema is used across multiple services and resources,
	//   remember that other services may have restrictions on allowed characters.
	//   Generally allowed characters are: letters, numbers, and spaces representable in
	//   UTF-8, and the following characters: + - = . _ : / @.
	//
	//   - Tag keys and values are case sensitive.
	//
	//   - Do not use aws:, AWS:, or any upper or lowercase combination of such as a
	//   prefix for keys as it is reserved for AWS use. You cannot edit or delete tag
	//   keys with this prefix. Values can have this prefix. If a tag value has aws as
	//   its prefix but the key does not, then Clean Rooms ML considers it to be a user
	//   tag and will count against the limit of 50 tags. Tags with only the key prefix
	//   of aws do not count against your tags per resource limit.
	Tags map[string]string

	// Configuration information for the training container, including entrypoints and
	// arguments.
	TrainingContainerConfig *types.ContainerConfig

	noSmithyDocumentSerde
}

type CreateConfiguredModelAlgorithmOutput struct {

	// The Amazon Resource Name (ARN) of the configured model algorithm.
	//
	// This member is required.
	ConfiguredModelAlgorithmArn *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateConfiguredModelAlgorithmMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCreateConfiguredModelAlgorithm{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCreateConfiguredModelAlgorithm{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateConfiguredModelAlgorithmValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateConfiguredModelAlgorithm"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
