// Code generated by internal/repotools/cmd/updatemodulemeta DO NOT EDIT.

package querycompatiblerpcv2protocol

// goModuleVersion is the tagged release for this module
const goModuleVersion = "tip"
