// Code generated by smithy-go-codegen DO NOT EDIT.

// Package bedrockdataautomation provides the API client, operations, and
// parameter types for Data Automation for Amazon Bedrock.
//
// Amazon Bedrock Data Automation BuildTime
package bedrockdataautomation
