// Code generated by smithy-go-codegen DO NOT EDIT.

package comprehendmedical

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/comprehendmedical/schemas"
	"github.com/aws/aws-sdk-go-v2/service/comprehendmedical/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Gets a list of InferSNOMEDCT jobs a user has submitted.
func (c *Client) ListSNOMEDCTInferenceJobs(ctx context.Context, params *ListSNOMEDCTInferenceJobsInput, optFns ...func(*Options)) (*ListSNOMEDCTInferenceJobsOutput, error) {
	if params == nil {
		params = &ListSNOMEDCTInferenceJobsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListSNOMEDCTInferenceJobs", params, optFns, c.addOperationListSNOMEDCTInferenceJobsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListSNOMEDCTInferenceJobsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListSNOMEDCTInferenceJobsInput struct {

	// Provides information for filtering a list of detection jobs.
	Filter *types.ComprehendMedicalAsyncJobFilter

	//  The maximum number of results to return in each page. The default is 100.
	MaxResults *int32

	//  Identifies the next page of InferSNOMEDCT results to return.
	NextToken *string

	noSmithyDocumentSerde
}

func (v *ListSNOMEDCTInferenceJobsInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.ListSNOMEDCTInferenceJobsRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *ListSNOMEDCTInferenceJobsInput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.Filter != nil {
		s.WriteStruct(schemas.ListSNOMEDCTInferenceJobsRequest_Filter)
		v.Filter.SerializeMembers(s)
		s.CloseStruct()
	}
	if v.MaxResults != nil {
		s.WriteInt32(schemas.ListSNOMEDCTInferenceJobsRequest_MaxResults, *v.MaxResults)
	}
	if v.NextToken != nil {
		s.WriteString(schemas.ListSNOMEDCTInferenceJobsRequest_NextToken, *v.NextToken)
	}
}

type ListSNOMEDCTInferenceJobsOutput struct {

	//  A list containing the properties of each job that is returned.
	ComprehendMedicalAsyncJobPropertiesList []types.ComprehendMedicalAsyncJobProperties

	//  Identifies the next page of results to return.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *ListSNOMEDCTInferenceJobsOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.ListSNOMEDCTInferenceJobsResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *ListSNOMEDCTInferenceJobsOutput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeComprehendMedicalAsyncJobPropertiesList(s, schemas.ListSNOMEDCTInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList, v.ComprehendMedicalAsyncJobPropertiesList)
	if v.NextToken != nil {
		s.WriteString(schemas.ListSNOMEDCTInferenceJobsResponse_NextToken, *v.NextToken)
	}
}
func (v *ListSNOMEDCTInferenceJobsOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.ListSNOMEDCTInferenceJobsResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.ListSNOMEDCTInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList:
			return deserializeComprehendMedicalAsyncJobPropertiesList(d, schemas.ListSNOMEDCTInferenceJobsResponse_ComprehendMedicalAsyncJobPropertiesList, &v.ComprehendMedicalAsyncJobPropertiesList)
		case schemas.ListSNOMEDCTInferenceJobsResponse_NextToken:
			v.NextToken = new(string)
			return d.ReadString(schemas.ListSNOMEDCTInferenceJobsResponse_NextToken, v.NextToken)
		}
		return nil
	})
}
func (c *Client) addOperationListSNOMEDCTInferenceJobsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.ListSNOMEDCTInferenceJobs, schemas.ListSNOMEDCTInferenceJobsRequest, schemas.ListSNOMEDCTInferenceJobsResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.ListSNOMEDCTInferenceJobs, schemas.ListSNOMEDCTInferenceJobsRequest, schemas.ListSNOMEDCTInferenceJobsResponse), output: &ListSNOMEDCTInferenceJobsOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListSNOMEDCTInferenceJobs"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
