// Code generated by smithy-go-codegen DO NOT EDIT.

// Package bedrockruntime provides the API client, operations, and parameter types
// for Amazon Bedrock Runtime.
//
// Describes the API operations for running inference using Amazon Bedrock models.
package bedrockruntime
