// Code generated by smithy-go-codegen DO NOT EDIT.

// Package bedrockagentcore provides the API client, operations, and parameter
// types for Amazon Bedrock AgentCore.
//
// Welcome to the Amazon Bedrock AgentCore Data Plane API reference. Data Plane
// actions process and handle data or workloads within Amazon Web Services
// services.
package bedrockagentcore
