// Code generated by smithy-go-codegen DO NOT EDIT.

// Package cloudcontrol provides the API client, operations, and parameter types
// for AWS Cloud Control API.
//
// For more information about Amazon Web Services Cloud Control API, see the [Amazon Web Services Cloud Control API User Guide].
//
// [Amazon Web Services Cloud Control API User Guide]: https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/what-is-cloudcontrolapi.html
package cloudcontrol
