// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanrooms

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanrooms/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Provides the details that are necessary to update an ID mapping table.
func (c *Client) UpdateIdMappingTable(ctx context.Context, params *UpdateIdMappingTableInput, optFns ...func(*Options)) (*UpdateIdMappingTableOutput, error) {
	if params == nil {
		params = &UpdateIdMappingTableInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateIdMappingTable", params, optFns, c.addOperationUpdateIdMappingTableMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateIdMappingTableOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateIdMappingTableInput struct {

	// The unique identifier of the ID mapping table that you want to update.
	//
	// This member is required.
	IdMappingTableIdentifier *string

	// The unique identifier of the membership that contains the ID mapping table that
	// you want to update.
	//
	// This member is required.
	MembershipIdentifier *string

	// A new description for the ID mapping table.
	Description *string

	// The Amazon Resource Name (ARN) of the Amazon Web Services KMS key.
	KmsKeyArn *string

	noSmithyDocumentSerde
}

type UpdateIdMappingTableOutput struct {

	// The updated ID mapping table.
	//
	// This member is required.
	IdMappingTable *types.IdMappingTable

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateIdMappingTableMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateIdMappingTable{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateIdMappingTable{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateIdMappingTableValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateIdMappingTable"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
