// Code generated by smithy-go-codegen DO NOT EDIT.

// Package cloudformation provides the API client, operations, and parameter types
// for AWS CloudFormation.
//
// # CloudFormation
//
// CloudFormation allows you to create and manage Amazon Web Services
// infrastructure deployments predictably and repeatedly. You can use
// CloudFormation to leverage Amazon Web Services products, such as Amazon Elastic
// Compute Cloud, Amazon Elastic Block Store, Amazon Simple Notification Service,
// Elastic Load Balancing, and Amazon EC2 Auto Scaling to build highly reliable,
// highly scalable, cost-effective applications without creating or configuring the
// underlying Amazon Web Services infrastructure.
//
// With CloudFormation, you declare all your resources and dependencies in a
// template file. The template defines a collection of resources as a single unit
// called a stack. CloudFormation creates and deletes all member resources of the
// stack together and manages all dependencies between the resources for you.
//
// For more information about CloudFormation, see the [CloudFormation product page].
//
// CloudFormation makes use of other Amazon Web Services products. If you need
// additional technical information about a specific Amazon Web Services product,
// you can find the product's technical documentation at [docs.aws.amazon.com].
//
// [docs.aws.amazon.com]: https://docs.aws.amazon.com/
// [CloudFormation product page]: http://aws.amazon.com/cloudformation/
package cloudformation
