// Code generated by smithy-go-codegen DO NOT EDIT.

package computeoptimizer

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/schemas"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns existing recommendation preferences, such as enhanced infrastructure
// metrics.
//
// Use the scope parameter to specify which preferences to return. You can specify
// to return preferences for an organization, a specific account ID, or a specific
// EC2 instance or Auto Scaling group Amazon Resource Name (ARN).
//
// For more information, see [Activating enhanced infrastructure metrics] in the Compute Optimizer User Guide.
//
// [Activating enhanced infrastructure metrics]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html
func (c *Client) GetRecommendationPreferences(ctx context.Context, params *GetRecommendationPreferencesInput, optFns ...func(*Options)) (*GetRecommendationPreferencesOutput, error) {
	if params == nil {
		params = &GetRecommendationPreferencesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetRecommendationPreferences", params, optFns, c.addOperationGetRecommendationPreferencesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetRecommendationPreferencesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetRecommendationPreferencesInput struct {

	// The target resource type of the recommendation preference for which to return
	// preferences.
	//
	// The Ec2Instance option encompasses standalone instances and instances that are
	// part of Auto Scaling groups. The AutoScalingGroup option encompasses only
	// instances that are part of an Auto Scaling group.
	//
	// This member is required.
	ResourceType types.ResourceType

	// The maximum number of recommendation preferences to return with a single
	// request.
	//
	// To retrieve the remaining results, make another request with the returned
	// nextToken value.
	MaxResults *int32

	// The token to advance to the next page of recommendation preferences.
	NextToken *string

	// An object that describes the scope of the recommendation preference to return.
	//
	// You can return recommendation preferences that are created at the organization
	// level (for management accounts of an organization only), account level, and
	// resource level. For more information, see [Activating enhanced infrastructure metrics]in the Compute Optimizer User Guide.
	//
	// [Activating enhanced infrastructure metrics]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/enhanced-infrastructure-metrics.html
	Scope *types.Scope

	noSmithyDocumentSerde
}

func (v *GetRecommendationPreferencesInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetRecommendationPreferencesRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetRecommendationPreferencesInput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.MaxResults != nil {
		s.WriteInt32(schemas.GetRecommendationPreferencesRequest_maxResults, *v.MaxResults)
	}
	if v.NextToken != nil {
		s.WriteString(schemas.GetRecommendationPreferencesRequest_nextToken, *v.NextToken)
	}
	if v.ResourceType != "" {
		s.WriteString(schemas.GetRecommendationPreferencesRequest_resourceType, string(v.ResourceType))
	}
	if v.Scope != nil {
		s.WriteStruct(schemas.GetRecommendationPreferencesRequest_scope)
		v.Scope.SerializeMembers(s)
		s.CloseStruct()
	}
}

type GetRecommendationPreferencesOutput struct {

	// The token to use to advance to the next page of recommendation preferences.
	//
	// This value is null when there are no more pages of recommendation preferences
	// to return.
	NextToken *string

	// An array of objects that describe recommendation preferences.
	RecommendationPreferencesDetails []types.RecommendationPreferencesDetail

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *GetRecommendationPreferencesOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetRecommendationPreferencesResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetRecommendationPreferencesOutput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.NextToken != nil {
		s.WriteString(schemas.GetRecommendationPreferencesResponse_nextToken, *v.NextToken)
	}
	serializeRecommendationPreferencesDetails(s, schemas.GetRecommendationPreferencesResponse_recommendationPreferencesDetails, v.RecommendationPreferencesDetails)
}
func (v *GetRecommendationPreferencesOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.GetRecommendationPreferencesResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.GetRecommendationPreferencesResponse_nextToken:
			v.NextToken = new(string)
			return d.ReadString(schemas.GetRecommendationPreferencesResponse_nextToken, v.NextToken)
		case schemas.GetRecommendationPreferencesResponse_recommendationPreferencesDetails:
			return deserializeRecommendationPreferencesDetails(d, schemas.GetRecommendationPreferencesResponse_recommendationPreferencesDetails, &v.RecommendationPreferencesDetails)
		}
		return nil
	})
}
func (c *Client) addOperationGetRecommendationPreferencesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetRecommendationPreferences, schemas.GetRecommendationPreferencesRequest, schemas.GetRecommendationPreferencesResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetRecommendationPreferences, schemas.GetRecommendationPreferencesRequest, schemas.GetRecommendationPreferencesResponse), output: &GetRecommendationPreferencesOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetRecommendationPreferencesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetRecommendationPreferences"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// GetRecommendationPreferencesPaginatorOptions is the paginator options for
// GetRecommendationPreferences
type GetRecommendationPreferencesPaginatorOptions struct {
	// The maximum number of recommendation preferences to return with a single
	// request.
	//
	// To retrieve the remaining results, make another request with the returned
	// nextToken value.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// GetRecommendationPreferencesPaginator is a paginator for
// GetRecommendationPreferences
type GetRecommendationPreferencesPaginator struct {
	options   GetRecommendationPreferencesPaginatorOptions
	client    GetRecommendationPreferencesAPIClient
	params    *GetRecommendationPreferencesInput
	nextToken *string
	firstPage bool
}

// NewGetRecommendationPreferencesPaginator returns a new
// GetRecommendationPreferencesPaginator
func NewGetRecommendationPreferencesPaginator(client GetRecommendationPreferencesAPIClient, params *GetRecommendationPreferencesInput, optFns ...func(*GetRecommendationPreferencesPaginatorOptions)) *GetRecommendationPreferencesPaginator {
	if params == nil {
		params = &GetRecommendationPreferencesInput{}
	}

	options := GetRecommendationPreferencesPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &GetRecommendationPreferencesPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *GetRecommendationPreferencesPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next GetRecommendationPreferences page.
func (p *GetRecommendationPreferencesPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*GetRecommendationPreferencesOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.GetRecommendationPreferences(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// GetRecommendationPreferencesAPIClient is a client that implements the
// GetRecommendationPreferences operation.
type GetRecommendationPreferencesAPIClient interface {
	GetRecommendationPreferences(context.Context, *GetRecommendationPreferencesInput, ...func(*Options)) (*GetRecommendationPreferencesOutput, error)
}

var _ GetRecommendationPreferencesAPIClient = (*Client)(nil)
