// Code generated by smithy-go-codegen DO NOT EDIT.

package computeoptimizer

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/schemas"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Returns Amazon Aurora and RDS database recommendations.
//
// Compute Optimizer generates recommendations for Amazon Aurora and RDS databases
// that meet a specific set of requirements. For more information, see the [Supported resources and requirements]in the
// Compute Optimizer User Guide.
//
// [Supported resources and requirements]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/requirements.html
func (c *Client) GetRDSDatabaseRecommendations(ctx context.Context, params *GetRDSDatabaseRecommendationsInput, optFns ...func(*Options)) (*GetRDSDatabaseRecommendationsOutput, error) {
	if params == nil {
		params = &GetRDSDatabaseRecommendationsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetRDSDatabaseRecommendations", params, optFns, c.addOperationGetRDSDatabaseRecommendationsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetRDSDatabaseRecommendationsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetRDSDatabaseRecommendationsInput struct {

	//  Return the Amazon Aurora and RDS database recommendations to the specified
	// Amazon Web Services account IDs.
	//
	// If your account is the management account or the delegated administrator of an
	// organization, use this parameter to return the Amazon Aurora and RDS database
	// recommendations to specific member accounts.
	//
	// You can only specify one account ID per request.
	AccountIds []string

	//  An array of objects to specify a filter that returns a more specific list of
	// Amazon Aurora and RDS database recommendations.
	Filters []types.RDSDBRecommendationFilter

	// The maximum number of Amazon Aurora and RDS database recommendations to return
	// with a single request.
	//
	// To retrieve the remaining results, make another request with the returned
	// nextToken value.
	MaxResults *int32

	//  The token to advance to the next page of Amazon Aurora and RDS database
	// recommendations.
	NextToken *string

	// Describes the recommendation preferences to return in the response of a GetAutoScalingGroupRecommendations, GetEC2InstanceRecommendations, GetEC2RecommendationProjectedMetrics, GetRDSDatabaseRecommendations,
	// and GetRDSDatabaseRecommendationProjectedMetricsrequest.
	RecommendationPreferences *types.RecommendationPreferences

	//  The ARN that identifies the Amazon Aurora or RDS database.
	//
	// The following is the format of the ARN:
	//
	//     arn:aws:rds:{region}:{accountId}:db:{resourceName}
	//
	// The following is the format of a DB Cluster ARN:
	//
	//     arn:aws:rds:{region}:{accountId}:cluster:{resourceName}
	ResourceArns []string

	noSmithyDocumentSerde
}

func (v *GetRDSDatabaseRecommendationsInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetRDSDatabaseRecommendationsRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetRDSDatabaseRecommendationsInput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeAccountIds(s, schemas.GetRDSDatabaseRecommendationsRequest_accountIds, v.AccountIds)
	serializeRDSDBRecommendationFilters(s, schemas.GetRDSDatabaseRecommendationsRequest_filters, v.Filters)
	if v.MaxResults != nil {
		s.WriteInt32(schemas.GetRDSDatabaseRecommendationsRequest_maxResults, *v.MaxResults)
	}
	if v.NextToken != nil {
		s.WriteString(schemas.GetRDSDatabaseRecommendationsRequest_nextToken, *v.NextToken)
	}
	if v.RecommendationPreferences != nil {
		s.WriteStruct(schemas.GetRDSDatabaseRecommendationsRequest_recommendationPreferences)
		v.RecommendationPreferences.SerializeMembers(s)
		s.CloseStruct()
	}
	serializeResourceArns(s, schemas.GetRDSDatabaseRecommendationsRequest_resourceArns, v.ResourceArns)
}

type GetRDSDatabaseRecommendationsOutput struct {

	//  An array of objects that describe errors of the request.
	Errors []types.GetRecommendationError

	//  The token to advance to the next page of Amazon Aurora and RDS database
	// recommendations.
	NextToken *string

	//  An array of objects that describe the Amazon Aurora and RDS database
	// recommendations.
	RdsDBRecommendations []types.RDSDBRecommendation

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *GetRDSDatabaseRecommendationsOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.GetRDSDatabaseRecommendationsResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *GetRDSDatabaseRecommendationsOutput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeGetRecommendationErrors(s, schemas.GetRDSDatabaseRecommendationsResponse_errors, v.Errors)
	if v.NextToken != nil {
		s.WriteString(schemas.GetRDSDatabaseRecommendationsResponse_nextToken, *v.NextToken)
	}
	serializeRDSDBRecommendations(s, schemas.GetRDSDatabaseRecommendationsResponse_rdsDBRecommendations, v.RdsDBRecommendations)
}
func (v *GetRDSDatabaseRecommendationsOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.GetRDSDatabaseRecommendationsResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.GetRDSDatabaseRecommendationsResponse_errors:
			return deserializeGetRecommendationErrors(d, schemas.GetRDSDatabaseRecommendationsResponse_errors, &v.Errors)
		case schemas.GetRDSDatabaseRecommendationsResponse_nextToken:
			v.NextToken = new(string)
			return d.ReadString(schemas.GetRDSDatabaseRecommendationsResponse_nextToken, v.NextToken)
		case schemas.GetRDSDatabaseRecommendationsResponse_rdsDBRecommendations:
			return deserializeRDSDBRecommendations(d, schemas.GetRDSDatabaseRecommendationsResponse_rdsDBRecommendations, &v.RdsDBRecommendations)
		}
		return nil
	})
}
func (c *Client) addOperationGetRDSDatabaseRecommendationsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetRDSDatabaseRecommendations, schemas.GetRDSDatabaseRecommendationsRequest, schemas.GetRDSDatabaseRecommendationsResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.GetRDSDatabaseRecommendations, schemas.GetRDSDatabaseRecommendationsRequest, schemas.GetRDSDatabaseRecommendationsResponse), output: &GetRDSDatabaseRecommendationsOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetRDSDatabaseRecommendations"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
