// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcore

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcore/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates multiple memory records with custom content in a single batch operation
// within the specified memory.
func (c *Client) BatchUpdateMemoryRecords(ctx context.Context, params *BatchUpdateMemoryRecordsInput, optFns ...func(*Options)) (*BatchUpdateMemoryRecordsOutput, error) {
	if params == nil {
		params = &BatchUpdateMemoryRecordsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "BatchUpdateMemoryRecords", params, optFns, c.addOperationBatchUpdateMemoryRecordsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*BatchUpdateMemoryRecordsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type BatchUpdateMemoryRecordsInput struct {

	// The unique ID of the memory resource where records will be updated.
	//
	// This member is required.
	MemoryId *string

	// A list of memory record update inputs to be processed in the batch operation.
	//
	// This member is required.
	Records []types.MemoryRecordUpdateInput

	noSmithyDocumentSerde
}

type BatchUpdateMemoryRecordsOutput struct {

	// A list of memory records that failed to be updated, including error details for
	// each failure.
	//
	// This member is required.
	FailedRecords []types.MemoryRecordOutput

	// A list of memory records that were successfully updated during the batch
	// operation.
	//
	// This member is required.
	SuccessfulRecords []types.MemoryRecordOutput

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationBatchUpdateMemoryRecordsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpBatchUpdateMemoryRecords{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpBatchUpdateMemoryRecords{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpBatchUpdateMemoryRecordsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "BatchUpdateMemoryRecords"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
