// Code generated by smithy-go-codegen DO NOT EDIT.

package comprehendmedical

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/comprehendmedical/schemas"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Stops an InferRxNorm inference job in progress.
func (c *Client) StopRxNormInferenceJob(ctx context.Context, params *StopRxNormInferenceJobInput, optFns ...func(*Options)) (*StopRxNormInferenceJobOutput, error) {
	if params == nil {
		params = &StopRxNormInferenceJobInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "StopRxNormInferenceJob", params, optFns, c.addOperationStopRxNormInferenceJobMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*StopRxNormInferenceJobOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type StopRxNormInferenceJobInput struct {

	// The identifier of the job.
	//
	// This member is required.
	JobId *string

	noSmithyDocumentSerde
}

func (v *StopRxNormInferenceJobInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.StopRxNormInferenceJobRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *StopRxNormInferenceJobInput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.JobId != nil {
		s.WriteString(schemas.StopRxNormInferenceJobRequest_JobId, *v.JobId)
	}
}

type StopRxNormInferenceJobOutput struct {

	// The identifier generated for the job. To get the status of job, use this
	// identifier with the DescribeRxNormInferenceJob operation.
	JobId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *StopRxNormInferenceJobOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.StopRxNormInferenceJobResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *StopRxNormInferenceJobOutput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.JobId != nil {
		s.WriteString(schemas.StopRxNormInferenceJobResponse_JobId, *v.JobId)
	}
}
func (v *StopRxNormInferenceJobOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.StopRxNormInferenceJobResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.StopRxNormInferenceJobResponse_JobId:
			v.JobId = new(string)
			return d.ReadString(schemas.StopRxNormInferenceJobResponse_JobId, v.JobId)
		}
		return nil
	})
}
func (c *Client) addOperationStopRxNormInferenceJobMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.StopRxNormInferenceJob, schemas.StopRxNormInferenceJobRequest, schemas.StopRxNormInferenceJobResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.StopRxNormInferenceJob, schemas.StopRxNormInferenceJobRequest, schemas.StopRxNormInferenceJobResponse), output: &StopRxNormInferenceJobOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpStopRxNormInferenceJobValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "StopRxNormInferenceJob"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
