// Code generated by smithy-go-codegen DO NOT EDIT.

// Package restxmlwithnamespace provides the API client, operations, and parameter
// types for Sample Rest Xml Protocol Service With Namespace.
//
// A REST XML service that sends XML requests and responses.
//
// This service and test case is complementary to the test cases in the restXml
// directory, but the service under test here has the xmlNamespace trait applied
// to it.
//
// See https://github.com/smithy-lang/smithy/issues/616
package restxmlwithnamespace
