// Code generated by smithy-go-codegen DO NOT EDIT.

package computeoptimizer

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/schemas"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizer/types"
	smithy "github.com/aws/smithy-go"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Export optimization recommendations for your licenses.
//
// Recommendations are exported in a comma-separated values (CSV) file, and its
// metadata in a JavaScript Object Notation (JSON) file, to an existing Amazon
// Simple Storage Service (Amazon S3) bucket that you specify. For more
// information, see [Exporting Recommendations]in the Compute Optimizer User Guide.
//
// You can have only one license export job in progress per Amazon Web Services
// Region.
//
// [Exporting Recommendations]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html
func (c *Client) ExportLicenseRecommendations(ctx context.Context, params *ExportLicenseRecommendationsInput, optFns ...func(*Options)) (*ExportLicenseRecommendationsOutput, error) {
	if params == nil {
		params = &ExportLicenseRecommendationsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ExportLicenseRecommendations", params, optFns, c.addOperationExportLicenseRecommendationsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ExportLicenseRecommendationsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ExportLicenseRecommendationsInput struct {

	// Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name
	// and key prefix for a recommendations export job.
	//
	// You must create the destination Amazon S3 bucket for your recommendations
	// export before you create the export job. Compute Optimizer does not create the
	// S3 bucket for you. After you create the S3 bucket, ensure that it has the
	// required permission policy to allow Compute Optimizer to write the export file
	// to it. If you plan to specify an object prefix when you create the export job,
	// you must include the object prefix in the policy that you add to the S3 bucket.
	// For more information, see [Amazon S3 Bucket Policy for Compute Optimizer]in the Compute Optimizer User Guide.
	//
	// [Amazon S3 Bucket Policy for Compute Optimizer]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/create-s3-bucket-policy-for-compute-optimizer.html
	//
	// This member is required.
	S3DestinationConfig *types.S3DestinationConfig

	// The IDs of the Amazon Web Services accounts for which to export license
	// recommendations.
	//
	// If your account is the management account of an organization, use this
	// parameter to specify the member account for which you want to export
	// recommendations.
	//
	// This parameter can't be specified together with the include member accounts
	// parameter. The parameters are mutually exclusive.
	//
	// If this parameter is omitted, recommendations for member accounts aren't
	// included in the export.
	//
	// You can specify multiple account IDs per request.
	AccountIds []string

	// The recommendations data to include in the export file. For more information
	// about the fields that can be exported, see [Exported files]in the Compute Optimizer User Guide.
	//
	// [Exported files]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/exporting-recommendations.html#exported-files
	FieldsToExport []types.ExportableLicenseField

	// The format of the export file.
	//
	// A CSV file is the only export format currently supported.
	FileFormat types.FileFormat

	//  An array of objects to specify a filter that exports a more specific set of
	// license recommendations.
	Filters []types.LicenseRecommendationFilter

	// Indicates whether to include recommendations for resources in all member
	// accounts of the organization if your account is the management account of an
	// organization.
	//
	// The member accounts must also be opted in to Compute Optimizer, and trusted
	// access for Compute Optimizer must be enabled in the organization account. For
	// more information, see [Compute Optimizer and Amazon Web Services Organizations trusted access]in the Compute Optimizer User Guide.
	//
	// If this parameter is omitted, recommendations for member accounts of the
	// organization aren't included in the export file .
	//
	// This parameter cannot be specified together with the account IDs parameter. The
	// parameters are mutually exclusive.
	//
	// [Compute Optimizer and Amazon Web Services Organizations trusted access]: https://docs.aws.amazon.com/compute-optimizer/latest/ug/security-iam.html#trusted-service-access
	IncludeMemberAccounts bool

	noSmithyDocumentSerde
}

func (v *ExportLicenseRecommendationsInput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.ExportLicenseRecommendationsRequest)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *ExportLicenseRecommendationsInput) SerializeMembers(s smithy.ShapeSerializer) {
	serializeAccountIds(s, schemas.ExportLicenseRecommendationsRequest_accountIds, v.AccountIds)
	serializeExportableLicenseFields(s, schemas.ExportLicenseRecommendationsRequest_fieldsToExport, v.FieldsToExport)
	if v.FileFormat != "" {
		s.WriteString(schemas.ExportLicenseRecommendationsRequest_fileFormat, string(v.FileFormat))
	}
	serializeLicenseRecommendationFilters(s, schemas.ExportLicenseRecommendationsRequest_filters, v.Filters)
	if v.IncludeMemberAccounts != false {
		s.WriteBool(schemas.ExportLicenseRecommendationsRequest_includeMemberAccounts, v.IncludeMemberAccounts)
	}
	if v.S3DestinationConfig != nil {
		s.WriteStruct(schemas.ExportLicenseRecommendationsRequest_s3DestinationConfig)
		v.S3DestinationConfig.SerializeMembers(s)
		s.CloseStruct()
	}
}

type ExportLicenseRecommendationsOutput struct {

	//  The identification number of the export job.
	//
	// To view the status of an export job, use the DescribeRecommendationExportJobs action and specify the job ID.
	JobId *string

	// Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name
	// and object keys of a recommendations export file, and its associated metadata
	// file.
	S3Destination *types.S3Destination

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (v *ExportLicenseRecommendationsOutput) Serialize(s smithy.ShapeSerializer) {
	s.WriteStruct(schemas.ExportLicenseRecommendationsResponse)
	v.SerializeMembers(s)
	s.CloseStruct()
}

func (v *ExportLicenseRecommendationsOutput) SerializeMembers(s smithy.ShapeSerializer) {
	if v.JobId != nil {
		s.WriteString(schemas.ExportLicenseRecommendationsResponse_jobId, *v.JobId)
	}
	if v.S3Destination != nil {
		s.WriteStruct(schemas.ExportLicenseRecommendationsResponse_s3Destination)
		v.S3Destination.SerializeMembers(s)
		s.CloseStruct()
	}
}
func (v *ExportLicenseRecommendationsOutput) Deserialize(d smithy.ShapeDeserializer) error {
	return smithy.ReadStruct(d, schemas.ExportLicenseRecommendationsResponse, func(s *smithy.Schema) error {
		switch s {
		case schemas.ExportLicenseRecommendationsResponse_jobId:
			v.JobId = new(string)
			return d.ReadString(schemas.ExportLicenseRecommendationsResponse_jobId, v.JobId)
		case schemas.ExportLicenseRecommendationsResponse_s3Destination:
			v.S3Destination = &types.S3Destination{}
			return v.S3Destination.Deserialize(d)
		}
		return nil
	})
}
func (c *Client) addOperationExportLicenseRecommendationsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&serializeRequestMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.ExportLicenseRecommendations, schemas.ExportLicenseRecommendationsRequest, schemas.ExportLicenseRecommendationsResponse)}, middleware.After); err != nil {
		return err
	}
	if err := stack.Deserialize.Add(&deserializeResponseMiddleware{options: &options, operationSchema: smithy.NewOperationSchema(schemas.ExportLicenseRecommendations, schemas.ExportLicenseRecommendationsRequest, schemas.ExportLicenseRecommendationsResponse), output: &ExportLicenseRecommendationsOutput{}}, middleware.After); err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpExportLicenseRecommendationsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ExportLicenseRecommendations"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
