// Code generated by smithy-go-codegen DO NOT EDIT.

package awsrestjson

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/credentials"
	"github.com/aws/smithy-go/middleware"
	"testing"
)

func TestEventStream_InputStreamWithInitialRequest_InitialRequestInput(t *testing.T) {
	mock := newEventstreamMockHTTPClient()
	defer mock.CloseResponse()

	client := New(Options{
		HTTPClient:         mock,
		Credentials:        credentials.NewStaticCredentialsProvider("AKID", "SECRET", "SESSION"),
		EndpointResolverV2: &protocolTestEndpointResolver{URL: "http://localhost"},
		APIOptions: []func(*middleware.Stack) error{
			func(s *middleware.Stack) error {
				s.Finalize.Remove("Retry")
				s.Initialize.Remove("OperationInputValidation")
				return nil
			},
		},
	})

	_, err := client.InputStreamWithInitialRequest(context.Background(), &InputStreamWithInitialRequestInput{})
	if err != nil {
		t.Fatalf("expect no error, got %v", err)
	}
}
