// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanrooms

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanrooms/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates the processing of a currently running job.
func (c *Client) UpdateProtectedJob(ctx context.Context, params *UpdateProtectedJobInput, optFns ...func(*Options)) (*UpdateProtectedJobOutput, error) {
	if params == nil {
		params = &UpdateProtectedJobInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateProtectedJob", params, optFns, c.addOperationUpdateProtectedJobMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateProtectedJobOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateProtectedJobInput struct {

	// The identifier for a member of a protected job instance.
	//
	// This member is required.
	MembershipIdentifier *string

	//  The identifier of the protected job to update.
	//
	// This member is required.
	ProtectedJobIdentifier *string

	// The target status of a protected job. Used to update the execution status of a
	// currently running job.
	//
	// This member is required.
	TargetStatus types.TargetProtectedJobStatus

	noSmithyDocumentSerde
}

type UpdateProtectedJobOutput struct {

	// The protected job output.
	//
	// This member is required.
	ProtectedJob *types.ProtectedJob

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateProtectedJobMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateProtectedJob{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateProtectedJob{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateProtectedJobValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateProtectedJob"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
