// Code generated by smithy-go-codegen DO NOT EDIT.

// Package cloudfrontkeyvaluestore provides the API client, operations, and
// parameter types for Amazon CloudFront KeyValueStore.
//
// Amazon CloudFront KeyValueStore Service to View and Update Data in a KVS
// Resource
package cloudfrontkeyvaluestore
