// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type CustomActionAttachmentCriteriaOperator string

// Enum values for CustomActionAttachmentCriteriaOperator
const (
	CustomActionAttachmentCriteriaOperatorHasValue CustomActionAttachmentCriteriaOperator = "HAS_VALUE"
	CustomActionAttachmentCriteriaOperatorEquals   CustomActionAttachmentCriteriaOperator = "EQUALS"
)

// Values returns all known values for CustomActionAttachmentCriteriaOperator.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomActionAttachmentCriteriaOperator) Values() []CustomActionAttachmentCriteriaOperator {
	return []CustomActionAttachmentCriteriaOperator{
		"HAS_VALUE",
		"EQUALS",
	}
}
