// Code generated by smithy-go-codegen DO NOT EDIT.

// Package amplifybackend provides the API client, operations, and parameter types
// for AmplifyBackend.
//
// AWS Amplify Admin API
package amplifybackend
