// Code generated by smithy-go-codegen DO NOT EDIT.

package acm

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	"github.com/aws/smithy-go/ptr"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes an ACME endpoint. After deletion, the endpoint URL is no longer
// accessible and ACME clients cannot issue certificates through it. Any existing
// external account bindings and domain validations associated with the endpoint
// are also deleted.
func (c *Client) DeleteAcmeEndpoint(ctx context.Context, params *DeleteAcmeEndpointInput, optFns ...func(*Options)) (*DeleteAcmeEndpointOutput, error) {
	if params == nil {
		params = &DeleteAcmeEndpointInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteAcmeEndpoint", params, optFns, c.addOperationDeleteAcmeEndpointMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteAcmeEndpointOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteAcmeEndpointInput struct {

	// The Amazon Resource Name (ARN) of the ACME endpoint to delete.
	//
	// This member is required.
	AcmeEndpointArn *string

	noSmithyDocumentSerde
}

func (in *DeleteAcmeEndpointInput) bindEndpointParams(p *EndpointParameters) {

	p.ServiceType = ptr.String("ACM-ACME")
}

type DeleteAcmeEndpointOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteAcmeEndpointMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDeleteAcmeEndpoint{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDeleteAcmeEndpoint{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteAcmeEndpointValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteAcmeEndpoint"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
