// Code generated by smithy-go-codegen DO NOT EDIT.

package document

import (
	smithydocument "github.com/aws/smithy-go/document"
)

var _ smithyDocument = (Interface)(nil)
var _ smithydocument.Marshaler = (Interface)(nil)
var _ smithydocument.Unmarshaler = (Interface)(nil)
