// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type AccessBudgetType string

// Enum values for AccessBudgetType
const (
	AccessBudgetTypeCalendarDay   AccessBudgetType = "CALENDAR_DAY"
	AccessBudgetTypeCalendarMonth AccessBudgetType = "CALENDAR_MONTH"
	AccessBudgetTypeCalendarWeek  AccessBudgetType = "CALENDAR_WEEK"
	AccessBudgetTypeLifetime      AccessBudgetType = "LIFETIME"
)

// Values returns all known values for AccessBudgetType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AccessBudgetType) Values() []AccessBudgetType {
	return []AccessBudgetType{
		"CALENDAR_DAY",
		"CALENDAR_MONTH",
		"CALENDAR_WEEK",
		"LIFETIME",
	}
}

type AudienceExportJobStatus string

// Enum values for AudienceExportJobStatus
const (
	AudienceExportJobStatusCreatePending    AudienceExportJobStatus = "CREATE_PENDING"
	AudienceExportJobStatusCreateInProgress AudienceExportJobStatus = "CREATE_IN_PROGRESS"
	AudienceExportJobStatusCreateFailed     AudienceExportJobStatus = "CREATE_FAILED"
	AudienceExportJobStatusActive           AudienceExportJobStatus = "ACTIVE"
)

// Values returns all known values for AudienceExportJobStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AudienceExportJobStatus) Values() []AudienceExportJobStatus {
	return []AudienceExportJobStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
	}
}

type AudienceGenerationJobStatus string

// Enum values for AudienceGenerationJobStatus
const (
	AudienceGenerationJobStatusCreatePending    AudienceGenerationJobStatus = "CREATE_PENDING"
	AudienceGenerationJobStatusCreateInProgress AudienceGenerationJobStatus = "CREATE_IN_PROGRESS"
	AudienceGenerationJobStatusCreateFailed     AudienceGenerationJobStatus = "CREATE_FAILED"
	AudienceGenerationJobStatusActive           AudienceGenerationJobStatus = "ACTIVE"
	AudienceGenerationJobStatusDeletePending    AudienceGenerationJobStatus = "DELETE_PENDING"
	AudienceGenerationJobStatusDeleteInProgress AudienceGenerationJobStatus = "DELETE_IN_PROGRESS"
	AudienceGenerationJobStatusDeleteFailed     AudienceGenerationJobStatus = "DELETE_FAILED"
)

// Values returns all known values for AudienceGenerationJobStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AudienceGenerationJobStatus) Values() []AudienceGenerationJobStatus {
	return []AudienceGenerationJobStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
		"DELETE_PENDING",
		"DELETE_IN_PROGRESS",
		"DELETE_FAILED",
	}
}

type AudienceModelStatus string

// Enum values for AudienceModelStatus
const (
	AudienceModelStatusCreatePending    AudienceModelStatus = "CREATE_PENDING"
	AudienceModelStatusCreateInProgress AudienceModelStatus = "CREATE_IN_PROGRESS"
	AudienceModelStatusCreateFailed     AudienceModelStatus = "CREATE_FAILED"
	AudienceModelStatusActive           AudienceModelStatus = "ACTIVE"
	AudienceModelStatusDeletePending    AudienceModelStatus = "DELETE_PENDING"
	AudienceModelStatusDeleteInProgress AudienceModelStatus = "DELETE_IN_PROGRESS"
	AudienceModelStatusDeleteFailed     AudienceModelStatus = "DELETE_FAILED"
)

// Values returns all known values for AudienceModelStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AudienceModelStatus) Values() []AudienceModelStatus {
	return []AudienceModelStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
		"DELETE_PENDING",
		"DELETE_IN_PROGRESS",
		"DELETE_FAILED",
	}
}

type AudienceSizeType string

// Enum values for AudienceSizeType
const (
	AudienceSizeTypeAbsolute   AudienceSizeType = "ABSOLUTE"
	AudienceSizeTypePercentage AudienceSizeType = "PERCENTAGE"
)

// Values returns all known values for AudienceSizeType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AudienceSizeType) Values() []AudienceSizeType {
	return []AudienceSizeType{
		"ABSOLUTE",
		"PERCENTAGE",
	}
}

type AutoRefreshMode string

// Enum values for AutoRefreshMode
const (
	AutoRefreshModeEnabled  AutoRefreshMode = "ENABLED"
	AutoRefreshModeDisabled AutoRefreshMode = "DISABLED"
)

// Values returns all known values for AutoRefreshMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutoRefreshMode) Values() []AutoRefreshMode {
	return []AutoRefreshMode{
		"ENABLED",
		"DISABLED",
	}
}

type ColumnType string

// Enum values for ColumnType
const (
	ColumnTypeUserId             ColumnType = "USER_ID"
	ColumnTypeItemId             ColumnType = "ITEM_ID"
	ColumnTypeTimestamp          ColumnType = "TIMESTAMP"
	ColumnTypeCategoricalFeature ColumnType = "CATEGORICAL_FEATURE"
	ColumnTypeNumericalFeature   ColumnType = "NUMERICAL_FEATURE"
)

// Values returns all known values for ColumnType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ColumnType) Values() []ColumnType {
	return []ColumnType{
		"USER_ID",
		"ITEM_ID",
		"TIMESTAMP",
		"CATEGORICAL_FEATURE",
		"NUMERICAL_FEATURE",
	}
}

type ConfiguredAudienceModelStatus string

// Enum values for ConfiguredAudienceModelStatus
const (
	ConfiguredAudienceModelStatusActive ConfiguredAudienceModelStatus = "ACTIVE"
)

// Values returns all known values for ConfiguredAudienceModelStatus. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConfiguredAudienceModelStatus) Values() []ConfiguredAudienceModelStatus {
	return []ConfiguredAudienceModelStatus{
		"ACTIVE",
	}
}

type DatasetType string

// Enum values for DatasetType
const (
	DatasetTypeInteractions DatasetType = "INTERACTIONS"
)

// Values returns all known values for DatasetType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DatasetType) Values() []DatasetType {
	return []DatasetType{
		"INTERACTIONS",
	}
}

type EntityType string

// Enum values for EntityType
const (
	EntityTypeAllPersonallyIdentifiableInformation EntityType = "ALL_PERSONALLY_IDENTIFIABLE_INFORMATION"
	EntityTypeNumbers                              EntityType = "NUMBERS"
	EntityTypeCustom                               EntityType = "CUSTOM"
)

// Values returns all known values for EntityType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EntityType) Values() []EntityType {
	return []EntityType{
		"ALL_PERSONALLY_IDENTIFIABLE_INFORMATION",
		"NUMBERS",
		"CUSTOM",
	}
}

type InferenceInstanceType string

// Enum values for InferenceInstanceType
const (
	InferenceInstanceTypeMlR7i48xlarge  InferenceInstanceType = "ml.r7i.48xlarge"
	InferenceInstanceTypeMlR6i16xlarge  InferenceInstanceType = "ml.r6i.16xlarge"
	InferenceInstanceTypeMlM6iXlarge    InferenceInstanceType = "ml.m6i.xlarge"
	InferenceInstanceTypeMlM54xlarge    InferenceInstanceType = "ml.m5.4xlarge"
	InferenceInstanceTypeMlP2Xlarge     InferenceInstanceType = "ml.p2.xlarge"
	InferenceInstanceTypeMlM416xlarge   InferenceInstanceType = "ml.m4.16xlarge"
	InferenceInstanceTypeMlR7i16xlarge  InferenceInstanceType = "ml.r7i.16xlarge"
	InferenceInstanceTypeMlM7iXlarge    InferenceInstanceType = "ml.m7i.xlarge"
	InferenceInstanceTypeMlM6i12xlarge  InferenceInstanceType = "ml.m6i.12xlarge"
	InferenceInstanceTypeMlR7i8xlarge   InferenceInstanceType = "ml.r7i.8xlarge"
	InferenceInstanceTypeMlR7iLarge     InferenceInstanceType = "ml.r7i.large"
	InferenceInstanceTypeMlM7i12xlarge  InferenceInstanceType = "ml.m7i.12xlarge"
	InferenceInstanceTypeMlM6i24xlarge  InferenceInstanceType = "ml.m6i.24xlarge"
	InferenceInstanceTypeMlM7i24xlarge  InferenceInstanceType = "ml.m7i.24xlarge"
	InferenceInstanceTypeMlR6i8xlarge   InferenceInstanceType = "ml.r6i.8xlarge"
	InferenceInstanceTypeMlR6iLarge     InferenceInstanceType = "ml.r6i.large"
	InferenceInstanceTypeMlG52xlarge    InferenceInstanceType = "ml.g5.2xlarge"
	InferenceInstanceTypeMlM5Large      InferenceInstanceType = "ml.m5.large"
	InferenceInstanceTypeMlM7i48xlarge  InferenceInstanceType = "ml.m7i.48xlarge"
	InferenceInstanceTypeMlM6i16xlarge  InferenceInstanceType = "ml.m6i.16xlarge"
	InferenceInstanceTypeMlP216xlarge   InferenceInstanceType = "ml.p2.16xlarge"
	InferenceInstanceTypeMlG54xlarge    InferenceInstanceType = "ml.g5.4xlarge"
	InferenceInstanceTypeMlM7i16xlarge  InferenceInstanceType = "ml.m7i.16xlarge"
	InferenceInstanceTypeMlC42xlarge    InferenceInstanceType = "ml.c4.2xlarge"
	InferenceInstanceTypeMlC52xlarge    InferenceInstanceType = "ml.c5.2xlarge"
	InferenceInstanceTypeMlC6i32xlarge  InferenceInstanceType = "ml.c6i.32xlarge"
	InferenceInstanceTypeMlC44xlarge    InferenceInstanceType = "ml.c4.4xlarge"
	InferenceInstanceTypeMlG58xlarge    InferenceInstanceType = "ml.g5.8xlarge"
	InferenceInstanceTypeMlC6iXlarge    InferenceInstanceType = "ml.c6i.xlarge"
	InferenceInstanceTypeMlC54xlarge    InferenceInstanceType = "ml.c5.4xlarge"
	InferenceInstanceTypeMlG4dnXlarge   InferenceInstanceType = "ml.g4dn.xlarge"
	InferenceInstanceTypeMlC7iXlarge    InferenceInstanceType = "ml.c7i.xlarge"
	InferenceInstanceTypeMlC6i12xlarge  InferenceInstanceType = "ml.c6i.12xlarge"
	InferenceInstanceTypeMlG4dn12xlarge InferenceInstanceType = "ml.g4dn.12xlarge"
	InferenceInstanceTypeMlC7i12xlarge  InferenceInstanceType = "ml.c7i.12xlarge"
	InferenceInstanceTypeMlC6i24xlarge  InferenceInstanceType = "ml.c6i.24xlarge"
	InferenceInstanceTypeMlG4dn2xlarge  InferenceInstanceType = "ml.g4dn.2xlarge"
	InferenceInstanceTypeMlC7i24xlarge  InferenceInstanceType = "ml.c7i.24xlarge"
	InferenceInstanceTypeMlC7i2xlarge   InferenceInstanceType = "ml.c7i.2xlarge"
	InferenceInstanceTypeMlC48xlarge    InferenceInstanceType = "ml.c4.8xlarge"
	InferenceInstanceTypeMlC6i2xlarge   InferenceInstanceType = "ml.c6i.2xlarge"
	InferenceInstanceTypeMlG4dn4xlarge  InferenceInstanceType = "ml.g4dn.4xlarge"
	InferenceInstanceTypeMlC7i48xlarge  InferenceInstanceType = "ml.c7i.48xlarge"
	InferenceInstanceTypeMlC7i4xlarge   InferenceInstanceType = "ml.c7i.4xlarge"
	InferenceInstanceTypeMlC6i16xlarge  InferenceInstanceType = "ml.c6i.16xlarge"
	InferenceInstanceTypeMlC59xlarge    InferenceInstanceType = "ml.c5.9xlarge"
	InferenceInstanceTypeMlG4dn16xlarge InferenceInstanceType = "ml.g4dn.16xlarge"
	InferenceInstanceTypeMlC7i16xlarge  InferenceInstanceType = "ml.c7i.16xlarge"
	InferenceInstanceTypeMlC6i4xlarge   InferenceInstanceType = "ml.c6i.4xlarge"
	InferenceInstanceTypeMlC5Xlarge     InferenceInstanceType = "ml.c5.xlarge"
	InferenceInstanceTypeMlC4Xlarge     InferenceInstanceType = "ml.c4.xlarge"
	InferenceInstanceTypeMlG4dn8xlarge  InferenceInstanceType = "ml.g4dn.8xlarge"
	InferenceInstanceTypeMlC7i8xlarge   InferenceInstanceType = "ml.c7i.8xlarge"
	InferenceInstanceTypeMlC7iLarge     InferenceInstanceType = "ml.c7i.large"
	InferenceInstanceTypeMlG5Xlarge     InferenceInstanceType = "ml.g5.xlarge"
	InferenceInstanceTypeMlC6i8xlarge   InferenceInstanceType = "ml.c6i.8xlarge"
	InferenceInstanceTypeMlC6iLarge     InferenceInstanceType = "ml.c6i.large"
	InferenceInstanceTypeMlG512xlarge   InferenceInstanceType = "ml.g5.12xlarge"
	InferenceInstanceTypeMlG524xlarge   InferenceInstanceType = "ml.g5.24xlarge"
	InferenceInstanceTypeMlM7i2xlarge   InferenceInstanceType = "ml.m7i.2xlarge"
	InferenceInstanceTypeMlC518xlarge   InferenceInstanceType = "ml.c5.18xlarge"
	InferenceInstanceTypeMlG548xlarge   InferenceInstanceType = "ml.g5.48xlarge"
	InferenceInstanceTypeMlM6i2xlarge   InferenceInstanceType = "ml.m6i.2xlarge"
	InferenceInstanceTypeMlG516xlarge   InferenceInstanceType = "ml.g5.16xlarge"
	InferenceInstanceTypeMlM7i4xlarge   InferenceInstanceType = "ml.m7i.4xlarge"
	InferenceInstanceTypeMlR6i32xlarge  InferenceInstanceType = "ml.r6i.32xlarge"
	InferenceInstanceTypeMlM6i4xlarge   InferenceInstanceType = "ml.m6i.4xlarge"
	InferenceInstanceTypeMlM5Xlarge     InferenceInstanceType = "ml.m5.xlarge"
	InferenceInstanceTypeMlM410xlarge   InferenceInstanceType = "ml.m4.10xlarge"
	InferenceInstanceTypeMlR6iXlarge    InferenceInstanceType = "ml.r6i.xlarge"
	InferenceInstanceTypeMlM512xlarge   InferenceInstanceType = "ml.m5.12xlarge"
	InferenceInstanceTypeMlM4Xlarge     InferenceInstanceType = "ml.m4.xlarge"
	InferenceInstanceTypeMlR7i2xlarge   InferenceInstanceType = "ml.r7i.2xlarge"
	InferenceInstanceTypeMlR7iXlarge    InferenceInstanceType = "ml.r7i.xlarge"
	InferenceInstanceTypeMlR6i12xlarge  InferenceInstanceType = "ml.r6i.12xlarge"
	InferenceInstanceTypeMlM524xlarge   InferenceInstanceType = "ml.m5.24xlarge"
	InferenceInstanceTypeMlR7i12xlarge  InferenceInstanceType = "ml.r7i.12xlarge"
	InferenceInstanceTypeMlM7i8xlarge   InferenceInstanceType = "ml.m7i.8xlarge"
	InferenceInstanceTypeMlM7iLarge     InferenceInstanceType = "ml.m7i.large"
	InferenceInstanceTypeMlR6i24xlarge  InferenceInstanceType = "ml.r6i.24xlarge"
	InferenceInstanceTypeMlR6i2xlarge   InferenceInstanceType = "ml.r6i.2xlarge"
	InferenceInstanceTypeMlM42xlarge    InferenceInstanceType = "ml.m4.2xlarge"
	InferenceInstanceTypeMlR7i24xlarge  InferenceInstanceType = "ml.r7i.24xlarge"
	InferenceInstanceTypeMlR7i4xlarge   InferenceInstanceType = "ml.r7i.4xlarge"
	InferenceInstanceTypeMlM6i8xlarge   InferenceInstanceType = "ml.m6i.8xlarge"
	InferenceInstanceTypeMlM6iLarge     InferenceInstanceType = "ml.m6i.large"
	InferenceInstanceTypeMlM52xlarge    InferenceInstanceType = "ml.m5.2xlarge"
	InferenceInstanceTypeMlP28xlarge    InferenceInstanceType = "ml.p2.8xlarge"
	InferenceInstanceTypeMlR6i4xlarge   InferenceInstanceType = "ml.r6i.4xlarge"
	InferenceInstanceTypeMlM6i32xlarge  InferenceInstanceType = "ml.m6i.32xlarge"
	InferenceInstanceTypeMlM44xlarge    InferenceInstanceType = "ml.m4.4xlarge"
	InferenceInstanceTypeMlP316xlarge   InferenceInstanceType = "ml.p3.16xlarge"
	InferenceInstanceTypeMlP32xlarge    InferenceInstanceType = "ml.p3.2xlarge"
	InferenceInstanceTypeMlP38xlarge    InferenceInstanceType = "ml.p3.8xlarge"
)

// Values returns all known values for InferenceInstanceType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InferenceInstanceType) Values() []InferenceInstanceType {
	return []InferenceInstanceType{
		"ml.r7i.48xlarge",
		"ml.r6i.16xlarge",
		"ml.m6i.xlarge",
		"ml.m5.4xlarge",
		"ml.p2.xlarge",
		"ml.m4.16xlarge",
		"ml.r7i.16xlarge",
		"ml.m7i.xlarge",
		"ml.m6i.12xlarge",
		"ml.r7i.8xlarge",
		"ml.r7i.large",
		"ml.m7i.12xlarge",
		"ml.m6i.24xlarge",
		"ml.m7i.24xlarge",
		"ml.r6i.8xlarge",
		"ml.r6i.large",
		"ml.g5.2xlarge",
		"ml.m5.large",
		"ml.m7i.48xlarge",
		"ml.m6i.16xlarge",
		"ml.p2.16xlarge",
		"ml.g5.4xlarge",
		"ml.m7i.16xlarge",
		"ml.c4.2xlarge",
		"ml.c5.2xlarge",
		"ml.c6i.32xlarge",
		"ml.c4.4xlarge",
		"ml.g5.8xlarge",
		"ml.c6i.xlarge",
		"ml.c5.4xlarge",
		"ml.g4dn.xlarge",
		"ml.c7i.xlarge",
		"ml.c6i.12xlarge",
		"ml.g4dn.12xlarge",
		"ml.c7i.12xlarge",
		"ml.c6i.24xlarge",
		"ml.g4dn.2xlarge",
		"ml.c7i.24xlarge",
		"ml.c7i.2xlarge",
		"ml.c4.8xlarge",
		"ml.c6i.2xlarge",
		"ml.g4dn.4xlarge",
		"ml.c7i.48xlarge",
		"ml.c7i.4xlarge",
		"ml.c6i.16xlarge",
		"ml.c5.9xlarge",
		"ml.g4dn.16xlarge",
		"ml.c7i.16xlarge",
		"ml.c6i.4xlarge",
		"ml.c5.xlarge",
		"ml.c4.xlarge",
		"ml.g4dn.8xlarge",
		"ml.c7i.8xlarge",
		"ml.c7i.large",
		"ml.g5.xlarge",
		"ml.c6i.8xlarge",
		"ml.c6i.large",
		"ml.g5.12xlarge",
		"ml.g5.24xlarge",
		"ml.m7i.2xlarge",
		"ml.c5.18xlarge",
		"ml.g5.48xlarge",
		"ml.m6i.2xlarge",
		"ml.g5.16xlarge",
		"ml.m7i.4xlarge",
		"ml.r6i.32xlarge",
		"ml.m6i.4xlarge",
		"ml.m5.xlarge",
		"ml.m4.10xlarge",
		"ml.r6i.xlarge",
		"ml.m5.12xlarge",
		"ml.m4.xlarge",
		"ml.r7i.2xlarge",
		"ml.r7i.xlarge",
		"ml.r6i.12xlarge",
		"ml.m5.24xlarge",
		"ml.r7i.12xlarge",
		"ml.m7i.8xlarge",
		"ml.m7i.large",
		"ml.r6i.24xlarge",
		"ml.r6i.2xlarge",
		"ml.m4.2xlarge",
		"ml.r7i.24xlarge",
		"ml.r7i.4xlarge",
		"ml.m6i.8xlarge",
		"ml.m6i.large",
		"ml.m5.2xlarge",
		"ml.p2.8xlarge",
		"ml.r6i.4xlarge",
		"ml.m6i.32xlarge",
		"ml.m4.4xlarge",
		"ml.p3.16xlarge",
		"ml.p3.2xlarge",
		"ml.p3.8xlarge",
	}
}

type InstanceType string

// Enum values for InstanceType
const (
	InstanceTypeMlM4Xlarge      InstanceType = "ml.m4.xlarge"
	InstanceTypeMlM42xlarge     InstanceType = "ml.m4.2xlarge"
	InstanceTypeMlM44xlarge     InstanceType = "ml.m4.4xlarge"
	InstanceTypeMlM410xlarge    InstanceType = "ml.m4.10xlarge"
	InstanceTypeMlM416xlarge    InstanceType = "ml.m4.16xlarge"
	InstanceTypeMlG4dnXlarge    InstanceType = "ml.g4dn.xlarge"
	InstanceTypeMlG4dn2xlarge   InstanceType = "ml.g4dn.2xlarge"
	InstanceTypeMlG4dn4xlarge   InstanceType = "ml.g4dn.4xlarge"
	InstanceTypeMlG4dn8xlarge   InstanceType = "ml.g4dn.8xlarge"
	InstanceTypeMlG4dn12xlarge  InstanceType = "ml.g4dn.12xlarge"
	InstanceTypeMlG4dn16xlarge  InstanceType = "ml.g4dn.16xlarge"
	InstanceTypeMlM5Large       InstanceType = "ml.m5.large"
	InstanceTypeMlM5Xlarge      InstanceType = "ml.m5.xlarge"
	InstanceTypeMlM52xlarge     InstanceType = "ml.m5.2xlarge"
	InstanceTypeMlM54xlarge     InstanceType = "ml.m5.4xlarge"
	InstanceTypeMlM512xlarge    InstanceType = "ml.m5.12xlarge"
	InstanceTypeMlM524xlarge    InstanceType = "ml.m5.24xlarge"
	InstanceTypeMlC4Xlarge      InstanceType = "ml.c4.xlarge"
	InstanceTypeMlC42xlarge     InstanceType = "ml.c4.2xlarge"
	InstanceTypeMlC44xlarge     InstanceType = "ml.c4.4xlarge"
	InstanceTypeMlC48xlarge     InstanceType = "ml.c4.8xlarge"
	InstanceTypeMlP2Xlarge      InstanceType = "ml.p2.xlarge"
	InstanceTypeMlP28xlarge     InstanceType = "ml.p2.8xlarge"
	InstanceTypeMlP216xlarge    InstanceType = "ml.p2.16xlarge"
	InstanceTypeMlP4d24xlarge   InstanceType = "ml.p4d.24xlarge"
	InstanceTypeMlP4de24xlarge  InstanceType = "ml.p4de.24xlarge"
	InstanceTypeMlP548xlarge    InstanceType = "ml.p5.48xlarge"
	InstanceTypeMlC5Xlarge      InstanceType = "ml.c5.xlarge"
	InstanceTypeMlC52xlarge     InstanceType = "ml.c5.2xlarge"
	InstanceTypeMlC54xlarge     InstanceType = "ml.c5.4xlarge"
	InstanceTypeMlC59xlarge     InstanceType = "ml.c5.9xlarge"
	InstanceTypeMlC518xlarge    InstanceType = "ml.c5.18xlarge"
	InstanceTypeMlC5nXlarge     InstanceType = "ml.c5n.xlarge"
	InstanceTypeMlC5n2xlarge    InstanceType = "ml.c5n.2xlarge"
	InstanceTypeMlC5n4xlarge    InstanceType = "ml.c5n.4xlarge"
	InstanceTypeMlC5n9xlarge    InstanceType = "ml.c5n.9xlarge"
	InstanceTypeMlC5n18xlarge   InstanceType = "ml.c5n.18xlarge"
	InstanceTypeMlG5Xlarge      InstanceType = "ml.g5.xlarge"
	InstanceTypeMlG52xlarge     InstanceType = "ml.g5.2xlarge"
	InstanceTypeMlG54xlarge     InstanceType = "ml.g5.4xlarge"
	InstanceTypeMlG58xlarge     InstanceType = "ml.g5.8xlarge"
	InstanceTypeMlG516xlarge    InstanceType = "ml.g5.16xlarge"
	InstanceTypeMlG512xlarge    InstanceType = "ml.g5.12xlarge"
	InstanceTypeMlG524xlarge    InstanceType = "ml.g5.24xlarge"
	InstanceTypeMlG548xlarge    InstanceType = "ml.g5.48xlarge"
	InstanceTypeMlTrn12xlarge   InstanceType = "ml.trn1.2xlarge"
	InstanceTypeMlTrn132xlarge  InstanceType = "ml.trn1.32xlarge"
	InstanceTypeMlTrn1n32xlarge InstanceType = "ml.trn1n.32xlarge"
	InstanceTypeMlM6iLarge      InstanceType = "ml.m6i.large"
	InstanceTypeMlM6iXlarge     InstanceType = "ml.m6i.xlarge"
	InstanceTypeMlM6i2xlarge    InstanceType = "ml.m6i.2xlarge"
	InstanceTypeMlM6i4xlarge    InstanceType = "ml.m6i.4xlarge"
	InstanceTypeMlM6i8xlarge    InstanceType = "ml.m6i.8xlarge"
	InstanceTypeMlM6i12xlarge   InstanceType = "ml.m6i.12xlarge"
	InstanceTypeMlM6i16xlarge   InstanceType = "ml.m6i.16xlarge"
	InstanceTypeMlM6i24xlarge   InstanceType = "ml.m6i.24xlarge"
	InstanceTypeMlM6i32xlarge   InstanceType = "ml.m6i.32xlarge"
	InstanceTypeMlC6iXlarge     InstanceType = "ml.c6i.xlarge"
	InstanceTypeMlC6i2xlarge    InstanceType = "ml.c6i.2xlarge"
	InstanceTypeMlC6i8xlarge    InstanceType = "ml.c6i.8xlarge"
	InstanceTypeMlC6i4xlarge    InstanceType = "ml.c6i.4xlarge"
	InstanceTypeMlC6i12xlarge   InstanceType = "ml.c6i.12xlarge"
	InstanceTypeMlC6i16xlarge   InstanceType = "ml.c6i.16xlarge"
	InstanceTypeMlC6i24xlarge   InstanceType = "ml.c6i.24xlarge"
	InstanceTypeMlC6i32xlarge   InstanceType = "ml.c6i.32xlarge"
	InstanceTypeMlR5dLarge      InstanceType = "ml.r5d.large"
	InstanceTypeMlR5dXlarge     InstanceType = "ml.r5d.xlarge"
	InstanceTypeMlR5d2xlarge    InstanceType = "ml.r5d.2xlarge"
	InstanceTypeMlR5d4xlarge    InstanceType = "ml.r5d.4xlarge"
	InstanceTypeMlR5d8xlarge    InstanceType = "ml.r5d.8xlarge"
	InstanceTypeMlR5d12xlarge   InstanceType = "ml.r5d.12xlarge"
	InstanceTypeMlR5d16xlarge   InstanceType = "ml.r5d.16xlarge"
	InstanceTypeMlR5d24xlarge   InstanceType = "ml.r5d.24xlarge"
	InstanceTypeMlT3Medium      InstanceType = "ml.t3.medium"
	InstanceTypeMlT3Large       InstanceType = "ml.t3.large"
	InstanceTypeMlT3Xlarge      InstanceType = "ml.t3.xlarge"
	InstanceTypeMlT32xlarge     InstanceType = "ml.t3.2xlarge"
	InstanceTypeMlR5Large       InstanceType = "ml.r5.large"
	InstanceTypeMlR5Xlarge      InstanceType = "ml.r5.xlarge"
	InstanceTypeMlR52xlarge     InstanceType = "ml.r5.2xlarge"
	InstanceTypeMlR54xlarge     InstanceType = "ml.r5.4xlarge"
	InstanceTypeMlR58xlarge     InstanceType = "ml.r5.8xlarge"
	InstanceTypeMlR512xlarge    InstanceType = "ml.r5.12xlarge"
	InstanceTypeMlR516xlarge    InstanceType = "ml.r5.16xlarge"
	InstanceTypeMlR524xlarge    InstanceType = "ml.r5.24xlarge"
	InstanceTypeMlC7iLarge      InstanceType = "ml.c7i.large"
	InstanceTypeMlC7iXlarge     InstanceType = "ml.c7i.xlarge"
	InstanceTypeMlC7i2xlarge    InstanceType = "ml.c7i.2xlarge"
	InstanceTypeMlC7i4xlarge    InstanceType = "ml.c7i.4xlarge"
	InstanceTypeMlC7i8xlarge    InstanceType = "ml.c7i.8xlarge"
	InstanceTypeMlC7i12xlarge   InstanceType = "ml.c7i.12xlarge"
	InstanceTypeMlC7i16xlarge   InstanceType = "ml.c7i.16xlarge"
	InstanceTypeMlC7i24xlarge   InstanceType = "ml.c7i.24xlarge"
	InstanceTypeMlC7i48xlarge   InstanceType = "ml.c7i.48xlarge"
	InstanceTypeMlM7iLarge      InstanceType = "ml.m7i.large"
	InstanceTypeMlM7iXlarge     InstanceType = "ml.m7i.xlarge"
	InstanceTypeMlM7i2xlarge    InstanceType = "ml.m7i.2xlarge"
	InstanceTypeMlM7i4xlarge    InstanceType = "ml.m7i.4xlarge"
	InstanceTypeMlM7i8xlarge    InstanceType = "ml.m7i.8xlarge"
	InstanceTypeMlM7i12xlarge   InstanceType = "ml.m7i.12xlarge"
	InstanceTypeMlM7i16xlarge   InstanceType = "ml.m7i.16xlarge"
	InstanceTypeMlM7i24xlarge   InstanceType = "ml.m7i.24xlarge"
	InstanceTypeMlM7i48xlarge   InstanceType = "ml.m7i.48xlarge"
	InstanceTypeMlR7iLarge      InstanceType = "ml.r7i.large"
	InstanceTypeMlR7iXlarge     InstanceType = "ml.r7i.xlarge"
	InstanceTypeMlR7i2xlarge    InstanceType = "ml.r7i.2xlarge"
	InstanceTypeMlR7i4xlarge    InstanceType = "ml.r7i.4xlarge"
	InstanceTypeMlR7i8xlarge    InstanceType = "ml.r7i.8xlarge"
	InstanceTypeMlR7i12xlarge   InstanceType = "ml.r7i.12xlarge"
	InstanceTypeMlR7i16xlarge   InstanceType = "ml.r7i.16xlarge"
	InstanceTypeMlR7i24xlarge   InstanceType = "ml.r7i.24xlarge"
	InstanceTypeMlR7i48xlarge   InstanceType = "ml.r7i.48xlarge"
	InstanceTypeMlG6Xlarge      InstanceType = "ml.g6.xlarge"
	InstanceTypeMlG62xlarge     InstanceType = "ml.g6.2xlarge"
	InstanceTypeMlG64xlarge     InstanceType = "ml.g6.4xlarge"
	InstanceTypeMlG68xlarge     InstanceType = "ml.g6.8xlarge"
	InstanceTypeMlG612xlarge    InstanceType = "ml.g6.12xlarge"
	InstanceTypeMlG616xlarge    InstanceType = "ml.g6.16xlarge"
	InstanceTypeMlG624xlarge    InstanceType = "ml.g6.24xlarge"
	InstanceTypeMlG648xlarge    InstanceType = "ml.g6.48xlarge"
	InstanceTypeMlG6eXlarge     InstanceType = "ml.g6e.xlarge"
	InstanceTypeMlG6e2xlarge    InstanceType = "ml.g6e.2xlarge"
	InstanceTypeMlG6e4xlarge    InstanceType = "ml.g6e.4xlarge"
	InstanceTypeMlG6e8xlarge    InstanceType = "ml.g6e.8xlarge"
	InstanceTypeMlG6e12xlarge   InstanceType = "ml.g6e.12xlarge"
	InstanceTypeMlG6e16xlarge   InstanceType = "ml.g6e.16xlarge"
	InstanceTypeMlG6e24xlarge   InstanceType = "ml.g6e.24xlarge"
	InstanceTypeMlG6e48xlarge   InstanceType = "ml.g6e.48xlarge"
	InstanceTypeMlP5en48xlarge  InstanceType = "ml.p5en.48xlarge"
	InstanceTypeMlP32xlarge     InstanceType = "ml.p3.2xlarge"
	InstanceTypeMlP38xlarge     InstanceType = "ml.p3.8xlarge"
	InstanceTypeMlP316xlarge    InstanceType = "ml.p3.16xlarge"
	InstanceTypeMlP3dn24xlarge  InstanceType = "ml.p3dn.24xlarge"
)

// Values returns all known values for InstanceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstanceType) Values() []InstanceType {
	return []InstanceType{
		"ml.m4.xlarge",
		"ml.m4.2xlarge",
		"ml.m4.4xlarge",
		"ml.m4.10xlarge",
		"ml.m4.16xlarge",
		"ml.g4dn.xlarge",
		"ml.g4dn.2xlarge",
		"ml.g4dn.4xlarge",
		"ml.g4dn.8xlarge",
		"ml.g4dn.12xlarge",
		"ml.g4dn.16xlarge",
		"ml.m5.large",
		"ml.m5.xlarge",
		"ml.m5.2xlarge",
		"ml.m5.4xlarge",
		"ml.m5.12xlarge",
		"ml.m5.24xlarge",
		"ml.c4.xlarge",
		"ml.c4.2xlarge",
		"ml.c4.4xlarge",
		"ml.c4.8xlarge",
		"ml.p2.xlarge",
		"ml.p2.8xlarge",
		"ml.p2.16xlarge",
		"ml.p4d.24xlarge",
		"ml.p4de.24xlarge",
		"ml.p5.48xlarge",
		"ml.c5.xlarge",
		"ml.c5.2xlarge",
		"ml.c5.4xlarge",
		"ml.c5.9xlarge",
		"ml.c5.18xlarge",
		"ml.c5n.xlarge",
		"ml.c5n.2xlarge",
		"ml.c5n.4xlarge",
		"ml.c5n.9xlarge",
		"ml.c5n.18xlarge",
		"ml.g5.xlarge",
		"ml.g5.2xlarge",
		"ml.g5.4xlarge",
		"ml.g5.8xlarge",
		"ml.g5.16xlarge",
		"ml.g5.12xlarge",
		"ml.g5.24xlarge",
		"ml.g5.48xlarge",
		"ml.trn1.2xlarge",
		"ml.trn1.32xlarge",
		"ml.trn1n.32xlarge",
		"ml.m6i.large",
		"ml.m6i.xlarge",
		"ml.m6i.2xlarge",
		"ml.m6i.4xlarge",
		"ml.m6i.8xlarge",
		"ml.m6i.12xlarge",
		"ml.m6i.16xlarge",
		"ml.m6i.24xlarge",
		"ml.m6i.32xlarge",
		"ml.c6i.xlarge",
		"ml.c6i.2xlarge",
		"ml.c6i.8xlarge",
		"ml.c6i.4xlarge",
		"ml.c6i.12xlarge",
		"ml.c6i.16xlarge",
		"ml.c6i.24xlarge",
		"ml.c6i.32xlarge",
		"ml.r5d.large",
		"ml.r5d.xlarge",
		"ml.r5d.2xlarge",
		"ml.r5d.4xlarge",
		"ml.r5d.8xlarge",
		"ml.r5d.12xlarge",
		"ml.r5d.16xlarge",
		"ml.r5d.24xlarge",
		"ml.t3.medium",
		"ml.t3.large",
		"ml.t3.xlarge",
		"ml.t3.2xlarge",
		"ml.r5.large",
		"ml.r5.xlarge",
		"ml.r5.2xlarge",
		"ml.r5.4xlarge",
		"ml.r5.8xlarge",
		"ml.r5.12xlarge",
		"ml.r5.16xlarge",
		"ml.r5.24xlarge",
		"ml.c7i.large",
		"ml.c7i.xlarge",
		"ml.c7i.2xlarge",
		"ml.c7i.4xlarge",
		"ml.c7i.8xlarge",
		"ml.c7i.12xlarge",
		"ml.c7i.16xlarge",
		"ml.c7i.24xlarge",
		"ml.c7i.48xlarge",
		"ml.m7i.large",
		"ml.m7i.xlarge",
		"ml.m7i.2xlarge",
		"ml.m7i.4xlarge",
		"ml.m7i.8xlarge",
		"ml.m7i.12xlarge",
		"ml.m7i.16xlarge",
		"ml.m7i.24xlarge",
		"ml.m7i.48xlarge",
		"ml.r7i.large",
		"ml.r7i.xlarge",
		"ml.r7i.2xlarge",
		"ml.r7i.4xlarge",
		"ml.r7i.8xlarge",
		"ml.r7i.12xlarge",
		"ml.r7i.16xlarge",
		"ml.r7i.24xlarge",
		"ml.r7i.48xlarge",
		"ml.g6.xlarge",
		"ml.g6.2xlarge",
		"ml.g6.4xlarge",
		"ml.g6.8xlarge",
		"ml.g6.12xlarge",
		"ml.g6.16xlarge",
		"ml.g6.24xlarge",
		"ml.g6.48xlarge",
		"ml.g6e.xlarge",
		"ml.g6e.2xlarge",
		"ml.g6e.4xlarge",
		"ml.g6e.8xlarge",
		"ml.g6e.12xlarge",
		"ml.g6e.16xlarge",
		"ml.g6e.24xlarge",
		"ml.g6e.48xlarge",
		"ml.p5en.48xlarge",
		"ml.p3.2xlarge",
		"ml.p3.8xlarge",
		"ml.p3.16xlarge",
		"ml.p3dn.24xlarge",
	}
}

type LogsStatus string

// Enum values for LogsStatus
const (
	LogsStatusPublishSucceeded LogsStatus = "PUBLISH_SUCCEEDED"
	LogsStatusPublishFailed    LogsStatus = "PUBLISH_FAILED"
)

// Values returns all known values for LogsStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LogsStatus) Values() []LogsStatus {
	return []LogsStatus{
		"PUBLISH_SUCCEEDED",
		"PUBLISH_FAILED",
	}
}

type LogType string

// Enum values for LogType
const (
	LogTypeAll          LogType = "ALL"
	LogTypeErrorSummary LogType = "ERROR_SUMMARY"
)

// Values returns all known values for LogType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LogType) Values() []LogType {
	return []LogType{
		"ALL",
		"ERROR_SUMMARY",
	}
}

type MembershipInferenceAttackVersion string

// Enum values for MembershipInferenceAttackVersion
const (
	MembershipInferenceAttackVersionDistanceToClosestRecordV1 MembershipInferenceAttackVersion = "DISTANCE_TO_CLOSEST_RECORD_V1"
)

// Values returns all known values for MembershipInferenceAttackVersion. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MembershipInferenceAttackVersion) Values() []MembershipInferenceAttackVersion {
	return []MembershipInferenceAttackVersion{
		"DISTANCE_TO_CLOSEST_RECORD_V1",
	}
}

type MetricsStatus string

// Enum values for MetricsStatus
const (
	MetricsStatusPublishSucceeded MetricsStatus = "PUBLISH_SUCCEEDED"
	MetricsStatusPublishFailed    MetricsStatus = "PUBLISH_FAILED"
)

// Values returns all known values for MetricsStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MetricsStatus) Values() []MetricsStatus {
	return []MetricsStatus{
		"PUBLISH_SUCCEEDED",
		"PUBLISH_FAILED",
	}
}

type MLInputChannelStatus string

// Enum values for MLInputChannelStatus
const (
	MLInputChannelStatusCreatePending    MLInputChannelStatus = "CREATE_PENDING"
	MLInputChannelStatusCreateInProgress MLInputChannelStatus = "CREATE_IN_PROGRESS"
	MLInputChannelStatusCreateFailed     MLInputChannelStatus = "CREATE_FAILED"
	MLInputChannelStatusActive           MLInputChannelStatus = "ACTIVE"
	MLInputChannelStatusDeletePending    MLInputChannelStatus = "DELETE_PENDING"
	MLInputChannelStatusDeleteInProgress MLInputChannelStatus = "DELETE_IN_PROGRESS"
	MLInputChannelStatusDeleteFailed     MLInputChannelStatus = "DELETE_FAILED"
	MLInputChannelStatusInactive         MLInputChannelStatus = "INACTIVE"
)

// Values returns all known values for MLInputChannelStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MLInputChannelStatus) Values() []MLInputChannelStatus {
	return []MLInputChannelStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
		"DELETE_PENDING",
		"DELETE_IN_PROGRESS",
		"DELETE_FAILED",
		"INACTIVE",
	}
}

type NoiseLevelType string

// Enum values for NoiseLevelType
const (
	NoiseLevelTypeHigh   NoiseLevelType = "HIGH"
	NoiseLevelTypeMedium NoiseLevelType = "MEDIUM"
	NoiseLevelTypeLow    NoiseLevelType = "LOW"
	NoiseLevelTypeNone   NoiseLevelType = "NONE"
)

// Values returns all known values for NoiseLevelType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (NoiseLevelType) Values() []NoiseLevelType {
	return []NoiseLevelType{
		"HIGH",
		"MEDIUM",
		"LOW",
		"NONE",
	}
}

type PolicyExistenceCondition string

// Enum values for PolicyExistenceCondition
const (
	PolicyExistenceConditionPolicyMustExist    PolicyExistenceCondition = "POLICY_MUST_EXIST"
	PolicyExistenceConditionPolicyMustNotExist PolicyExistenceCondition = "POLICY_MUST_NOT_EXIST"
)

// Values returns all known values for PolicyExistenceCondition. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PolicyExistenceCondition) Values() []PolicyExistenceCondition {
	return []PolicyExistenceCondition{
		"POLICY_MUST_EXIST",
		"POLICY_MUST_NOT_EXIST",
	}
}

type ResultFormat string

// Enum values for ResultFormat
const (
	ResultFormatCsv     ResultFormat = "CSV"
	ResultFormatParquet ResultFormat = "PARQUET"
)

// Values returns all known values for ResultFormat. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ResultFormat) Values() []ResultFormat {
	return []ResultFormat{
		"CSV",
		"PARQUET",
	}
}

type S3DataDistributionType string

// Enum values for S3DataDistributionType
const (
	S3DataDistributionTypeFullyReplicated S3DataDistributionType = "FullyReplicated"
	S3DataDistributionTypeShardedByS3Key  S3DataDistributionType = "ShardedByS3Key"
)

// Values returns all known values for S3DataDistributionType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (S3DataDistributionType) Values() []S3DataDistributionType {
	return []S3DataDistributionType{
		"FullyReplicated",
		"ShardedByS3Key",
	}
}

type SharedAudienceMetrics string

// Enum values for SharedAudienceMetrics
const (
	SharedAudienceMetricsAll  SharedAudienceMetrics = "ALL"
	SharedAudienceMetricsNone SharedAudienceMetrics = "NONE"
)

// Values returns all known values for SharedAudienceMetrics. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SharedAudienceMetrics) Values() []SharedAudienceMetrics {
	return []SharedAudienceMetrics{
		"ALL",
		"NONE",
	}
}

type SyntheticDataColumnType string

// Enum values for SyntheticDataColumnType
const (
	SyntheticDataColumnTypeCategorical SyntheticDataColumnType = "CATEGORICAL"
	SyntheticDataColumnTypeNumerical   SyntheticDataColumnType = "NUMERICAL"
)

// Values returns all known values for SyntheticDataColumnType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SyntheticDataColumnType) Values() []SyntheticDataColumnType {
	return []SyntheticDataColumnType{
		"CATEGORICAL",
		"NUMERICAL",
	}
}

type TagOnCreatePolicy string

// Enum values for TagOnCreatePolicy
const (
	TagOnCreatePolicyFromParentResource TagOnCreatePolicy = "FROM_PARENT_RESOURCE"
	TagOnCreatePolicyNone               TagOnCreatePolicy = "NONE"
)

// Values returns all known values for TagOnCreatePolicy. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TagOnCreatePolicy) Values() []TagOnCreatePolicy {
	return []TagOnCreatePolicy{
		"FROM_PARENT_RESOURCE",
		"NONE",
	}
}

type TrainedModelArtifactMaxSizeUnitType string

// Enum values for TrainedModelArtifactMaxSizeUnitType
const (
	TrainedModelArtifactMaxSizeUnitTypeGb TrainedModelArtifactMaxSizeUnitType = "GB"
)

// Values returns all known values for TrainedModelArtifactMaxSizeUnitType. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelArtifactMaxSizeUnitType) Values() []TrainedModelArtifactMaxSizeUnitType {
	return []TrainedModelArtifactMaxSizeUnitType{
		"GB",
	}
}

type TrainedModelExportFileType string

// Enum values for TrainedModelExportFileType
const (
	TrainedModelExportFileTypeModel  TrainedModelExportFileType = "MODEL"
	TrainedModelExportFileTypeOutput TrainedModelExportFileType = "OUTPUT"
)

// Values returns all known values for TrainedModelExportFileType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelExportFileType) Values() []TrainedModelExportFileType {
	return []TrainedModelExportFileType{
		"MODEL",
		"OUTPUT",
	}
}

type TrainedModelExportJobStatus string

// Enum values for TrainedModelExportJobStatus
const (
	TrainedModelExportJobStatusCreatePending    TrainedModelExportJobStatus = "CREATE_PENDING"
	TrainedModelExportJobStatusCreateInProgress TrainedModelExportJobStatus = "CREATE_IN_PROGRESS"
	TrainedModelExportJobStatusCreateFailed     TrainedModelExportJobStatus = "CREATE_FAILED"
	TrainedModelExportJobStatusActive           TrainedModelExportJobStatus = "ACTIVE"
)

// Values returns all known values for TrainedModelExportJobStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelExportJobStatus) Values() []TrainedModelExportJobStatus {
	return []TrainedModelExportJobStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
	}
}

type TrainedModelExportsMaxSizeUnitType string

// Enum values for TrainedModelExportsMaxSizeUnitType
const (
	TrainedModelExportsMaxSizeUnitTypeGb TrainedModelExportsMaxSizeUnitType = "GB"
)

// Values returns all known values for TrainedModelExportsMaxSizeUnitType. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelExportsMaxSizeUnitType) Values() []TrainedModelExportsMaxSizeUnitType {
	return []TrainedModelExportsMaxSizeUnitType{
		"GB",
	}
}

type TrainedModelInferenceJobStatus string

// Enum values for TrainedModelInferenceJobStatus
const (
	TrainedModelInferenceJobStatusCreatePending    TrainedModelInferenceJobStatus = "CREATE_PENDING"
	TrainedModelInferenceJobStatusCreateInProgress TrainedModelInferenceJobStatus = "CREATE_IN_PROGRESS"
	TrainedModelInferenceJobStatusCreateFailed     TrainedModelInferenceJobStatus = "CREATE_FAILED"
	TrainedModelInferenceJobStatusActive           TrainedModelInferenceJobStatus = "ACTIVE"
	TrainedModelInferenceJobStatusCancelPending    TrainedModelInferenceJobStatus = "CANCEL_PENDING"
	TrainedModelInferenceJobStatusCancelInProgress TrainedModelInferenceJobStatus = "CANCEL_IN_PROGRESS"
	TrainedModelInferenceJobStatusCancelFailed     TrainedModelInferenceJobStatus = "CANCEL_FAILED"
	TrainedModelInferenceJobStatusInactive         TrainedModelInferenceJobStatus = "INACTIVE"
)

// Values returns all known values for TrainedModelInferenceJobStatus. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelInferenceJobStatus) Values() []TrainedModelInferenceJobStatus {
	return []TrainedModelInferenceJobStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
		"CANCEL_PENDING",
		"CANCEL_IN_PROGRESS",
		"CANCEL_FAILED",
		"INACTIVE",
	}
}

type TrainedModelInferenceMaxOutputSizeUnitType string

// Enum values for TrainedModelInferenceMaxOutputSizeUnitType
const (
	TrainedModelInferenceMaxOutputSizeUnitTypeGb TrainedModelInferenceMaxOutputSizeUnitType = "GB"
)

// Values returns all known values for TrainedModelInferenceMaxOutputSizeUnitType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelInferenceMaxOutputSizeUnitType) Values() []TrainedModelInferenceMaxOutputSizeUnitType {
	return []TrainedModelInferenceMaxOutputSizeUnitType{
		"GB",
	}
}

type TrainedModelStatus string

// Enum values for TrainedModelStatus
const (
	TrainedModelStatusCreatePending    TrainedModelStatus = "CREATE_PENDING"
	TrainedModelStatusCreateInProgress TrainedModelStatus = "CREATE_IN_PROGRESS"
	TrainedModelStatusCreateFailed     TrainedModelStatus = "CREATE_FAILED"
	TrainedModelStatusActive           TrainedModelStatus = "ACTIVE"
	TrainedModelStatusDeletePending    TrainedModelStatus = "DELETE_PENDING"
	TrainedModelStatusDeleteInProgress TrainedModelStatus = "DELETE_IN_PROGRESS"
	TrainedModelStatusDeleteFailed     TrainedModelStatus = "DELETE_FAILED"
	TrainedModelStatusInactive         TrainedModelStatus = "INACTIVE"
	TrainedModelStatusCancelPending    TrainedModelStatus = "CANCEL_PENDING"
	TrainedModelStatusCancelInProgress TrainedModelStatus = "CANCEL_IN_PROGRESS"
	TrainedModelStatusCancelFailed     TrainedModelStatus = "CANCEL_FAILED"
)

// Values returns all known values for TrainedModelStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainedModelStatus) Values() []TrainedModelStatus {
	return []TrainedModelStatus{
		"CREATE_PENDING",
		"CREATE_IN_PROGRESS",
		"CREATE_FAILED",
		"ACTIVE",
		"DELETE_PENDING",
		"DELETE_IN_PROGRESS",
		"DELETE_FAILED",
		"INACTIVE",
		"CANCEL_PENDING",
		"CANCEL_IN_PROGRESS",
		"CANCEL_FAILED",
	}
}

type TrainingDatasetStatus string

// Enum values for TrainingDatasetStatus
const (
	TrainingDatasetStatusActive TrainingDatasetStatus = "ACTIVE"
)

// Values returns all known values for TrainingDatasetStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainingDatasetStatus) Values() []TrainingDatasetStatus {
	return []TrainingDatasetStatus{
		"ACTIVE",
	}
}

type TrainingInputMode string

// Enum values for TrainingInputMode
const (
	TrainingInputModeFile     TrainingInputMode = "File"
	TrainingInputModeFastFile TrainingInputMode = "FastFile"
	TrainingInputModePipe     TrainingInputMode = "Pipe"
)

// Values returns all known values for TrainingInputMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (TrainingInputMode) Values() []TrainingInputMode {
	return []TrainingInputMode{
		"File",
		"FastFile",
		"Pipe",
	}
}

type WorkerComputeType string

// Enum values for WorkerComputeType
const (
	WorkerComputeTypeCr1x WorkerComputeType = "CR.1X"
	WorkerComputeTypeCr4x WorkerComputeType = "CR.4X"
)

// Values returns all known values for WorkerComputeType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (WorkerComputeType) Values() []WorkerComputeType {
	return []WorkerComputeType{
		"CR.1X",
		"CR.4X",
	}
}
