// Code generated by smithy-go-codegen DO NOT EDIT.

package types_test

import (
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/cloudfront/types"
)

func ExampleCaCertificatesBundleSource_outputUsage() {
	var union types.CaCertificatesBundleSource
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.CaCertificatesBundleSourceMemberCaCertificatesBundleS3Location:
		_ = v.Value // Value is types.CaCertificatesBundleS3Location

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

var _ *types.CaCertificatesBundleS3Location
