// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns all properties for a data table except for attributes and values. All
// properties from CreateDataTable are returned as well as properties for region
// replication, versioning, and system tables. "Describe" is a deprecated term but
// is allowed to maintain consistency with existing operations.
func (c *Client) DescribeDataTable(ctx context.Context, params *DescribeDataTableInput, optFns ...func(*Options)) (*DescribeDataTableOutput, error) {
	if params == nil {
		params = &DescribeDataTableInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeDataTable", params, optFns, c.addOperationDescribeDataTableMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeDataTableOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeDataTableInput struct {

	// The unique identifier for the data table. Must also accept the table ARN with
	// or without a version alias. If no alias is provided, the default behavior is
	// identical to providing the $LATEST alias.
	//
	// This member is required.
	DataTableId *string

	// The unique identifier for the Amazon Connect instance.
	//
	// This member is required.
	InstanceId *string

	noSmithyDocumentSerde
}

type DescribeDataTableOutput struct {

	// The complete data table information including metadata, configuration, and
	// versioning details.
	//
	// This member is required.
	DataTable *types.DataTable

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeDataTableMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDescribeDataTable{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDescribeDataTable{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDescribeDataTableValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeDataTable"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
