// Code generated by smithy-go-codegen DO NOT EDIT.

package apprunner

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/apprunner/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Delete an App Runner observability configuration resource. You can delete a
// specific revision or the latest active revision. You can't delete a
// configuration that's used by one or more App Runner services.
func (c *Client) DeleteObservabilityConfiguration(ctx context.Context, params *DeleteObservabilityConfigurationInput, optFns ...func(*Options)) (*DeleteObservabilityConfigurationOutput, error) {
	if params == nil {
		params = &DeleteObservabilityConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteObservabilityConfiguration", params, optFns, c.addOperationDeleteObservabilityConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteObservabilityConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteObservabilityConfigurationInput struct {

	// The Amazon Resource Name (ARN) of the App Runner observability configuration
	// that you want to delete.
	//
	// The ARN can be a full observability configuration ARN, or a partial ARN ending
	// with either .../name  or .../name/revision . If a revision isn't specified, the
	// latest active revision is deleted.
	//
	// This member is required.
	ObservabilityConfigurationArn *string

	noSmithyDocumentSerde
}

type DeleteObservabilityConfigurationOutput struct {

	// A description of the App Runner observability configuration that this request
	// just deleted.
	//
	// This member is required.
	ObservabilityConfiguration *types.ObservabilityConfiguration

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteObservabilityConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpDeleteObservabilityConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpDeleteObservabilityConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteObservabilityConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteObservabilityConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
