// Code generated by smithy-go-codegen DO NOT EDIT.

// Package bcmdashboards provides the API client, operations, and parameter types
// for AWS Billing and Cost Management Dashboards.
//
// Amazon Web Services Billing and Cost Management Dashboards is a service that
// enables you to create, manage, and share dashboards that combine multiple
// visualizations of your Amazon Web Services cost and usage data. You can combine
// multiple data sources including Cost Explorer, Savings Plans, and Reserved
// Instance metrics into unified dashboards, helping you analyze spending patterns
// and share cost insights across your organization.
//
// You can use the Amazon Web Services Billing and Cost Management Dashboards API
// to programmatically create, manage, and share dashboards. This includes creating
// custom dashboards, configuring widgets, managing dashboard permissions, and
// sharing dashboards across accounts in your organization.
package bcmdashboards
