// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type AutomationEventFilterName string

// Enum values for AutomationEventFilterName
const (
	AutomationEventFilterNameAccountId    AutomationEventFilterName = "AccountId"
	AutomationEventFilterNameResourceType AutomationEventFilterName = "ResourceType"
	AutomationEventFilterNameEventType    AutomationEventFilterName = "EventType"
	AutomationEventFilterNameEventStatus  AutomationEventFilterName = "EventStatus"
)

// Values returns all known values for AutomationEventFilterName. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomationEventFilterName) Values() []AutomationEventFilterName {
	return []AutomationEventFilterName{
		"AccountId",
		"ResourceType",
		"EventType",
		"EventStatus",
	}
}

type AutomationRuleFilterName string

// Enum values for AutomationRuleFilterName
const (
	AutomationRuleFilterNameName                                    AutomationRuleFilterName = "Name"
	AutomationRuleFilterNameRecommendedActionType                   AutomationRuleFilterName = "RecommendedActionType"
	AutomationRuleFilterNameStatus                                  AutomationRuleFilterName = "Status"
	AutomationRuleFilterNameRuleType                                AutomationRuleFilterName = "RuleType"
	AutomationRuleFilterNameOrganizationConfigurationRuleApplyOrder AutomationRuleFilterName = "OrganizationConfigurationRuleApplyOrder"
	AutomationRuleFilterNameAccountId                               AutomationRuleFilterName = "AccountId"
)

// Values returns all known values for AutomationRuleFilterName. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomationRuleFilterName) Values() []AutomationRuleFilterName {
	return []AutomationRuleFilterName{
		"Name",
		"RecommendedActionType",
		"Status",
		"RuleType",
		"OrganizationConfigurationRuleApplyOrder",
		"AccountId",
	}
}

type ComparisonOperator string

// Enum values for ComparisonOperator
const (
	ComparisonOperatorStringEquals                      ComparisonOperator = "StringEquals"
	ComparisonOperatorStringNotEquals                   ComparisonOperator = "StringNotEquals"
	ComparisonOperatorStringEqualsIgnoreCase            ComparisonOperator = "StringEqualsIgnoreCase"
	ComparisonOperatorStringNotEqualsIgnoreCase         ComparisonOperator = "StringNotEqualsIgnoreCase"
	ComparisonOperatorStringLike                        ComparisonOperator = "StringLike"
	ComparisonOperatorStringNotLike                     ComparisonOperator = "StringNotLike"
	ComparisonOperatorNumericEquals                     ComparisonOperator = "NumericEquals"
	ComparisonOperatorNumericNotEquals                  ComparisonOperator = "NumericNotEquals"
	ComparisonOperatorNumericLessThan                   ComparisonOperator = "NumericLessThan"
	ComparisonOperatorNumericLessThanEquals             ComparisonOperator = "NumericLessThanEquals"
	ComparisonOperatorNumericGreaterThan                ComparisonOperator = "NumericGreaterThan"
	ComparisonOperatorNumericGreaterThanEquals          ComparisonOperator = "NumericGreaterThanEquals"
	ComparisonOperatorStringEqualsIfExists              ComparisonOperator = "StringEqualsIfExists"
	ComparisonOperatorStringNotEqualsIfExists           ComparisonOperator = "StringNotEqualsIfExists"
	ComparisonOperatorStringEqualsIgnoreCaseIfExists    ComparisonOperator = "StringEqualsIgnoreCaseIfExists"
	ComparisonOperatorStringNotEqualsIgnoreCaseIfExists ComparisonOperator = "StringNotEqualsIgnoreCaseIfExists"
	ComparisonOperatorStringLikeIfExists                ComparisonOperator = "StringLikeIfExists"
	ComparisonOperatorStringNotLikeIfExists             ComparisonOperator = "StringNotLikeIfExists"
	ComparisonOperatorNumericEqualsIfExists             ComparisonOperator = "NumericEqualsIfExists"
	ComparisonOperatorNumericNotEqualsIfExists          ComparisonOperator = "NumericNotEqualsIfExists"
	ComparisonOperatorNumericLessThanIfExists           ComparisonOperator = "NumericLessThanIfExists"
	ComparisonOperatorNumericLessThanEqualsIfExists     ComparisonOperator = "NumericLessThanEqualsIfExists"
	ComparisonOperatorNumericGreaterThanIfExists        ComparisonOperator = "NumericGreaterThanIfExists"
	ComparisonOperatorNumericGreaterThanEqualsIfExists  ComparisonOperator = "NumericGreaterThanEqualsIfExists"
)

// Values returns all known values for ComparisonOperator. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ComparisonOperator) Values() []ComparisonOperator {
	return []ComparisonOperator{
		"StringEquals",
		"StringNotEquals",
		"StringEqualsIgnoreCase",
		"StringNotEqualsIgnoreCase",
		"StringLike",
		"StringNotLike",
		"NumericEquals",
		"NumericNotEquals",
		"NumericLessThan",
		"NumericLessThanEquals",
		"NumericGreaterThan",
		"NumericGreaterThanEquals",
		"StringEqualsIfExists",
		"StringNotEqualsIfExists",
		"StringEqualsIgnoreCaseIfExists",
		"StringNotEqualsIgnoreCaseIfExists",
		"StringLikeIfExists",
		"StringNotLikeIfExists",
		"NumericEqualsIfExists",
		"NumericNotEqualsIfExists",
		"NumericLessThanIfExists",
		"NumericLessThanEqualsIfExists",
		"NumericGreaterThanIfExists",
		"NumericGreaterThanEqualsIfExists",
	}
}

type EnrollmentStatus string

// Enum values for EnrollmentStatus
const (
	EnrollmentStatusActive   EnrollmentStatus = "Active"
	EnrollmentStatusInactive EnrollmentStatus = "Inactive"
	EnrollmentStatusPending  EnrollmentStatus = "Pending"
	EnrollmentStatusFailed   EnrollmentStatus = "Failed"
)

// Values returns all known values for EnrollmentStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EnrollmentStatus) Values() []EnrollmentStatus {
	return []EnrollmentStatus{
		"Active",
		"Inactive",
		"Pending",
		"Failed",
	}
}

type EventStatus string

// Enum values for EventStatus
const (
	EventStatusReady              EventStatus = "Ready"
	EventStatusInProgress         EventStatus = "InProgress"
	EventStatusComplete           EventStatus = "Complete"
	EventStatusFailed             EventStatus = "Failed"
	EventStatusCancelled          EventStatus = "Cancelled"
	EventStatusRollbackReady      EventStatus = "RollbackReady"
	EventStatusRollbackInProgress EventStatus = "RollbackInProgress"
	EventStatusRollbackComplete   EventStatus = "RollbackComplete"
	EventStatusRollbackFailed     EventStatus = "RollbackFailed"
)

// Values returns all known values for EventStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EventStatus) Values() []EventStatus {
	return []EventStatus{
		"Ready",
		"InProgress",
		"Complete",
		"Failed",
		"Cancelled",
		"RollbackReady",
		"RollbackInProgress",
		"RollbackComplete",
		"RollbackFailed",
	}
}

type EventType string

// Enum values for EventType
const (
	EventTypeSnapshotAndDeleteUnattachedEbsVolume EventType = "SnapshotAndDeleteUnattachedEbsVolume"
	EventTypeUpgradeEbsVolumeType                 EventType = "UpgradeEbsVolumeType"
)

// Values returns all known values for EventType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EventType) Values() []EventType {
	return []EventType{
		"SnapshotAndDeleteUnattachedEbsVolume",
		"UpgradeEbsVolumeType",
	}
}

type OrganizationRuleMode string

// Enum values for OrganizationRuleMode
const (
	OrganizationRuleModeAnyAllowed  OrganizationRuleMode = "AnyAllowed"
	OrganizationRuleModeNoneAllowed OrganizationRuleMode = "NoneAllowed"
)

// Values returns all known values for OrganizationRuleMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OrganizationRuleMode) Values() []OrganizationRuleMode {
	return []OrganizationRuleMode{
		"AnyAllowed",
		"NoneAllowed",
	}
}

type RecommendedActionFilterName string

// Enum values for RecommendedActionFilterName
const (
	RecommendedActionFilterNameResourceType                        RecommendedActionFilterName = "ResourceType"
	RecommendedActionFilterNameRecommendedActionType               RecommendedActionFilterName = "RecommendedActionType"
	RecommendedActionFilterNameResourceId                          RecommendedActionFilterName = "ResourceId"
	RecommendedActionFilterNameLookBackPeriodInDays                RecommendedActionFilterName = "LookBackPeriodInDays"
	RecommendedActionFilterNameCurrentResourceDetailsEbsVolumeType RecommendedActionFilterName = "CurrentResourceDetailsEbsVolumeType"
	RecommendedActionFilterNameResourceTagsKey                     RecommendedActionFilterName = "ResourceTagsKey"
	RecommendedActionFilterNameResourceTagsValue                   RecommendedActionFilterName = "ResourceTagsValue"
	RecommendedActionFilterNameAccountId                           RecommendedActionFilterName = "AccountId"
	RecommendedActionFilterNameRestartNeeded                       RecommendedActionFilterName = "RestartNeeded"
)

// Values returns all known values for RecommendedActionFilterName. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RecommendedActionFilterName) Values() []RecommendedActionFilterName {
	return []RecommendedActionFilterName{
		"ResourceType",
		"RecommendedActionType",
		"ResourceId",
		"LookBackPeriodInDays",
		"CurrentResourceDetailsEbsVolumeType",
		"ResourceTagsKey",
		"ResourceTagsValue",
		"AccountId",
		"RestartNeeded",
	}
}

type RecommendedActionType string

// Enum values for RecommendedActionType
const (
	RecommendedActionTypeSnapshotAndDeleteUnattachedEbsVolume RecommendedActionType = "SnapshotAndDeleteUnattachedEbsVolume"
	RecommendedActionTypeUpgradeEbsVolumeType                 RecommendedActionType = "UpgradeEbsVolumeType"
)

// Values returns all known values for RecommendedActionType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RecommendedActionType) Values() []RecommendedActionType {
	return []RecommendedActionType{
		"SnapshotAndDeleteUnattachedEbsVolume",
		"UpgradeEbsVolumeType",
	}
}

type ResourceType string

// Enum values for ResourceType
const (
	ResourceTypeEbsVolume ResourceType = "EbsVolume"
)

// Values returns all known values for ResourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ResourceType) Values() []ResourceType {
	return []ResourceType{
		"EbsVolume",
	}
}

type RuleApplyOrder string

// Enum values for RuleApplyOrder
const (
	RuleApplyOrderBeforeAccountRules RuleApplyOrder = "BeforeAccountRules"
	RuleApplyOrderAfterAccountRules  RuleApplyOrder = "AfterAccountRules"
)

// Values returns all known values for RuleApplyOrder. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RuleApplyOrder) Values() []RuleApplyOrder {
	return []RuleApplyOrder{
		"BeforeAccountRules",
		"AfterAccountRules",
	}
}

type RuleStatus string

// Enum values for RuleStatus
const (
	RuleStatusActive   RuleStatus = "Active"
	RuleStatusInactive RuleStatus = "Inactive"
)

// Values returns all known values for RuleStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RuleStatus) Values() []RuleStatus {
	return []RuleStatus{
		"Active",
		"Inactive",
	}
}

type RuleType string

// Enum values for RuleType
const (
	RuleTypeOrganizationalRule RuleType = "OrganizationRule"
	RuleTypeAccountRule        RuleType = "AccountRule"
)

// Values returns all known values for RuleType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RuleType) Values() []RuleType {
	return []RuleType{
		"OrganizationRule",
		"AccountRule",
	}
}

type SavingsEstimationMode string

// Enum values for SavingsEstimationMode
const (
	SavingsEstimationModeBeforeDiscount SavingsEstimationMode = "BeforeDiscount"
	SavingsEstimationModeAfterDiscount  SavingsEstimationMode = "AfterDiscount"
)

// Values returns all known values for SavingsEstimationMode. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SavingsEstimationMode) Values() []SavingsEstimationMode {
	return []SavingsEstimationMode{
		"BeforeDiscount",
		"AfterDiscount",
	}
}

type StepStatus string

// Enum values for StepStatus
const (
	StepStatusReady      StepStatus = "Ready"
	StepStatusInProgress StepStatus = "InProgress"
	StepStatusComplete   StepStatus = "Complete"
	StepStatusFailed     StepStatus = "Failed"
)

// Values returns all known values for StepStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (StepStatus) Values() []StepStatus {
	return []StepStatus{
		"Ready",
		"InProgress",
		"Complete",
		"Failed",
	}
}

type StepType string

// Enum values for StepType
const (
	StepTypeCreateEbsSnapshot StepType = "CreateEbsSnapshot"
	StepTypeDeleteEbsVolume   StepType = "DeleteEbsVolume"
	StepTypeModifyEbsVolume   StepType = "ModifyEbsVolume"
	StepTypeCreateEbsVolume   StepType = "CreateEbsVolume"
)

// Values returns all known values for StepType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (StepType) Values() []StepType {
	return []StepType{
		"CreateEbsSnapshot",
		"DeleteEbsVolume",
		"ModifyEbsVolume",
		"CreateEbsVolume",
	}
}

type SummaryDimensionKey string

// Enum values for SummaryDimensionKey
const (
	SummaryDimensionKeyEventStatus SummaryDimensionKey = "EventStatus"
)

// Values returns all known values for SummaryDimensionKey. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SummaryDimensionKey) Values() []SummaryDimensionKey {
	return []SummaryDimensionKey{
		"EventStatus",
	}
}
