// Code generated by smithy-go-codegen DO NOT EDIT.

package jsonrpc10querycompatible

import (
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/jsonrpc10querycompatible/schemas"
	"github.com/aws/aws-sdk-go-v2/internal/protocoltest/jsonrpc10querycompatible/types"
	smithy "github.com/aws/smithy-go"
)

// TypeRegistry is the type registry for this service.
var TypeRegistry = &smithy.TypeRegistry{
	Entries: map[string]*smithy.TypeRegistryEntry{
		"aws.protocoltests.json#ItemNotFound": {
			Schema: schemas.ItemNotFound,
			New:    func() any { return &types.ItemNotFound{} },
		},
	},
}
