// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudfront

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a real-time log configuration.
//
// You cannot delete a real-time log configuration if it's attached to a cache
// behavior. First update your distributions to remove the real-time log
// configuration from all cache behaviors, then delete the real-time log
// configuration.
//
// To delete a real-time log configuration, you can provide the configuration's
// name or its Amazon Resource Name (ARN). You must provide at least one. If you
// provide both, CloudFront uses the name to identify the real-time log
// configuration to delete.
func (c *Client) DeleteRealtimeLogConfig(ctx context.Context, params *DeleteRealtimeLogConfigInput, optFns ...func(*Options)) (*DeleteRealtimeLogConfigOutput, error) {
	if params == nil {
		params = &DeleteRealtimeLogConfigInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteRealtimeLogConfig", params, optFns, c.addOperationDeleteRealtimeLogConfigMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteRealtimeLogConfigOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteRealtimeLogConfigInput struct {

	// The Amazon Resource Name (ARN) of the real-time log configuration to delete.
	ARN *string

	// The name of the real-time log configuration to delete.
	Name *string

	noSmithyDocumentSerde
}

type DeleteRealtimeLogConfigOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteRealtimeLogConfigMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestxml_serializeOpDeleteRealtimeLogConfig{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestxml_deserializeOpDeleteRealtimeLogConfig{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteRealtimeLogConfig"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
